
const string SYSTEM_PATTERN="<system name=*";
const string CIRCUIT_PATTERN="*<circuit name=*";
const string INSTRUM_PATTERN="*<cryo_device>*";

dyn_dyn_string g_ddsInstrum;
dyn_string g_dsCircuits;
dyn_string g_dsCircuitsNo;
bool g_bXMLInit_Done;

//---------------------

main()
{
string sFile, sLog;
int iRes, i, iLen, iPos;
dyn_string dsErrors, dsOk;

  DebugTN("Start...");

  dynClear(g_dsCircuits);
  dynClear(g_ddsInstrum);
  
  sFile=getPath(DATA_REL_PATH)+"Cryo_Synoptics_Data_LHC.xml";
  sLog=getPath(LOG_REL_PATH)+"checkCryoInstrum";
  
  iRes=readXMLFile(sFile);
  iLen=dynlen(g_dsCircuits);
  //for each Circuit - check the Cryo Instrum
    
  for (i=1; i<=iLen; i++)
    {  
    //if(g_dsCircuits[i]=="RB.A12") DebugN(g_ddsInstrum[i]);
	iRes=checkCircuitInstrument(i, dsErrors, dsOk);
    }
  
  iPos=dynlen(dsOk);
  dynInsertAt(dsOk, iPos + "/" + iLen + " Circuits Ok\n--------------------\n", 1);
  dynInsertAt(dsErrors, (iLen-iPos) + "/" + iLen + " Circuits Bad\n--------------------\n", 1);  
    
  iRes=writeLog(sLog, dsErrors, dsOk);

  DebugTN("...End");  
  
}

//---------------------

int writeLog(const string sLog, const dyn_string dsErrors, const dyn_string dsOk)
{
string sLogPath;
file fLogFile;
int i, iLen, iRes;

  sLogPath = sLog + "BAD_.txt";
  fLogFile = fopen(sLogPath, "w");
  iLen=dynlen(dsErrors);
  for (i=1; i<=iLen; i++)
    fputs(dsErrors[i] + "\n", fLogFile);
  fclose(fLogFile);
  
  sLogPath = sLog + "OK_.txt";
  fLogFile = fopen(sLogPath, "w");
  iLen=dynlen(dsOk);
  for (i=1; i<=iLen; i++)
    fputs(dsOk[i] + "\n", fLogFile);
  fclose(fLogFile);
  
  return iRes;
  
}

//---------------------  
  
int readXMLFile(const string sFileName)
{
string sBuffer, sSystem;
dyn_string dsSplit, dsLines;
int i, iLen, iRes, iPos, iNum;
dyn_string dsInstrum;

	iRes=access(sFileName, F_OK);
	if (iRes==0) // File exist
		{
	 	fileToString(sFileName, sBuffer);
		dsLines = strsplit(sBuffer, "\n");
		iLen = dynlen(dsLines);
		for(i=1;i<=iLen;i++)
			{
			dsSplit=strsplit(dsLines[i], "\"");
			if(dynlen(dsSplit)==3)
				{
				if(patternMatch(SYSTEM_PATTERN, dsLines[i]))
					{
					sSystem=dsSplit[2];
					}
				}	
			else if(dynlen(dsSplit)==9)
				{
				if(patternMatch(CIRCUIT_PATTERN, dsLines[i]))
					{
					dynAppend(g_dsCircuits, dsSplit[2]);
					iNum=getNumberOfInstrum(dsSplit[2], dsSplit[4], dsSplit[6], dsSplit[8]);
					if(patternMatch("RCS.*", dsSplit[2])) iNum=iNum+3;
					dynAppend(g_dsCircuitsNo, iNum);
					iPos++;
					g_ddsInstrum[iPos]=makeDynString();
					}
				}
			else
				{
				if (patternMatch(INSTRUM_PATTERN, dsLines[i]))
					{
					dsInstrum=g_ddsInstrum[iPos];
					string sTemp;
					sTemp=substr(dsLines[i], strpos(dsLines[i], "<cryo_device>") + strlen("<cryo_device>"));
					sTemp=substr(sTemp, 0, strpos(sTemp, "</cryo_device>"));		
					dynAppend(dsInstrum,sSystem+sTemp);
					g_ddsInstrum[iPos]=dsInstrum;
					}
				}
			}
		g_bXMLInit_Done=TRUE;
		}
	else
		DebugN("readXMLFile() - File does not exist! - " + sFileName);
	
	return iRes;  
}

//---------------------

int checkCircuitInstrument(const int iPos, dyn_string &dsErrors, dyn_string &dsOk)
{
string sDpe;
int i, iLen, iRes;    
bool bOk=FALSE;

  iLen=dynlen(g_ddsInstrum[iPos]);
  
  if(iLen!=g_dsCircuitsNo[iPos])
    dynAppend(dsErrors, g_dsCircuits[iPos] + " - Wrong number of cryo_device: " + iLen + " (" + g_dsCircuitsNo[iPos] + ")");
  else
    bOk=TRUE;
    
  for(i=1;i<=iLen;i++)
    {
    sDpe=unGenericDpFunctions_dpAliasToName(g_ddsInstrum[iPos][i]);
    if(sDpe=="")
      {
      dynAppend(dsErrors, g_dsCircuits[iPos] + " - " + g_ddsInstrum[iPos][i]);
      bOk=FALSE;
      }
    }
 
  if(bOk)
    dynAppend(dsOk, g_dsCircuits[iPos]);
   
  return iRes;
}

//---------------------

int getNumberOfInstrum(const string sCircuit, const string sIT, const string sCT, const string sPW)
{
int iRes;
    
  switch(sIT)
    {
    case "A":
      switch(sCT)
        {
        case "MAINDIPOLE":
          iRes=18;
          break;
        case "MAINQUAD":
          iRes=9;          
          break;  
        case "IT":
          iRes=15;          
          break;
         default:
           iRes=-1;                  
        } 
      break;
      
    case "B1":
      if(sCT=="IPD")
        iRes=9;
      else
        {
        if(patternMatch("X*", sPW))  //Inner Triplet
		  iRes=7;		
        else if(patternMatch("RCO*", sCircuit)) 
          iRes=6;
        else
          iRes=9;          
        }
      break;
      
    case "B2":
      iRes=12;
      break;
      
    case "C":
      iRes=6;      
      break;

    case "D":
      iRes=-1;      
      break;
      
    default:
      iRes=-2;                  
    }

  if(iRes!=-2)
    iRes=iRes+2;  //to add Cryo_Maintain and Cryo_Start
          
  return iRes;
}        
