/**
@authors: Herve Milcent AB/CO-IS
@date: 25/04/2008
@file unLHCCircuit_CircuitWidget.ctl

@par Modification History
  26/04/2011: Herve
  - CIR-23: Powering sub-sector and circuit widget: use PIC superlock for the animation

*/

/**
* @name LHCCircuit widget
This is a set of functions provided to manage LHCCircuit widget
* @{
*/

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_RegisterCB
/**
Purpose:
Register function used with the unTreeDeviceOverview_distributedRegister 

  @param sDp: string, input: the bConnected Dp
  @param bConnected: bool, input: the state of the system
  @param sTreeDp: string, input: the internal tree command Dp
  @param iCommand: int, input: the command=DEVUN_ADD_COMMAND/DEVUN_DELETE_COMMAND/DEVUN_APPLY_FILTER
  @param sTreeDpSystem: string, input: the internal tree system Dp
  @param sSystemName: string, input: the system name/"" associated with the command

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_RegisterCB(string sDp, bool bConnected, string sTreeDp, int iCommand, string sTreeDpSystem, string sSystemName)
{
  bool bReInit;
  string sCircuit = $sCircuit;
  dyn_string dsCircuitDeviceDp, dsCircuitDeviceAlias, dsCircuitDeviceType;
  bool b;
  mapping mDeviceDp, mdsDeviceDpe, mDeviceType, mDQGROUPId;
  int iFGC_MASK;
  
  unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl RegisterCB:"+$sCircuit+","+$sInterlockType, "RegisterCB", iCommand, sSystemName);
  switch(iCommand) {
    case DEVUN_ADD_COMMAND:
    case DEVUN_DELETE_COMMAND:
      bReInit = true;
      break;
    default:
      if(!g_bInitDone) // the first time do also the init in case other command
        bReInit = true;
      g_bInitDone = true;
      break;
  }
  
  if(bReInit) {
    unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl RegisterCB:"+$sCircuit+","+$sInterlockType, "RegisterCB start getCircuitDevice:", sCircuit);
    // get all the circuit device associated with the circuit
    unLHCCircuit_TreeOverview_getCircuitDevice(sCircuit, dsCircuitDeviceDp, dsCircuitDeviceAlias, dsCircuitDeviceType);
    unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl RegisterCB:"+$sCircuit+","+$sInterlockType, "RegisterCB end getCircuitDevice:", sCircuit);
    if(dynlen(dsCircuitDeviceDp) > 0) {
    // re-organise the device: mainly remove all the QPS device names and replace them by the appropriate DQGROUP
      unLHCCircuit_CircuitWidget_ReOrganiseDevice(sCircuit, dsCircuitDeviceDp, dsCircuitDeviceAlias, dsCircuitDeviceType, 
                                    mDeviceDp, mDeviceType, mDQGROUPId);
      unGenericDpFunctions_debugN(DEBUG_ONLY_BIT5, "unCIRCUITWidget.pnl RegisterCB:"+$sCircuit+","+$sInterlockType, "RegisterCB res:", sCircuit, dsCircuitDeviceDp, dsCircuitDeviceAlias, dsCircuitDeviceType, mDeviceDp, mDeviceType);
      // get the DPE associated with the device for the circuit
      b=unLHCCircuit_CircuitWidget_GetDpe(mDeviceDp, mDeviceType, mdsDeviceDpe, iFGC_MASK);
      unGenericDpFunctions_debugN(DEBUG_ONLY_BIT5, "unCIRCUITWidget.pnl RegisterCB:"+$sCircuit+","+$sInterlockType, "RegisterCB", b, mdsDeviceDpe);
      if(b && (mdsDeviceDpe != g_mdsDeviceDpe)) {
        unGenericDpFunctions_debugN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl RegisterCB:"+$sCircuit+","+$sInterlockType, "RegisterCB !!!!!!!!!!dpDisConnect", $sCircuit, g_mdsDeviceDpe);
        // disconnect and then if the DPE check is correct --> connect.
        unLHCCircuit_CircuitWidget_dpDisConnect();
        unLHCCircuit_CircuitWidget_setDisconnection();
        if(unLHCCircuit_CircuitWidget_checkDpeList(mdsDeviceDpe, $sCircuit, $sInterlockType)) {
          unLHCCircuit_CircuitWidget_dpConnect(mdsDeviceDpe, mDQGROUPId, iFGC_MASK);
        }
        unGenericDpFunctions_debugN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl RegisterCB:"+$sCircuit+","+$sInterlockType, "RegisterCB !!!!!!!!!!dpConnect", $sCircuit, g_mdsDeviceDpe);
      }
      else if(!b) {
        unGenericDpFunctions_debugN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl RegisterCB:"+$sCircuit+","+$sInterlockType, "RegisterCB !!!!!!!!!!dpDisConnect", $sCircuit, g_mdsDeviceDpe);
        unLHCCircuit_CircuitWidget_dpDisConnect();
        unLHCCircuit_CircuitWidget_setDisconnection();
      }
    }
    else{
      unLHCCircuit_CircuitWidget_noCircuit();
    }
  }
  
  /*if(sCircuit=="RQD.A23")
    DebugN("unLHCCircuit_CircuitWidget_dpConnect", mdsDeviceDpe); */
    
    
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_checkDpeList
/**
Purpose:
Check the DPEList 

  @param mdsDeviceDpe: mapping, input: list of DPE/system
  @param sCircuit: string, input: the circuit
  @param sInterlockType: string, input: the interlock type

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
bool unLHCCircuit_CircuitWidget_checkDpeList(mapping mdsDeviceDpe, string sCircuit, string sInterlockType)
{
  bool bOk;
  int iNbSystem = mappinglen(mdsDeviceDpe);
  string sSystem;
  int i;
  
  // check if the number of system is correct
  switch(sInterlockType)
  {
    case CIRCUIT_A:
      bOk=(iNbSystem==LHC_CIRCUIT_PVSS_SYSTEMS)||(iNbSystem==LHC_CIRCUIT_PVSS_SYSTEMS_NQPS);
      break;      
    case CIRCUIT_B2:
      bOk=(iNbSystem==LHC_CIRCUIT_PVSS_SYSTEMS);
      break;
    case CIRCUIT_B1:
      if(dynContains(g_dsCircuitException, sCircuit) > 0)
        bOk=(iNbSystem==2);
      else
        bOk=(iNbSystem==LHC_CIRCUIT_PVSS_SYSTEMS);
      break;
    case CIRCUIT_C:
      bOk=(iNbSystem==2);
      break;
    case CIRCUIT_D:			
      bOk=(iNbSystem==1);			
      break;
  }
     
  if(bOk) { // ok nb system, check contents
    bOk = true;
  // check if for each system the DPE list is correct
    for(i=1; (i<=iNbSystem) & bOk;i++) {
      sSystem = mappingGetKey(mdsDeviceDpe, i);
      unGenericDpFunctions_debugN(DEBUG_ONLY_BIT4, "unCIRCUITWidget.pnl checkDpeList:"+$sCircuit+","+$sInterlockType, "Key="+sSystem, i);
      if(sSystem == getSystemName())
        bOk = unLHCCircuit_CircuitWidget_checkFGC(mappingGetValue(mdsDeviceDpe, i), sCircuit, sInterlockType);
      else if(strpos(sSystem, "QPS_") == 0)
        bOk = unLHCCircuit_CircuitWidget_checkQPS(mappingGetValue(mdsDeviceDpe, i), sCircuit, sInterlockType);
      else if(strpos(sSystem, "pic_") == 0)
        bOk = unLHCCircuit_CircuitWidget_checkPIC(mappingGetValue(mdsDeviceDpe, i), sCircuit, sInterlockType);
      else
        bOk = false;
   }
  }
    
  unGenericDpFunctions_debugN(DEBUG_ONLY_BIT4, "unCIRCUITWidget.pnl checkDpeList:"+$sCircuit+","+$sInterlockType, "end checkDpeList", iNbSystem, mappinglen(mdsDeviceDpe), sCircuit, sInterlockType, bOk);
  return bOk;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_checkFGC
/**
Purpose:
Check the DPE List for the FGC

  @param dsDpe: dyn_string, input: list of DPE
  @param sCircuit: string, input: the circuit
  @param sInterlockType: string, input: the interlock type

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
bool unLHCCircuit_CircuitWidget_checkFGC(dyn_string dsDpe, string sCircuit, string sInterlockType)
{
  bool bOk;
  
  switch(sInterlockType)
  {
    case CIRCUIT_A:
      if(strpos(sCircuit, "RQX") == 0)
        bOk=(dynlen(dsDpe)==8);
      else
        bOk=(dynlen(dsDpe)==4);
      break;
    case CIRCUIT_B1:
    case CIRCUIT_C:
    case CIRCUIT_D:
      bOk=(dynlen(dsDpe)==4);
      break;
    case CIRCUIT_B2:
      bOk=(dynlen(dsDpe)==6);
      break;
  }
  
  unGenericDpFunctions_debugN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl unLHCCircuit_CircuitWidget_checkFGC:"+$sCircuit+","+$sInterlockType, "checkFGC", bOk, dynlen(dsDpe));
  return bOk;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_checkQPS
/**
Purpose:
Check the DPE List for the FGC

  @param dsDpe: dyn_string, input: list of DPE
  @param sCircuit: string, input: the circuit
  @param sInterlockType: string, input: the interlock type

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
bool unLHCCircuit_CircuitWidget_checkQPS(dyn_string dsDpe, string sCircuit, string sInterlockType, bool nQPS=FALSE)
{
  bool bOk;
  
  switch(sInterlockType)
  {
    case CIRCUIT_A:
      if((strpos(sCircuit, "RB.A") == 0) || (strpos(sCircuit, "RQD.A") == 0) || (strpos(sCircuit, "RQF.A") == 0))
        {
          bOk = ((dynlen(dsDpe)==7) || (dynlen(dsDpe)==14));
        }
      else
        bOk=(dynlen(dsDpe)==7);
      break;
    case CIRCUIT_B1:
      bOk = ((dynlen(dsDpe)==7) || (dynlen(dsDpe)==14));
      break;
    case CIRCUIT_B2:
    case CIRCUIT_C:
      bOk=(dynlen(dsDpe)==7);
      break;
  }
  
  unGenericDpFunctions_debugN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl unLHCCircuit_CircuitWidget_checkQPS:"+$sCircuit+","+$sInterlockType, "checkQPS", bOk, dynlen(dsDpe));
  return bOk;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_checkPIC
/**
Purpose:
Check the DPE List for the FGC

  @param dsDpe: dyn_string, input: list of DPE
  @param sCircuit: string, input: the circuit
  @param sInterlockType: string, input: the interlock type

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
bool unLHCCircuit_CircuitWidget_checkPIC(dyn_string dsDpe, string sCircuit, string sInterlockType)
{
  bool bOk;
  
  switch(sInterlockType)
  {
    case CIRCUIT_A:
      if(strpos(sCircuit, "RB.A") == 0)
        bOk=(dynlen(dsDpe)==14);
      else
        bOk=(dynlen(dsDpe)==10);
      break;
    case CIRCUIT_B1:
      bOk=(dynlen(dsDpe)==8);
      break;
    case CIRCUIT_B2:
      bOk=(dynlen(dsDpe)==9);
      break;
    case CIRCUIT_C:
      bOk=(dynlen(dsDpe)==6);
      break;
  }
  unGenericDpFunctions_debugN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl unLHCCircuit_CircuitWidget_checkPIC:"+$sCircuit+","+$sInterlockType, "checkPIC", bOk, dynlen(dsDpe));
  return bOk;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_noCircuit
/**
Purpose:
set the widget animation when the circuit is unknown


Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_noCircuit()
{
  unLHCCircuit_CircuitWidget_setWidgetAnimationColor("unDataNoAccess", "");			
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_setDisconnection
/**
Purpose:
set the widget animation when at least one system of the circuit is not connected


Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_setDisconnection()
{
  unLHCCircuit_CircuitWidget_setWidgetAnimationColor("cyan", "o");
//  DebugTN("disconn");
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_setWidgetAnimationColor
/**
Purpose:
Animate the circuit widget color

  @param sBodyColor: string, input: body color
  @param sWarningText: string, input: warning text
  @param bSuperLock: bool, input, superlock state: true=superlock ON/false=superlock false (default)

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_setWidgetAnimationColor(string sBodyColor, string sWarningText, bool bSuperLock=false) 
{
  setMultiValue("Body1", "backCol", sBodyColor, "WarningText", "text", sWarningText, 
                "WarningText", "foreCol", sBodyColor, "AlarmText", "text", "", "superlock", "visible", bSuperLock);
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_dpDisConnect
/**
Purpose:
Do the dpDisconnect


Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_dpDisConnect()
{
  int i, len=mappinglen(g_mdsDeviceDpe);
  mapping m;
  dyn_string dsCircuitCIPC;
  synchronized(g_mbBadColor)
  {
    dsCircuitCIPC = g_dsCircuitCIPC;
  }  
  if(dynlen(dsCircuitCIPC))
  {
    unGenericDpFunctions_debugN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl SuperLock dpDisconnect: "+$sCircuit+","+$sInterlockType, "SuperLock dpDisconnect", $sCircuit, dsCircuitCIPC);
    dpDisconnect("unLHCCircuit_CircuitWidget_CIPC_SuperLockCB", dsCircuitCIPC);
  }
  for(i=1;i<=len;i++) {
    dpDisconnect("unLHCCircuit_CircuitWidget_CB", mappingGetValue(g_mdsDeviceDpe, i));
  }
  synchronized(g_mbBadColor)
  {
    g_mdsDeviceDpe = m;
    g_mbWarningLetter = m;
    g_mbBadColor = m;
    dynClear(g_dsCircuitCIPC);
    g_bSuperLock = false;
  }
}
//------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_CircuitWidget_CIPC_SuperLockCB
/** Superlock CB
  
@par Constraints
  None

@par Usage
  Public

@par PVSS managers
  Ui

@param dsDPE  input, list of DPE
@param ddsComment  input, list of device log
*/
unLHCCircuit_CircuitWidget_CIPC_SuperLockCB(dyn_string dsDPE, dyn_dyn_string ddsComment)
{
  int i, len=dynlen(ddsComment);
  bool bSuperLock=false;
  string sCircuit=$sCircuit;
  
  if(strpos(sCircuit, "RB.A") == 0) // RB circuit, add .EVEN
    sCircuit += ".EVEN";
  for(i=1;i<=len;i++)
  {
    bSuperLock = picCIPC_FaceplateIsCommented(ddsComment[i], sCircuit);
    if(bSuperLock)
      i=len+1;
  }
  synchronized(g_mbBadColor)
  {
    g_bSuperLock = bSuperLock;
    unLHCCircuit_CircuitWidget_setWidgetState();
  }
  unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl SuperLock CB: "+$sCircuit+","+$sInterlockType, "SuperLock CB", $sCircuit, sCircuit, dsDPE, ddsComment, "SuperLock:"+g_bSuperLock);
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_dpConnect
/**
Purpose:
Do the dpConnect

  @param mdsDeviceDpe: mapping, input: list of DPE
  @param mDQGROUPId: mapping, input: list of QPS id per DQGROUP involded in the circuit
  @param iFGC_MASK: int, input: FGC mask

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_dpConnect(mapping mdsDeviceDpe, mapping mDQGROUPId, int iFGC_MASK)
{
  int i, len=mappinglen(mdsDeviceDpe);
  dyn_string ds;
  
  synchronized(g_mbBadColor)
  {
    // prepare the data
    g_mdsDeviceDpe = mdsDeviceDpe;
    g_mDQGROUPId = mDQGROUPId;
    g_iFGC_MASK = iFGC_MASK;
    
    for(i=1;i<=len;i++) {
      g_mbBadColor[mappingGetKey(mdsDeviceDpe, i)] = true;
      g_mbWarningLetter[mappingGetKey(mdsDeviceDpe, i)] = true;
      ds = mappingGetValue(mdsDeviceDpe, i);
      if(mappingGetKey(mdsDeviceDpe, i) == "pic_1:") // WARNING: works fine if the FE systemIntegritty DPE are the first ones.
        unLHCCircuit_CircuitWidget_CIPC_getSuperLock(ds);
    }
  }
  for(i=1;i<=len;i++) {
    ds = mappingGetValue(mdsDeviceDpe, i);
    dpConnect("unLHCCircuit_CircuitWidget_CB", ds);
  }
  synchronized(g_mbBadColor)
  {
    if(dynlen(g_dsCircuitCIPC))
    {
      unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl SuperLock dpConnect: "+$sCircuit+","+$sInterlockType, "SuperLock dpConnect", $sCircuit, g_dsCircuitCIPC);
      dpConnect("unLHCCircuit_CircuitWidget_CIPC_SuperLockCB", g_dsCircuitCIPC);
    }
  }
  unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl dpConnect:"+$sCircuit+","+$sInterlockType, "!!!!!!!!!!!!!!!", g_mdsDeviceDpe, mDQGROUPId, iFGC_MASK, "!!!!!!!!!!!!!!!end ");
}

//------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_CircuitWidget_CIPC_getSuperLock
/** Set the CIPC device name (g_dsCircuitCIPC) for the circuit Superlock state
  
@par Constraints
  None

@par Usage
  Public

@par PVSS managers
  Ui

@param dsDPE  input, list of DPE
*/
unLHCCircuit_CircuitWidget_CIPC_getSuperLock(dyn_string dsDPE)
{
  string sType, sDP;
  int i, len;
  dyn_string dsCIPC;
  
  len = dynlen(dsDPE);
  if(len >=1)
  {
    for(i=1;i<=len;i++) {
      sDP=dpSubStr(dsDPE[i], DPSUB_SYS_DP);
      if(dpExists(sDP)) {
        sType = dpTypeName(sDP);
        if(sType == "CIPC")
        {
          dynAppend(dsCIPC, sDP+".statusInformation.deviceLog");
        }
      }
      dynUnique(dsCIPC);
      g_dsCircuitCIPC = dsCIPC;
      unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl getSuperLock: "+$sCircuit+","+$sInterlockType, "getSuperLock", $sCircuit, dsDPE, g_dsCircuitCIPC);
    }
  }
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_CB
/**
Purpose:
call back function, evaluate the content and animate the widget

  @param dsDpe: dyn_string, input: list of DPE
  @param diValue: dyn_dyn_int, input: list value

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_CB(dyn_string dsDpe, dyn_dyn_int diValue)
{
  bool bBadColor, bWarningLetter;
  string sSystem=unGenericDpFunctions_getSystemName(dsDpe[1]);
  int i, len;

  unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl Circuit_CB:"+$sCircuit+","+$sInterlockType, "Circuit_CB", $sCircuit, dsDpe, diValue);
  
  string sCircuit=$sCircuit;

  len = dynlen(dsDpe);
  for(i=1;i<=len;i++) {
    switch(dpTypeName(dpSubStr(dsDpe[i], DPSUB_SYS_DP))) {
      case "DQGROUP":
        // DQGROUP animate bodycolor
        unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl QPS Circuit_CB:"+$sCircuit+","+$sInterlockType, "Circuit_CB check DQGROUP", $sCircuit, g_mDQGROUPId);
        bBadColor |= unLHCCircuit_CircuitWidget_CBCheckDQGROUPContent(dpSubStr(dsDpe[i], DPSUB_SYS_DP), diValue[i]);
        break;
      case "CIPC":
        // PIC DPE animate bodycolor
        unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl PIC Circuit_CB:"+$sCircuit+","+$sInterlockType, "Circuit_CB check CIPC", $sCircuit);
        if(diValue[i][1] != 1) {
          unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl PIC Circuit_CB:"+$sCircuit+","+$sInterlockType, "!!!!! CIPC COL", dsDpe[i]);
          bBadColor |=true;
        }
        break;
      case "FGC2_LHC_PC":
        // FGC2_LHC_PC: ST_FAULTS animate bodycolor, ST_GTWDEV (dev not available) animate warningtext
        unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl FGC Circuit_CB:"+$sCircuit+","+$sInterlockType, "Circuit_CB check FGC2_LHC_PC", $sCircuit);
        if(strpos(dsDpe[i], ".ST_FAULTS") > 0)
          {
          if(diValue[i][1] != 0)
            {
            unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl FGC Circuit_CB:"+$sCircuit+","+$sInterlockType, "!!!!! FGC2_ ST_FAULTS COL", dsDpe[i]);
            bBadColor |=true;
            }
          }
        else
          {
          if(diValue[i][1] != 1)
            {
            unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl FGC Circuit_CB:"+$sCircuit+","+$sInterlockType, "!!!!! FGC2_ ST_GTWDEV COL", dsDpe[i]);
            bWarningLetter |=true;
            }
          }
        break;
      case "GW_FGC":
        // GW_FGC: FGC offline animate warningtext
        unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl FGC Circuit_CB:"+$sCircuit+","+$sInterlockType, "Circuit_CB check GW_FGC", $sCircuit, g_iFGC_MASK);
        if((diValue[i][1] & g_iFGC_MASK) == 0) {
          unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl FGC Circuit_CB:"+$sCircuit+","+$sInterlockType, "!!!!! GWFG_ WAR", dsDpe[i], diValue[i][1], g_iFGC_MASK);
          bWarningLetter |=true;
        }
        break;
      case "_UnSystemAlarm":
        // systemAlarm enable/alarm animate warningtext
        unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl FGC, QPS,PIC Circuit_CB:"+$sCircuit+","+$sInterlockType, "Circuit_CB check _UnSystemAlarm", $sCircuit);
        if(strpos(dsDpe[i], ".enabled") > 0) {
          if(diValue[i][1] != 1) {
            unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl FGC, QPS,PIC Circuit_CB:"+$sCircuit+","+$sInterlockType, "!!!!! AL_EN WAR", dsDpe[i]);
            bWarningLetter |=true;
          }
        }
        else {
          if(diValue[i][1] != 0) {
            unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl FGC, QPS,PIC Circuit_CB:"+$sCircuit+","+$sInterlockType, "!!!!! AL_AL WAR", dsDpe[i]);
            bWarningLetter |=true;
          }
        }
        break;
      default:
        DebugN("unLHCCircuit_CircuitWidget_CB - unknown device type", dsDpe[i], dpTypeName(dpSubStr(dsDpe[i], DPSUB_SYS_DP)));    
        // unknown device type: animate bodycolor and warningtext
        unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl Circuit_CB:"+$sCircuit+","+$sInterlockType, "!!!!! UNKNO !!!", dpTypeName(dpSubStr(dsDpe[i], DPSUB_SYS_DP)), dsDpe[i]);
        bBadColor |=true;
        bWarningLetter |= true;
        break;
    }
  }
  // lock the global var, and animate the widget
  synchronized(g_mbBadColor)
  {
    g_mbWarningLetter[sSystem] = bWarningLetter;
    g_mbBadColor[sSystem] = bBadColor;
    unLHCCircuit_CircuitWidget_setWidgetState();
  }
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_CBCheckDQGROUPContent
/**
Purpose:
If the DPe value of the DQGROUP contains one Id of the list of device associated to the circuit --> bad

  @param sDQGROUP: string, input: the DQGROUP
  @param diValue: dyn_int, input: the DQGROUP value

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
bool unLHCCircuit_CircuitWidget_CBCheckDQGROUPContent(string sDQGROUP, dyn_int diValue)
{
  bool bBad=true;
  dyn_int di, diRes;
  
  if(mappingHasKey(g_mDQGROUPId, sDQGROUP)) {
    di = g_mDQGROUPId[sDQGROUP];
    diRes = dynIntersect(diValue, di);
    if(dynlen(diRes) <= 0)
      bBad = false;
  }
  if(bBad) {
    unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT1, "unCIRCUITWidget.pnl CBCheckDQGROUPContent:"+$sCircuit+","+$sInterlockType, "!!!!! DGRP COL", sDQGROUP/*, g_mDQGROUPId, diValue*/);
  }
  return bBad;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_setWidgetState
/**
Purpose:
Set the widget state bodycolor and warningtext

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_setWidgetState()
{
  string sWarningColor="green", sBodyColor="green", sWarningText;
  bool bBadColor, bWarningLetter;
  int i, len=mappinglen(g_mbBadColor);
  bool bOk;
  
  //DebugN(g_mbBadColor, g_mbWarningLetter);
  bOk = unLHCCircuit_CircuitWidget_checkSystemList($sCircuit, $sInterlockType);
  if(bOk)
  {
    // get the bodycolor and warningtext of all the system involded in the circuit
    for(i=1;i<=len;i++) {
      switch(mappingGetKey(g_mbBadColor, i))
      {
        case "LHC_CIRCUIT:":
          if(!g_bSuperLock)
          {
            bBadColor |= mappingGetValue(g_mbBadColor, i);
            bWarningLetter |= mappingGetValue(g_mbWarningLetter, i);
          }
          break;
        case "pic_1:":
          if(!g_bSuperLock)
          {
            bBadColor |= mappingGetValue(g_mbBadColor, i);
          }
          bWarningLetter |= mappingGetValue(g_mbWarningLetter, i);
          break;
        default:
          bBadColor |= mappingGetValue(g_mbBadColor, i);
          bWarningLetter |= mappingGetValue(g_mbWarningLetter, i);
          break;
      }
    }
    
    if(bWarningLetter) {
      sWarningText = "o";
      sWarningColor = "cyan";
      sBodyColor = "cyan";
    }
    else if(bBadColor) {
      sWarningColor = "red";
      sBodyColor = "red";
    }
    unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl setWidgetState:"+$sCircuit+","+$sInterlockType, "setWidgetState", $sCircuit, bWarningLetter, g_mbWarningLetter, bBadColor, g_mbBadColor, g_bSuperLock);
    unLHCCircuit_CircuitWidget_setWidgetAnimationColor(sBodyColor, sWarningText, g_bSuperLock);
  }
  else
  {
    unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl setWidgetState:"+$sCircuit+","+$sInterlockType, "setWidgetState", $sCircuit, "missing system", len);
    unLHCCircuit_CircuitWidget_setDisconnection();
  }
}

//------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_CircuitWidget_checkSystemList
/** Check if the number of system is correct
  
@par Constraints
  None

@par Usage
  Public

@par PVSS managers
  Ui

@param sCircuit  input, the circuit name
@param sCircuitInterlockType  input, the interlock type of the circuit
@return true=OK/false=BAD
*/
bool unLHCCircuit_CircuitWidget_checkSystemList(string sCircuit, string sCircuitInterlockType)
{
  int iLenQPS, iLenPIC, iLenPC;
  int i, len=mappinglen(g_mbBadColor);
  bool bOk;
  int iPos;
  string sInterlockType=sCircuitInterlockType;
  
  iPos=dynContains(g_dsCircuitException, sCircuit);
  if (iPos>0)
  {
    sInterlockType=g_dsInterlockTypeException[iPos];
    unGenericDpFunctions_debugN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl checkSystemList:"+sCircuit+","+sCircuitInterlockType,  "checkSystemList:"+sCircuit+","+sCircuitInterlockType+","+sInterlockType);
  }
  switch(sInterlockType)
  {
    case CIRCUIT_A:
      if((strpos(sCircuit, "RB.A") == 0) || (strpos(sCircuit, "RQD.A") == 0) || (strpos(sCircuit, "RQF.A") == 0))
        bOk = (len == LHC_CIRCUIT_PVSS_SYSTEMS_NQPS);
      else
        bOk = (len == LHC_CIRCUIT_PVSS_SYSTEMS);
      break;
    case CIRCUIT_B1:
    case CIRCUIT_B2:
      bOk = (len == LHC_CIRCUIT_PVSS_SYSTEMS);
      break;
    case CIRCUIT_C:
      bOk = (len == 2);
      break;
    case CIRCUIT_D:
      bOk = (len == 1);
      break;
    default:
      break;
  }
  return bOk;
}
//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_GetDpe
/**
Purpose:
Get all the device DPE involded in the circuit and the FGC mask

  @param mDeviceDp: mapping, input: List of device DP per system
  @param mDeviceType: mapping, input: List of device type per system
  @param mdsDeviceDpe: mapping, output: List of device DPE per system
  @param iFGC_MASK: int, output: FGC mask

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
bool unLHCCircuit_CircuitWidget_GetDpe(mapping mDeviceDp, mapping mDeviceType, mapping &mdsDeviceDpe, int &iFGC_MASK)
{
  int i, len=mappinglen(mDeviceDp);
  mapping m;
  dyn_string ds, dsDpe, dsType;
  bool bOk=true;
  
  mdsDeviceDpe = m;
  
  for(i=1;(i<=len)&bOk;i++) {
    ds = mappingGetValue(mDeviceDp, i);
    dsType = mappingGetValue(mDeviceType, i);
    dynClear(dsDpe);
    if(g_m_bTreeDeviceOverviewSystemConnected[mappingGetKey(mDeviceDp, i)]) {
      bOk = unLHCCircuit_CircuitWidget_GetDpeSystem(ds, dsType, dsDpe, iFGC_MASK);
      if(!bOk)
        dynClear(dsDpe);
      else if(dynlen(dsDpe) > 0)
        mdsDeviceDpe[mappingGetKey(mDeviceDp, i)] = dsDpe;
    }
  }
  return bOk;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_GetDpeSystem
/**
Purpose:
Get for one system the device DPE involded in the circuit and the FGC mask

  @param dsCircuitDeviceDp: dyn_string, input: List of device DP
  @param dsDeviceType: dyn_string, input: List of device type 
  @param dsCircuitDeviceDpe: dyn_string, output: List of device DPE
  @param iFGC_MASK: int, output: FGC mask

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
bool unLHCCircuit_CircuitWidget_GetDpeSystem(dyn_string dsCircuitDeviceDp, dyn_string dsDeviceType, dyn_string &dsCircuitDeviceDpe,
                               int &iFGC_MASK)
{
  int i, len=dynlen(dsCircuitDeviceDp);
  string sFrontEnd, sSystem, sFEApplication;
  bool bOk=true;
  dyn_string dsId;
  int iBitPosFGC, iWFFGC;
  bit32 b32 = iFGC_MASK;
  dyn_int diId;
  
  for(i=1;(i<=len) & bOk;i++) {
    // get FE DPE
    sFrontEnd = unGenericObject_GetPLCNameFromDpName(dsCircuitDeviceDp[i]);
    sSystem = unGenericDpFunctions_getSystemName(dsCircuitDeviceDp[i]);
    if(sFrontEnd != "")
    {
      if (!dpExists(sSystem+c_unSystemAlarm_dpPattern+PLC_DS_pattern+sFrontEnd))
      {
        bOk = false;
        unGenericDpFunctions_debugN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl GetDpeSystem:"+$sCircuit+","+$sInterlockType, "GetDpeSystem: Dpe doesn't exist " + sSystem+c_unSystemAlarm_dpPattern+PLC_DS_pattern+sFrontEnd, dsCircuitDeviceDp[i]);
      }
      else {
        dynAppend(dsCircuitDeviceDpe, sSystem+c_unSystemAlarm_dpPattern+PLC_DS_pattern+sFrontEnd+".alarm");
        dynAppend(dsCircuitDeviceDpe, sSystem+c_unSystemAlarm_dpPattern+PLC_DS_pattern+sFrontEnd+".enabled");
        if(!dpExists(sSystem + sFrontEnd)) {
          unGenericDpFunctions_debugN(DEBUG_ONLY_BIT0, "unCIRCUITWidget.pnl GetDpeSystem:"+$sCircuit+","+$sInterlockType, "GetDpeSystem: Dpe doesn't exist " + sSystem + sFrontEnd, dsCircuitDeviceDp[i]);
        }
      }
    }
    else
      bOk = false;
    if(bOk) 
    {
    // get DPE
      switch(dsDeviceType[i]) {
        case "DQGROUP":
          dynAppend(dsCircuitDeviceDpe, dsCircuitDeviceDp[i]+ ".ProcessInput.ST_OK");
          dynAppend(dsCircuitDeviceDpe, dsCircuitDeviceDp[i]+ ".ProcessInput.ST_PWR_PERM");
          dynAppend(dsCircuitDeviceDpe, dsCircuitDeviceDp[i]+ ".ProcessInput.ST_LOGGING");
          dynAppend(dsCircuitDeviceDpe, dsCircuitDeviceDp[i]+ ".ProcessInput.ST_FIP");
          dynAppend(dsCircuitDeviceDpe, dsCircuitDeviceDp[i]+ ".ProcessInput.ST_FIP_DRV");
          break;
        case "FGC2_LHC_PC":
          dynAppend(dsCircuitDeviceDpe, dsCircuitDeviceDp[i]+ ".ProcessInput.ST_FAULTS");
          dynAppend(dsCircuitDeviceDpe, dsCircuitDeviceDp[i]+ ".ProcessInput.ST_GTWDEV");
          // get the FGC_mask
          pcFGC2_LHC_PC_getConfig(dsCircuitDeviceDp[i], sFrontEnd, sFEApplication, iBitPosFGC, iWFFGC);
          setBit(b32, iBitPosFGC, true);
          break;
        case "CIPC":
          unLHCCircuit_PIC_getCircuitsPICId(sSystem, dsCircuitDeviceDp[i], $sCircuit, $sInterlockType, dsId);
          dynAppend(dsCircuitDeviceDpe,dsId);
          unGenericDpFunctions_debugN(DEBUG_ONLY_BIT4, "unCIRCUITWidget.pnl GetDpeSystem:"+$sCircuit+","+$sInterlockType, "!!!!GetDpeSystem", dsId);
          break;
      }
    }
  }
  iFGC_MASK = b32;
  unGenericDpFunctions_debugN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl GetDpeSystem:"+$sCircuit+","+$sInterlockType, "!!!!GetDpeSystem", b32, iFGC_MASK);
  dynUnique(dsCircuitDeviceDpe);
  return bOk;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_ReOrganiseDevice
/**
Purpose:
Remove all the QPS device and add the appropriate DQGROUP

  @param sCircuit: string, intput: the circuit
  @param dsCircuitDeviceDp: dyn_string, output: List of device DP
  @param dsCircuitDeviceAlias: dyn_string, output: List of device DP
  @param dsCircuitDeviceType: dyn_string, output: List of device type 
  @param mDeviceIdentifier: mapping, output: list of device identifer per system
  @param mDeviceType: mapping, output: list of device type per system
  @param mDQGROUPId: mapping, output: list of QPS device ID per DQGROUP

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_ReOrganiseDevice(string sCircuit, dyn_string &dsCircuitDeviceDp, dyn_string &dsCircuitDeviceAlias, dyn_string &dsCircuitDeviceType,
                              mapping &mDeviceIdentifier, mapping &mDeviceType, mapping &mDQGROUPId)
{
  dyn_string dsRetCircuitDeviceDp, dsRetCircuitDeviceAlias, dsRetCircuitDeviceType;
  int i, len;
  string sLink;
  bool bAdd, bQPS;
  mapping mTemp = mDQGROUPId;
  
  unGenericDpFunctions_debugN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl ReOrganiseDevice:"+$sCircuit+","+$sInterlockType, "ReOrganiseDevice", sCircuit, strpos(sCircuit, "RB.A"));
  
  len = dynlen(dsCircuitDeviceDp); 
  for(i=1;i<=len;i++) {
    bQPS = false;
    bAdd = unLHCCircuit_CircuitWidget_allowedDeviceType(dsCircuitDeviceType[i], bQPS);
    if(bAdd) {
      if(bQPS) {
// get link
        sLink = unLHCCircuit_CircuitWidget_getQPSCircuitDeviceLink(sCircuit, dsCircuitDeviceDp[i]);
        sLink = unGenericDpFunctions_getSystemName(dsCircuitDeviceDp[i])+sLink;
        unGenericDpFunctions_debugN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl ReOrganiseDevice:"+$sCircuit+","+$sInterlockType, sCircuit, "get link", sLink, dynContains(dsRetCircuitDeviceDp, sLink));
        if(sLink != "") {
          unLHCCircuit_CircuitWidget_addIdInDQGROUP(mTemp, unGenericDpFunctions_getDpName(dpAliasToName(sLink)), dsCircuitDeviceDp[i]);
          if(dynContains(dsRetCircuitDeviceAlias, sLink) <= 0) {
            unGenericDpFunctions_debugN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl ReOrganiseDevice:"+$sCircuit+","+$sInterlockType, sCircuit, "add link", sLink, dynContains(dsRetCircuitDeviceAlias, sLink), dpAliasToName(sLink));
            dynAppend(dsRetCircuitDeviceDp, unGenericDpFunctions_getDpName(dpAliasToName(sLink)));
            dynAppend(dsRetCircuitDeviceAlias, sLink);
            dynAppend(dsRetCircuitDeviceType, "DQGROUP");
            unLHCCircuit_CircuitWidget_addInMapping(mDeviceIdentifier, unGenericDpFunctions_getDpName(dpAliasToName(sLink)), unGenericDpFunctions_getSystemName(dsCircuitDeviceDp[i]));
            unLHCCircuit_CircuitWidget_addInMapping(mDeviceType, "DQGROUP", unGenericDpFunctions_getSystemName(dsCircuitDeviceDp[i]));
          }
        }
      }
      else {
        dynAppend(dsRetCircuitDeviceDp, dsCircuitDeviceDp[i]);
        dynAppend(dsRetCircuitDeviceAlias, unGenericDpFunctions_getSystemName(dsCircuitDeviceDp[i])+dsCircuitDeviceAlias[i]);
        dynAppend(dsRetCircuitDeviceType, dsCircuitDeviceType[i]);
        unLHCCircuit_CircuitWidget_addInMapping(mDeviceIdentifier, dsCircuitDeviceDp[i], unGenericDpFunctions_getSystemName(dsCircuitDeviceDp[i]));
        unLHCCircuit_CircuitWidget_addInMapping(mDeviceType, dsCircuitDeviceType[i], unGenericDpFunctions_getSystemName(dsCircuitDeviceDp[i]));
      }
    }
  }
  dsCircuitDeviceDp = dsRetCircuitDeviceDp;
  dsCircuitDeviceAlias = dsRetCircuitDeviceAlias;
  dsCircuitDeviceType = dsRetCircuitDeviceType;
  mDQGROUPId = mTemp;
  
  unGenericDpFunctions_debugN(DEBUG_ONLY_BIT2, "unCIRCUITWidget.pnl ReOrganiseDevice:"+$sCircuit+","+$sInterlockType, "ReOrganiseDevice:", sCircuit, dsRetCircuitDeviceDp, dsRetCircuitDeviceAlias, dsRetCircuitDeviceType);
}

string unLHCCircuit_CircuitWidget_getQPSCircuitDeviceLink(string sCircuit, string sCircuitDeviceDp)
{
  string sLink, sCircruitLink;
  dyn_string dsTempLink;
  int i, len;
  
  unGenericDpFunctions_getDeviceLink(sCircuitDeviceDp, sLink);
  if(strpos(sLink, UN_CONFIG_GROUP_SEPARATOR)>0)
  {
    dsTempLink = strsplit(sLink, UN_CONFIG_GROUP_SEPARATOR);
    len = dynlen(dsTempLink);
    for(i=1;i<=len;i++)
    {
      if(strpos(dsTempLink[i], sCircuit)>0)
      {
        sCircruitLink = dsTempLink[i];
        i = len+1;
      }
    }
  }
  else
    sCircruitLink = sLink;
  
  return sCircruitLink;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_addIdInDQGROUP
/**
Purpose:
Remove all the QPS device and add the appropriate DQGROUP

  @param mId: dyn_string, output: add the sDeviceDp ID in the DQGROUP
  @param sDQGROUP: dyn_string, input: the DQGROUP
  @param sDeviceDp: input, output: the device dp 

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_addIdInDQGROUP(mapping &mId, string sDQGROUP, string sDeviceDp)
{
  string sLink;
  dyn_string dsAlias;
  dyn_int diTempDeviceId;
  int i, len;
  string sFrontEnd, sFEApplication;
  int iWorldFip, iMezzanine, iCircuitNumber;
  
  if(mappingHasKey(mId, sDQGROUP))
    diTempDeviceId = mId[sDQGROUP];
  
  qpsGenericFunctions_getDQAMxParams(sDeviceDp, sFrontEnd, sFEApplication, iWorldFip, iMezzanine, iCircuitNumber);
  dynAppend(diTempDeviceId, iMezzanine*10000 + iWorldFip*10 + iCircuitNumber);
  dynUnique(diTempDeviceId);
  mId[sDQGROUP] = diTempDeviceId;
  unGenericDpFunctions_debugN(DEBUG_ONLY_BIT3, "unCIRCUITWidget.pnl addIdInDQGROUP:"+$sCircuit+","+$sInterlockType, "!!!!!!!addIdInDQGROUP", sDQGROUP, sDeviceDp/*, diTempDeviceId*/);
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_allowedDeviceType
/**
Purpose:
Check if the device is allowed and if of type QPS

  @param sCircuitDeviceType: string, input: the device type
  @param bQPS: bool, output: true=QPS device/false if not QPS device

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
bool unLHCCircuit_CircuitWidget_allowedDeviceType(string sCircuitDeviceType, bool &bQPS)
{
  bool bOk;
  switch(sCircuitDeviceType)
  {
    case "FGC2_LHC_PC":
    case "CIPC":
      bOk = true;
      bQPS = false;
      break;
    case "DQAMCNMB":
    case "DQAMCNMQ":
    case "DQAMGNA":
    case "DQAMGNC":
    case "DQAMGNDRB_EVEN":
    case "DQAMGNDRB_ODD":
    case "DQAMGNDRQ":
    case "DQAMGNRD":
    case "DQAMGNRQA":
    case "DQAMGNRQB":
    case "DQAMGNRQC":
    case "DQAMSN600":
    case "DQAMSNRB":
    case "DQAMSNQ":
    case "DQQLC_NEVEN":
    case "DQQLC_NODD": 
    case "DQAMGNSRB":
    case "DQAMGNSRQF":
    case "DQAMGNSRQD":      
      bOk = true;
      bQPS = true;
      break;
    
    /*default:
      DebugN("unLHCCircuit_CircuitWidget_allowedDeviceType", sCircuitDeviceType);*/  
  }
  return bOk;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_CircuitWidget_addInMapping
/**
Purpose:
Add sId for the sKey of the mapping m 

  @param m: mapping, output: the mapping
  @param sId: string, input: the data to add
  @param sKey: string, input: the key

Usage: Public

PVSS manager usage: PVSS00ui

Constraints:
  . PVSS version: 3.6 
  . PVSS manager type: PVSS00ui
  . operating system: WXP, Linux.
  . distributed system: yes.
*/
void unLHCCircuit_CircuitWidget_addInMapping(mapping &m, string sId, string sKey)
{
  dyn_string ds;
  
  if(mappingHasKey(m, sKey))
    ds = m[sKey];
  dynAppend(ds, sId);
  m[sKey] = ds;
}

//@}
