/**@file

// unLHCCircuit_PC.ctl
This library contains the functions to manage the FGC used in the subsector widget in the LHCCircuit.

@par Creation Date
  24/09/2007

@par Modification History
  26/04/2011: Herve
  - CIR-23: Powering sub-sector and circuit widget: use PIC superlock for the animation

@par Constraints
  None

@par Usage
  Public

@par PVSS managers
  Ui

@author 
  Frederic BERNARD (AB/CO-IS)
*/

/**
* @name LHCCircuit Power Converters functions
This is a set of functions provided to manage Power Converters data in LHCCircuit
* @{
*/

//------------------------------------------------------------------------------------------------------------------------
//		FGC CB FUNCTIONS
/** FGC2_LHC_PC_widgetCB_1_1
*/
void unLHCCircuit_FGC2_LHC_PC_widgetCB_1_1(	string sDpFEAl, int iFEAlValue, string sDpFEEnabled, bool bFEEnabled,
																												string sDpFGCMask, bit32 iMask,
																												string sDevice1, int iFault, string sDpGTWDEV, bool bGTW)
{
int iBitPos, iWF;
string sFE, sAppl;
bool bMask; 

	pcFGC2_LHC_PC_getConfig(sDevice1, sFE, sAppl, iBitPos, iWF);
	bMask=getBit(iMask, iBitPos);
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
    unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), iFEAlValue, bFEEnabled & bGTW & bMask);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_2_1
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_2_1(  string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1, string sDpFGCMask, bit32 iMask,
                                        string sDevice1, int iFault1,
                                        string sDpGTWDEV1, bool bGTW1,
                                        string sDevice2, int iFault2,
                                        string sDpGTWDEV2, bool bGTW2)
{
int iBitPos, iWF;
string sFE, sAppl;
dyn_int diFEValue;
bool bMask; 
 	
	pcFGC2_LHC_PC_getConfig(sDevice1, sFE, sAppl, iBitPos, iWF);
	bMask=getBit(iMask, iBitPos);
	diFEValue=makeDynInt(iFEAlValue1);
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
	
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1 & bGTW1 & bGTW2 & bMask);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_3_1
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_3_1(	string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1, 
                                        string sDpFGCMask, bit32 iMask,
                                        string sDevice1, int iFault1,
                                        string sDpGTWDEV1, bool bGTW1,
                                        string sDevice2, int iFault2,
                                        string sDpGTWDEV5, bool bGTW2,
                                        string sDevice3, int iFault3,
                                        string sDpGTWDEV3, bool bGTW3)
{
int iBitPos, iWF;
string sFE, sAppl;
dyn_int diFEValue;
bool bMask; 
 	
	pcFGC2_LHC_PC_getConfig(sDevice1, sFE, sAppl, iBitPos, iWF);
	bMask=getBit(iMask, iBitPos);
	
	diFEValue=makeDynInt(iFEAlValue1);
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1 & bGTW1 & bGTW2 & bGTW3 & bMask);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_11_1
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_11_1(string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																												string sDevice1, int iFault1, string sDevice2, int iFault2,
																												string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																												string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																												string sDevice11, int iFault11)
{
int iFault;
dyn_int diFEValue;

	diFEValue=makeDynInt(iFEAlValue1);

	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1, false);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_15_1
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_15_1(string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																												string sDevice1, int iFault1, string sDevice2, int iFault2,
																												string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																												string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																												string sDevice11, int iFault11, string sDevice12, int iFault12, string sDevice13, int iFault13, string sDevice14, int iFault14,
																												string sDevice15, int iFault15)
{
int iFault;
dyn_int diFEValue;

	diFEValue=makeDynInt(iFEAlValue1);

	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11+iFault12+iFault13+iFault14+iFault15;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    g_diFGCFault[12] = iFault12;
    g_diFGCFault[13] = iFault13;
    g_diFGCFault[14] = iFault14;
    g_diFGCFault[15] = iFault15;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_16_1
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_16_1(string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																												string sDevice1, int iFault1, string sDevice2, int iFault2,
																												string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																												string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																												string sDevice11, int iFault11, string sDevice12, int iFault12, string sDevice13, int iFault13, string sDevice14, int iFault14,
																												string sDevice15, int iFault15, string sDevice16, int iFault16)
{
int iFault;
dyn_int diFEValue;

	diFEValue=makeDynInt(iFEAlValue1);

	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11+iFault12+iFault13+iFault14+iFault15+iFault16;
		
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    g_diFGCFault[12] = iFault12;
    g_diFGCFault[13] = iFault13;
    g_diFGCFault[14] = iFault14;
    g_diFGCFault[15] = iFault15;
    g_diFGCFault[16] = iFault16;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_8_2
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_8_2(string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																												string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
																												string sDevice1, int iFault1, string sDevice2, int iFault2,
																												string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																												string sDevice7, int iFault7, string sDevice8, int iFault8)
{
int iFault;
dyn_int diFEValue;

	diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2);
		
	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1&bFEEnabled2);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_17_2
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_17_2(string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																												string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
																												string sDevice1, int iFault1, string sDevice2, int iFault2,
																												string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																												string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																												string sDevice11, int iFault11, string sDevice12, int iFault12, string sDevice13, int iFault13, string sDevice14, int iFault14,
																												string sDevice15, int iFault15, string sDevice16, int iFault16, string sDevice17, int iFault17)
{
int iFault;
dyn_int diFEValue;

	diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2);
		
	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11+iFault12+iFault13+iFault14+iFault15+iFault16+iFault17;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    g_diFGCFault[12] = iFault12;
    g_diFGCFault[13] = iFault13;
    g_diFGCFault[14] = iFault14;
    g_diFGCFault[15] = iFault15;
    g_diFGCFault[16] = iFault16;
    g_diFGCFault[17] = iFault17;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1&bFEEnabled2);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_78_4
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_78_4(	string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																													string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
																													string sDpFEAl3, int iFEAlValue3, string sDpFEEnabled3, bool bFEEnabled3,
																													string sDpFEAl4, int iFEAlValue4, string sDpFEEnabled4, bool bFEEnabled4,
																													string sDevice1, int iFault1, string sDevice2, int iFault2,
																													string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																													string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																													string sDevice11, int iFault11, string sDevice12, int iFault12, string sDevice13, int iFault13, string sDevice14, int iFault14,
																													string sDevice15, int iFault15, string sDevice16, int iFault16, string sDevice17, int iFault17, string sDevice18, int iFault18,
																													string sDevice19, int iFault19, string sDevice20, int iFault20, string sDevice21, int iFault21, string sDevice22, int iFault22,
																													string sDevice23, int iFault23, string sDevice24, int iFault24, string sDevice25, int iFault25, string sDevice26, int iFault26,
																													string sDevice27, int iFault27, string sDevice28, int iFault28, string sDevice29, int iFault29, string sDevice30, int iFault30,
																													string sDevice31, int iFault31, string sDevice32, int iFault32, string sDevice33, int iFault33, string sDevice34, int iFault34,
																													string sDevice35, int iFault35, string sDevice36, int iFault36, string sDevice37, int iFault37, string sDevice38, int iFault38,
																													string sDevice39, int iFault39, string sDevice40, int iFault40, string sDevice41, int iFault41, string sDevice42, int iFault42,
																													string sDevice43, int iFault43, string sDevice44, int iFault44, string sDevice45, int iFault45, string sDevice46, int iFault46,
																													string sDevice47, int iFault47, string sDevice48, int iFault48, string sDevice49, int iFault49, string sDevice50, int iFault50,
																													string sDevice51, int iFault51, string sDevice52, int iFault52, string sDevice53, int iFault53, string sDevice54, int iFault54,
																													string sDevice55, int iFault55, string sDevice56, int iFault56, string sDevice57, int iFault57, string sDevice58, int iFault58,
																													string sDevice59, int iFault59, string sDevice60, int iFault60, string sDevice61, int iFault61, string sDevice62, int iFault62,
																													string sDevice63, int iFault63, string sDevice64, int iFault64, string sDevice65, int iFault65, string sDevice66, int iFault66,
																													string sDevice67, int iFault67, string sDevice68, int iFault68, string sDevice69, int iFault69, string sDevice70, int iFault70,
																													string sDevice71, int iFault71, string sDevice72, int iFault72, string sDevice73, int iFault73, string sDevice74, int iFault74,
																													string sDevice75, int iFault75, string sDevice76, int iFault76, string sDevice77, int iFault77, string sDevice78, int iFault78)
{
int iFault;
dyn_int diFEValue;
	
	diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2, iFEAlValue3, iFEAlValue4);

	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11+iFault12+iFault13+iFault14+iFault15+iFault16+iFault17+iFault18+iFault19+iFault20+
					iFault21+iFault22+iFault23+iFault24+iFault25+iFault26+iFault27+iFault28+iFault29+iFault30+
					iFault31+iFault32+iFault33+iFault34+iFault35+iFault36+iFault37+iFault38+iFault39+iFault40+
					iFault41+iFault42+iFault43+iFault44+iFault45+iFault46+iFault47+iFault48+iFault49+iFault50+
					iFault51+iFault52+iFault53+iFault54+iFault55+iFault56+iFault57+iFault58+iFault59+iFault60+
					iFault61+iFault62+iFault63+iFault64+iFault65+iFault66+iFault67+iFault68+iFault69+iFault70+
					iFault71+iFault72+iFault73+iFault74+iFault75+iFault76+iFault77+iFault78;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    g_diFGCFault[12] = iFault12;
    g_diFGCFault[13] = iFault13;
    g_diFGCFault[14] = iFault14;
    g_diFGCFault[15] = iFault15;
    g_diFGCFault[16] = iFault16;
    g_diFGCFault[17] = iFault17;
    g_diFGCFault[18] = iFault18;
    g_diFGCFault[19] = iFault19;
    g_diFGCFault[20] = iFault20;
    g_diFGCFault[21] = iFault21;
    g_diFGCFault[22] = iFault22;
    g_diFGCFault[23] = iFault23;
    g_diFGCFault[24] = iFault24;
    g_diFGCFault[25] = iFault25;
    g_diFGCFault[26] = iFault26;
    g_diFGCFault[27] = iFault27;
    g_diFGCFault[28] = iFault28;
    g_diFGCFault[29] = iFault29;
    g_diFGCFault[30] = iFault30;
    g_diFGCFault[31] = iFault31;
    g_diFGCFault[32] = iFault32;
    g_diFGCFault[33] = iFault33;
    g_diFGCFault[34] = iFault34;
    g_diFGCFault[35] = iFault35;
    g_diFGCFault[36] = iFault36;
    g_diFGCFault[37] = iFault37;
    g_diFGCFault[38] = iFault38;
    g_diFGCFault[39] = iFault39;
    g_diFGCFault[40] = iFault40;
    g_diFGCFault[41] = iFault41;
    g_diFGCFault[42] = iFault42;
    g_diFGCFault[43] = iFault43;
    g_diFGCFault[44] = iFault44;
    g_diFGCFault[45] = iFault45;
    g_diFGCFault[46] = iFault46;
    g_diFGCFault[47] = iFault47;
    g_diFGCFault[48] = iFault48;
    g_diFGCFault[49] = iFault49;
    g_diFGCFault[50] = iFault50;
    g_diFGCFault[51] = iFault51;
    g_diFGCFault[52] = iFault52;
    g_diFGCFault[53] = iFault53;
    g_diFGCFault[54] = iFault54;
    g_diFGCFault[55] = iFault55;
    g_diFGCFault[56] = iFault56;
    g_diFGCFault[57] = iFault57;
    g_diFGCFault[58] = iFault58;
    g_diFGCFault[59] = iFault59;
    g_diFGCFault[60] = iFault60;
    g_diFGCFault[61] = iFault61;
    g_diFGCFault[62] = iFault62;
    g_diFGCFault[63] = iFault63;
    g_diFGCFault[64] = iFault64;
    g_diFGCFault[65] = iFault65;
    g_diFGCFault[66] = iFault66;
    g_diFGCFault[67] = iFault67;
    g_diFGCFault[68] = iFault68;
    g_diFGCFault[69] = iFault69;
    g_diFGCFault[70] = iFault70;
    g_diFGCFault[71] = iFault71;
    g_diFGCFault[72] = iFault72;
    g_diFGCFault[73] = iFault73;
    g_diFGCFault[74] = iFault74;
    g_diFGCFault[75] = iFault75;
    g_diFGCFault[76] = iFault76;
    g_diFGCFault[77] = iFault77;
    g_diFGCFault[78] = iFault78;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1 & bFEEnabled2 & bFEEnabled3 & bFEEnabled4);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_82_4
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_82_4(	string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																													string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
																													string sDpFEAl3, int iFEAlValue3, string sDpFEEnabled3, bool bFEEnabled3,
																													string sDpFEAl4, int iFEAlValue4, string sDpFEEnabled4, bool bFEEnabled4,
																													string sDevice1, int iFault1, string sDevice2, int iFault2,
																													string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																													string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																													string sDevice11, int iFault11, string sDevice12, int iFault12, string sDevice13, int iFault13, string sDevice14, int iFault14,
																													string sDevice15, int iFault15, string sDevice16, int iFault16, string sDevice17, int iFault17, string sDevice18, int iFault18,
																													string sDevice19, int iFault19, string sDevice20, int iFault20, string sDevice21, int iFault21, string sDevice22, int iFault22,
																													string sDevice23, int iFault23, string sDevice24, int iFault24, string sDevice25, int iFault25, string sDevice26, int iFault26,
																													string sDevice27, int iFault27, string sDevice28, int iFault28, string sDevice29, int iFault29, string sDevice30, int iFault30,
																													string sDevice31, int iFault31, string sDevice32, int iFault32, string sDevice33, int iFault33, string sDevice34, int iFault34,
																													string sDevice35, int iFault35, string sDevice36, int iFault36, string sDevice37, int iFault37, string sDevice38, int iFault38,
																													string sDevice39, int iFault39, string sDevice40, int iFault40, string sDevice41, int iFault41, string sDevice42, int iFault42,
																													string sDevice43, int iFault43, string sDevice44, int iFault44, string sDevice45, int iFault45, string sDevice46, int iFault46,
																													string sDevice47, int iFault47, string sDevice48, int iFault48, string sDevice49, int iFault49, string sDevice50, int iFault50,
																													string sDevice51, int iFault51, string sDevice52, int iFault52, string sDevice53, int iFault53, string sDevice54, int iFault54,
																													string sDevice55, int iFault55, string sDevice56, int iFault56, string sDevice57, int iFault57, string sDevice58, int iFault58,
																													string sDevice59, int iFault59, string sDevice60, int iFault60, string sDevice61, int iFault61, string sDevice62, int iFault62,
																													string sDevice63, int iFault63, string sDevice64, int iFault64, string sDevice65, int iFault65, string sDevice66, int iFault66,
																													string sDevice67, int iFault67, string sDevice68, int iFault68, string sDevice69, int iFault69, string sDevice70, int iFault70,
																													string sDevice71, int iFault71, string sDevice72, int iFault72, string sDevice73, int iFault73, string sDevice74, int iFault74,
																													string sDevice75, int iFault75, string sDevice76, int iFault76, string sDevice77, int iFault77, string sDevice78, int iFault78,
																													string sDevice79, int iFault79, string sDevice80, int iFault80, string sDevice81, int iFault81, string sDevice82, int iFault82)
{
int iFault;
dyn_int diFEValue;
	
	diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2, iFEAlValue3, iFEAlValue4);

	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11+iFault12+iFault13+iFault14+iFault15+iFault16+iFault17+iFault18+iFault19+iFault20+
					iFault21+iFault22+iFault23+iFault24+iFault25+iFault26+iFault27+iFault28+iFault29+iFault30+
					iFault31+iFault32+iFault33+iFault34+iFault35+iFault36+iFault37+iFault38+iFault39+iFault40+
					iFault41+iFault42+iFault43+iFault44+iFault45+iFault46+iFault47+iFault48+iFault49+iFault50+
					iFault51+iFault52+iFault53+iFault54+iFault55+iFault56+iFault57+iFault58+iFault59+iFault60+
					iFault61+iFault62+iFault63+iFault64+iFault65+iFault66+iFault67+iFault68+iFault69+iFault70+
					iFault71+iFault72+iFault73+iFault74+iFault75+iFault76+iFault77+iFault78+iFault79+iFault80+iFault81+iFault82;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    g_diFGCFault[12] = iFault12;
    g_diFGCFault[13] = iFault13;
    g_diFGCFault[14] = iFault14;
    g_diFGCFault[15] = iFault15;
    g_diFGCFault[16] = iFault16;
    g_diFGCFault[17] = iFault17;
    g_diFGCFault[18] = iFault18;
    g_diFGCFault[19] = iFault19;
    g_diFGCFault[20] = iFault20;
    g_diFGCFault[21] = iFault21;
    g_diFGCFault[22] = iFault22;
    g_diFGCFault[23] = iFault23;
    g_diFGCFault[24] = iFault24;
    g_diFGCFault[25] = iFault25;
    g_diFGCFault[26] = iFault26;
    g_diFGCFault[27] = iFault27;
    g_diFGCFault[28] = iFault28;
    g_diFGCFault[29] = iFault29;
    g_diFGCFault[30] = iFault30;
    g_diFGCFault[31] = iFault31;
    g_diFGCFault[32] = iFault32;
    g_diFGCFault[33] = iFault33;
    g_diFGCFault[34] = iFault34;
    g_diFGCFault[35] = iFault35;
    g_diFGCFault[36] = iFault36;
    g_diFGCFault[37] = iFault37;
    g_diFGCFault[38] = iFault38;
    g_diFGCFault[39] = iFault39;
    g_diFGCFault[40] = iFault40;
    g_diFGCFault[41] = iFault41;
    g_diFGCFault[42] = iFault42;
    g_diFGCFault[43] = iFault43;
    g_diFGCFault[44] = iFault44;
    g_diFGCFault[45] = iFault45;
    g_diFGCFault[46] = iFault46;
    g_diFGCFault[47] = iFault47;
    g_diFGCFault[48] = iFault48;
    g_diFGCFault[49] = iFault49;
    g_diFGCFault[50] = iFault50;
    g_diFGCFault[51] = iFault51;
    g_diFGCFault[52] = iFault52;
    g_diFGCFault[53] = iFault53;
    g_diFGCFault[54] = iFault54;
    g_diFGCFault[55] = iFault55;
    g_diFGCFault[56] = iFault56;
    g_diFGCFault[57] = iFault57;
    g_diFGCFault[58] = iFault58;
    g_diFGCFault[59] = iFault59;
    g_diFGCFault[60] = iFault60;
    g_diFGCFault[61] = iFault61;
    g_diFGCFault[62] = iFault62;
    g_diFGCFault[63] = iFault63;
    g_diFGCFault[64] = iFault64;
    g_diFGCFault[65] = iFault65;
    g_diFGCFault[66] = iFault66;
    g_diFGCFault[67] = iFault67;
    g_diFGCFault[68] = iFault68;
    g_diFGCFault[69] = iFault69;
    g_diFGCFault[70] = iFault70;
    g_diFGCFault[71] = iFault71;
    g_diFGCFault[72] = iFault72;
    g_diFGCFault[73] = iFault73;
    g_diFGCFault[74] = iFault74;
    g_diFGCFault[75] = iFault75;
    g_diFGCFault[76] = iFault76;
    g_diFGCFault[77] = iFault77;
    g_diFGCFault[78] = iFault78;
    g_diFGCFault[79] = iFault79;
    g_diFGCFault[80] = iFault80;
    g_diFGCFault[81] = iFault81;
    g_diFGCFault[82] = iFault82;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1 & bFEEnabled2 & bFEEnabled3 & bFEEnabled4);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_164_8
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_164_8(	string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																													string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
																													string sDpFEAl3, int iFEAlValue3, string sDpFEEnabled3, bool bFEEnabled3,
																													string sDpFEAl4, int iFEAlValue4, string sDpFEEnabled4, bool bFEEnabled4,
																													string sDpFEAl5, int iFEAlValue5, string sDpFEEnabled5, bool bFEEnabled5,
																													string sDpFEAl6, int iFEAlValue6, string sDpFEEnabled6, bool bFEEnabled6,
																													string sDpFEAl7, int iFEAlValue7, string sDpFEEnabled7, bool bFEEnabled7,
																													string sDpFEAl8, int iFEAlValue8, string sDpFEEnabled8, bool bFEEnabled8,
																													string sDevice1, int iFault1, string sDevice2, int iFault2,
																													string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																													string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																													string sDevice11, int iFault11, string sDevice12, int iFault12, string sDevice13, int iFault13, string sDevice14, int iFault14,
																													string sDevice15, int iFault15, string sDevice16, int iFault16, string sDevice17, int iFault17, string sDevice18, int iFault18,
																													string sDevice19, int iFault19, string sDevice20, int iFault20, string sDevice21, int iFault21, string sDevice22, int iFault22,
																													string sDevice23, int iFault23, string sDevice24, int iFault24, string sDevice25, int iFault25, string sDevice26, int iFault26,
																													string sDevice27, int iFault27, string sDevice28, int iFault28, string sDevice29, int iFault29, string sDevice30, int iFault30,
																													string sDevice31, int iFault31, string sDevice32, int iFault32, string sDevice33, int iFault33, string sDevice34, int iFault34,
																													string sDevice35, int iFault35, string sDevice36, int iFault36, string sDevice37, int iFault37, string sDevice38, int iFault38,
																													string sDevice39, int iFault39, string sDevice40, int iFault40, string sDevice41, int iFault41, string sDevice42, int iFault42,
																													string sDevice43, int iFault43, string sDevice44, int iFault44, string sDevice45, int iFault45, string sDevice46, int iFault46,
																													string sDevice47, int iFault47, string sDevice48, int iFault48, string sDevice49, int iFault49, string sDevice50, int iFault50,
																													string sDevice51, int iFault51, string sDevice52, int iFault52, string sDevice53, int iFault53, string sDevice54, int iFault54,
																													string sDevice55, int iFault55, string sDevice56, int iFault56, string sDevice57, int iFault57, string sDevice58, int iFault58,
																													string sDevice59, int iFault59, string sDevice60, int iFault60, string sDevice61, int iFault61, string sDevice62, int iFault62,
																													string sDevice63, int iFault63, string sDevice64, int iFault64, string sDevice65, int iFault65, string sDevice66, int iFault66,
																													string sDevice67, int iFault67, string sDevice68, int iFault68, string sDevice69, int iFault69, string sDevice70, int iFault70,
																													string sDevice71, int iFault71, string sDevice72, int iFault72, string sDevice73, int iFault73, string sDevice74, int iFault74,
																													string sDevice75, int iFault75, string sDevice76, int iFault76, string sDevice77, int iFault77, string sDevice78, int iFault78
																													, string sDevice79, int iFault79, string sDevice80, int iFault80, string sDevice81, int iFault81, string sDevice82, int iFault82
																													, string sDevice83, int iFault83, string sDevice84, int iFault84, string sDevice85, int iFault85, string sDevice86, int iFault86
																													, string sDevice87, int iFault87, string sDevice88, int iFault88, string sDevice89, int iFault89, string sDevice90, int iFault90
																													, string sDevice91, int iFault91, string sDevice92, int iFault92, string sDevice93, int iFault93, string sDevice94, int iFault94
																													, string sDevice95, int iFault95, string sDevice96, int iFault96, string sDevice97, int iFault97, string sDevice98, int iFault98
																													, string sDevice99, int iFault99, string sDevice100, int iFault100, string sDevice101, int iFault101, string sDevice102, int iFault102
																													, string sDevice103, int iFault103, string sDevice104, int iFault104, string sDevice105, int iFault105, string sDevice106, int iFault106
																													, string sDevice107, int iFault107, string sDevice108, int iFault108, string sDevice109, int iFault109, string sDevice110, int iFault110
																													, string sDevice111, int iFault111, string sDevice112, int iFault112, string sDevice113, int iFault113, string sDevice114, int iFault114
																													, string sDevice115, int iFault115, string sDevice116, int iFault116, string sDevice117, int iFault117, string sDevice118, int iFault118
																													, string sDevice119, int iFault119, string sDevice120, int iFault120, string sDevice121, int iFault121, string sDevice122, int iFault122
																													, string sDevice123, int iFault123, string sDevice124, int iFault124, string sDevice125, int iFault125, string sDevice126, int iFault126
																													, string sDevice127, int iFault127, string sDevice128, int iFault128, string sDevice129, int iFault129, string sDevice130, int iFault130
																													, string sDevice131, int iFault131, string sDevice132, int iFault132, string sDevice133, int iFault133, string sDevice134, int iFault134
																													, string sDevice135, int iFault135, string sDevice136, int iFault136, string sDevice137, int iFault137, string sDevice138, int iFault138
																													, string sDevice139, int iFault139, string sDevice140, int iFault140, string sDevice141, int iFault141, string sDevice142, int iFault142
																													, string sDevice143, int iFault143, string sDevice144, int iFault144, string sDevice145, int iFault145, string sDevice146, int iFault146
																													, string sDevice147, int iFault147, string sDevice148, int iFault148, string sDevice149, int iFault149, string sDevice150, int iFault150
																													, string sDevice151, int iFault151, string sDevice152, int iFault152, string sDevice153, int iFault153, string sDevice154, int iFault154
																													, string sDevice155, int iFault155, string sDevice156, int iFault156, string sDevice157, int iFault157, string sDevice158, int iFault158
																													, string sDevice159, int iFault159, string sDevice160, int iFault160, string sDevice161, int iFault161, string sDevice162, int iFault162
																													, string sDevice163, int iFault163, string sDevice164, int iFault164)
{
int iFault;
dyn_int diFEValue;
	
	diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2, iFEAlValue3, iFEAlValue4, iFEAlValue5, iFEAlValue6, iFEAlValue7, iFEAlValue8);

	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11+iFault12+iFault13+iFault14+iFault15+iFault16+iFault17+iFault18+iFault19+iFault20+
					iFault21+iFault22+iFault23+iFault24+iFault25+iFault26+iFault27+iFault28+iFault29+iFault30+
					iFault31+iFault32+iFault33+iFault34+iFault35+iFault36+iFault37+iFault38+iFault39+iFault40+
					iFault41+iFault42+iFault43+iFault44+iFault45+iFault46+iFault47+iFault48+iFault49+iFault50+
					iFault51+iFault52+iFault53+iFault54+iFault55+iFault56+iFault57+iFault58+iFault59+iFault60+
					iFault61+iFault62+iFault63+iFault64+iFault65+iFault66+iFault67+iFault68+iFault69+iFault70+
					iFault71+iFault72+iFault73+iFault74+iFault75+iFault76+iFault77+iFault78+iFault79+iFault80+iFault81+iFault82+
					iFault83+iFault84+iFault85+iFault86+iFault87+iFault88+iFault89+iFault90+iFault91+iFault92+iFault93+iFault94+iFault95+iFault96+iFault97+
					iFault98+iFault99+iFault100+iFault101+iFault102+iFault103+iFault104+iFault105+iFault106+iFault107+iFault108+iFault109+iFault110+iFault111+iFault112+iFault113+
					iFault114+iFault115+iFault116+iFault117+iFault118+iFault119+iFault120+iFault121+iFault122+iFault123+iFault124+iFault125+iFault126+iFault127+iFault128+iFault129+
					iFault130+iFault131+iFault132+iFault133+iFault134+iFault135+iFault136+iFault137+iFault138+iFault139+iFault140+iFault141+iFault142+iFault143+iFault144+iFault145+
					iFault146+iFault147+iFault148+iFault149+iFault150+iFault151+iFault152+iFault153+iFault154+iFault155+iFault156+iFault157+iFault158+iFault159+iFault160+iFault161+
					iFault162+iFault163+iFault164;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    g_diFGCFault[12] = iFault12;
    g_diFGCFault[13] = iFault13;
    g_diFGCFault[14] = iFault14;
    g_diFGCFault[15] = iFault15;
    g_diFGCFault[16] = iFault16;
    g_diFGCFault[17] = iFault17;
    g_diFGCFault[18] = iFault18;
    g_diFGCFault[19] = iFault19;
    g_diFGCFault[20] = iFault20;
    g_diFGCFault[21] = iFault21;
    g_diFGCFault[22] = iFault22;
    g_diFGCFault[23] = iFault23;
    g_diFGCFault[24] = iFault24;
    g_diFGCFault[25] = iFault25;
    g_diFGCFault[26] = iFault26;
    g_diFGCFault[27] = iFault27;
    g_diFGCFault[28] = iFault28;
    g_diFGCFault[29] = iFault29;
    g_diFGCFault[30] = iFault30;
    g_diFGCFault[31] = iFault31;
    g_diFGCFault[32] = iFault32;
    g_diFGCFault[33] = iFault33;
    g_diFGCFault[34] = iFault34;
    g_diFGCFault[35] = iFault35;
    g_diFGCFault[36] = iFault36;
    g_diFGCFault[37] = iFault37;
    g_diFGCFault[38] = iFault38;
    g_diFGCFault[39] = iFault39;
    g_diFGCFault[40] = iFault40;
    g_diFGCFault[41] = iFault41;
    g_diFGCFault[42] = iFault42;
    g_diFGCFault[43] = iFault43;
    g_diFGCFault[44] = iFault44;
    g_diFGCFault[45] = iFault45;
    g_diFGCFault[46] = iFault46;
    g_diFGCFault[47] = iFault47;
    g_diFGCFault[48] = iFault48;
    g_diFGCFault[49] = iFault49;
    g_diFGCFault[50] = iFault50;
    g_diFGCFault[51] = iFault51;
    g_diFGCFault[52] = iFault52;
    g_diFGCFault[53] = iFault53;
    g_diFGCFault[54] = iFault54;
    g_diFGCFault[55] = iFault55;
    g_diFGCFault[56] = iFault56;
    g_diFGCFault[57] = iFault57;
    g_diFGCFault[58] = iFault58;
    g_diFGCFault[59] = iFault59;
    g_diFGCFault[60] = iFault60;
    g_diFGCFault[61] = iFault61;
    g_diFGCFault[62] = iFault62;
    g_diFGCFault[63] = iFault63;
    g_diFGCFault[64] = iFault64;
    g_diFGCFault[65] = iFault65;
    g_diFGCFault[66] = iFault66;
    g_diFGCFault[67] = iFault67;
    g_diFGCFault[68] = iFault68;
    g_diFGCFault[69] = iFault69;
    g_diFGCFault[70] = iFault70;
    g_diFGCFault[71] = iFault71;
    g_diFGCFault[72] = iFault72;
    g_diFGCFault[73] = iFault73;
    g_diFGCFault[74] = iFault74;
    g_diFGCFault[75] = iFault75;
    g_diFGCFault[76] = iFault76;
    g_diFGCFault[77] = iFault77;
    g_diFGCFault[78] = iFault78;
    g_diFGCFault[79] = iFault79;
    g_diFGCFault[80] = iFault80;
    g_diFGCFault[81] = iFault81;
    g_diFGCFault[82] = iFault82;
    g_diFGCFault[83] = iFault83;
    g_diFGCFault[84] = iFault84;
    g_diFGCFault[85] = iFault85;
    g_diFGCFault[86] = iFault86;
    g_diFGCFault[87] = iFault87;
    g_diFGCFault[88] = iFault88;
    g_diFGCFault[89] = iFault89;
    g_diFGCFault[90] = iFault90;
    g_diFGCFault[91] = iFault91;
    g_diFGCFault[92] = iFault92;
    g_diFGCFault[93] = iFault93;
    g_diFGCFault[94] = iFault94;
    g_diFGCFault[95] = iFault95;
    g_diFGCFault[96] = iFault96;
    g_diFGCFault[97] = iFault97;
    g_diFGCFault[98] = iFault98;
    g_diFGCFault[99] = iFault99;
    g_diFGCFault[100] = iFault100;
    g_diFGCFault[101] = iFault101;
    g_diFGCFault[102] = iFault102;
    g_diFGCFault[103] = iFault103;
    g_diFGCFault[104] = iFault104;
    g_diFGCFault[105] = iFault105;
    g_diFGCFault[106] = iFault106;
    g_diFGCFault[107] = iFault107;
    g_diFGCFault[108] = iFault108;
    g_diFGCFault[109] = iFault109;
    g_diFGCFault[110] = iFault110;
    g_diFGCFault[111] = iFault111;
    g_diFGCFault[112] = iFault112;
    g_diFGCFault[113] = iFault113;
    g_diFGCFault[114] = iFault114;
    g_diFGCFault[115] = iFault115;
    g_diFGCFault[116] = iFault116;
    g_diFGCFault[117] = iFault117;
    g_diFGCFault[118] = iFault118;
    g_diFGCFault[119] = iFault119;
    g_diFGCFault[120] = iFault120;
    g_diFGCFault[121] = iFault121;
    g_diFGCFault[122] = iFault122;
    g_diFGCFault[123] = iFault123;
    g_diFGCFault[124] = iFault124;
    g_diFGCFault[125] = iFault125;
    g_diFGCFault[126] = iFault126;
    g_diFGCFault[127] = iFault127;
    g_diFGCFault[128] = iFault128;
    g_diFGCFault[129] = iFault129;
    g_diFGCFault[130] = iFault130;
    g_diFGCFault[131] = iFault131;
    g_diFGCFault[132] = iFault132;
    g_diFGCFault[133] = iFault133;
    g_diFGCFault[134] = iFault134;
    g_diFGCFault[135] = iFault135;
    g_diFGCFault[136] = iFault136;
    g_diFGCFault[137] = iFault137;
    g_diFGCFault[138] = iFault138;
    g_diFGCFault[139] = iFault139;
    g_diFGCFault[140] = iFault140;
    g_diFGCFault[141] = iFault141;
    g_diFGCFault[142] = iFault142;
    g_diFGCFault[143] = iFault143;
    g_diFGCFault[144] = iFault144;
    g_diFGCFault[145] = iFault145;
    g_diFGCFault[146] = iFault146;
    g_diFGCFault[147] = iFault147;
    g_diFGCFault[148] = iFault148;
    g_diFGCFault[149] = iFault149;
    g_diFGCFault[150] = iFault150;
    g_diFGCFault[151] = iFault151;
    g_diFGCFault[152] = iFault152;
    g_diFGCFault[153] = iFault153;
    g_diFGCFault[154] = iFault154;
    g_diFGCFault[155] = iFault155;
    g_diFGCFault[156] = iFault156;
    g_diFGCFault[157] = iFault157;
    g_diFGCFault[158] = iFault158;
    g_diFGCFault[159] = iFault159;
    g_diFGCFault[160] = iFault160;
    g_diFGCFault[161] = iFault161;
    g_diFGCFault[162] = iFault162;
    g_diFGCFault[163] = iFault163;
    g_diFGCFault[164] = iFault164;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1 & bFEEnabled2 & bFEEnabled3 & bFEEnabled4 & bFEEnabled5 & bFEEnabled6 & bFEEnabled7 & bFEEnabled8);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/**FGC2_LHC_PC_widgetCB_176_8
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_176_8(	string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																													string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
																													string sDpFEAl3, int iFEAlValue3, string sDpFEEnabled3, bool bFEEnabled3,
																													string sDpFEAl4, int iFEAlValue4, string sDpFEEnabled4, bool bFEEnabled4,
																													string sDpFEAl5, int iFEAlValue5, string sDpFEEnabled5, bool bFEEnabled5,
																													string sDpFEAl6, int iFEAlValue6, string sDpFEEnabled6, bool bFEEnabled6,
																													string sDpFEAl7, int iFEAlValue7, string sDpFEEnabled7, bool bFEEnabled7,
																													string sDpFEAl8, int iFEAlValue8, string sDpFEEnabled8, bool bFEEnabled8,
																													string sDevice1, int iFault1, string sDevice2, int iFault2,
																													string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																													string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																													string sDevice11, int iFault11, string sDevice12, int iFault12, string sDevice13, int iFault13, string sDevice14, int iFault14,
																													string sDevice15, int iFault15, string sDevice16, int iFault16, string sDevice17, int iFault17, string sDevice18, int iFault18,
																													string sDevice19, int iFault19, string sDevice20, int iFault20, string sDevice21, int iFault21, string sDevice22, int iFault22,
																													string sDevice23, int iFault23, string sDevice24, int iFault24, string sDevice25, int iFault25, string sDevice26, int iFault26,
																													string sDevice27, int iFault27, string sDevice28, int iFault28, string sDevice29, int iFault29, string sDevice30, int iFault30,
																													string sDevice31, int iFault31, string sDevice32, int iFault32, string sDevice33, int iFault33, string sDevice34, int iFault34,
																													string sDevice35, int iFault35, string sDevice36, int iFault36, string sDevice37, int iFault37, string sDevice38, int iFault38,
																													string sDevice39, int iFault39, string sDevice40, int iFault40, string sDevice41, int iFault41, string sDevice42, int iFault42,
																													string sDevice43, int iFault43, string sDevice44, int iFault44, string sDevice45, int iFault45, string sDevice46, int iFault46,
																													string sDevice47, int iFault47, string sDevice48, int iFault48, string sDevice49, int iFault49, string sDevice50, int iFault50,
																													string sDevice51, int iFault51, string sDevice52, int iFault52, string sDevice53, int iFault53, string sDevice54, int iFault54,
																													string sDevice55, int iFault55, string sDevice56, int iFault56, string sDevice57, int iFault57, string sDevice58, int iFault58,
																													string sDevice59, int iFault59, string sDevice60, int iFault60, string sDevice61, int iFault61, string sDevice62, int iFault62,
																													string sDevice63, int iFault63, string sDevice64, int iFault64, string sDevice65, int iFault65, string sDevice66, int iFault66,
																													string sDevice67, int iFault67, string sDevice68, int iFault68, string sDevice69, int iFault69, string sDevice70, int iFault70,
																													string sDevice71, int iFault71, string sDevice72, int iFault72, string sDevice73, int iFault73, string sDevice74, int iFault74,
																													string sDevice75, int iFault75, string sDevice76, int iFault76, string sDevice77, int iFault77, string sDevice78, int iFault78
																													, string sDevice79, int iFault79, string sDevice80, int iFault80, string sDevice81, int iFault81, string sDevice82, int iFault82
																													, string sDevice83, int iFault83, string sDevice84, int iFault84, string sDevice85, int iFault85, string sDevice86, int iFault86
																													, string sDevice87, int iFault87, string sDevice88, int iFault88, string sDevice89, int iFault89, string sDevice90, int iFault90
																													, string sDevice91, int iFault91, string sDevice92, int iFault92, string sDevice93, int iFault93, string sDevice94, int iFault94
																													, string sDevice95, int iFault95, string sDevice96, int iFault96, string sDevice97, int iFault97, string sDevice98, int iFault98
																													, string sDevice99, int iFault99, string sDevice100, int iFault100, string sDevice101, int iFault101, string sDevice102, int iFault102
																													, string sDevice103, int iFault103, string sDevice104, int iFault104, string sDevice105, int iFault105, string sDevice106, int iFault106
																													, string sDevice107, int iFault107, string sDevice108, int iFault108, string sDevice109, int iFault109, string sDevice110, int iFault110
																													, string sDevice111, int iFault111, string sDevice112, int iFault112, string sDevice113, int iFault113, string sDevice114, int iFault114
																													, string sDevice115, int iFault115, string sDevice116, int iFault116, string sDevice117, int iFault117, string sDevice118, int iFault118
																													, string sDevice119, int iFault119, string sDevice120, int iFault120, string sDevice121, int iFault121, string sDevice122, int iFault122
																													, string sDevice123, int iFault123, string sDevice124, int iFault124, string sDevice125, int iFault125, string sDevice126, int iFault126
																													, string sDevice127, int iFault127, string sDevice128, int iFault128, string sDevice129, int iFault129, string sDevice130, int iFault130
																													, string sDevice131, int iFault131, string sDevice132, int iFault132, string sDevice133, int iFault133, string sDevice134, int iFault134
																													, string sDevice135, int iFault135, string sDevice136, int iFault136, string sDevice137, int iFault137, string sDevice138, int iFault138
																													, string sDevice139, int iFault139, string sDevice140, int iFault140, string sDevice141, int iFault141, string sDevice142, int iFault142
																													, string sDevice143, int iFault143, string sDevice144, int iFault144, string sDevice145, int iFault145, string sDevice146, int iFault146
																													, string sDevice147, int iFault147, string sDevice148, int iFault148, string sDevice149, int iFault149, string sDevice150, int iFault150
																													, string sDevice151, int iFault151, string sDevice152, int iFault152, string sDevice153, int iFault153, string sDevice154, int iFault154
																													, string sDevice155, int iFault155, string sDevice156, int iFault156, string sDevice157, int iFault157, string sDevice158, int iFault158
																													, string sDevice159, int iFault159, string sDevice160, int iFault160, string sDevice161, int iFault161, string sDevice162, int iFault162
																													, string sDevice163, int iFault163, string sDevice164, int iFault164, string sDevice165, int iFault165, string sDevice166, int iFault166
																													, string sDevice167, int iFault167, string sDevice168, int iFault168, string sDevice169, int iFault169, string sDevice170, int iFault170
																													, string sDevice171, int iFault171, string sDevice172, int iFault172, string sDevice173, int iFault173, string sDevice174, int iFault174
																													, string sDevice175, int iFault175, string sDevice176, int iFault176)
{
int iFault;
dyn_int diFEValue;
	
	diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2, iFEAlValue3, iFEAlValue4, iFEAlValue5, iFEAlValue6, iFEAlValue7, iFEAlValue8);

	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11+iFault12+iFault13+iFault14+iFault15+iFault16+iFault17+iFault18+iFault19+iFault20+
					iFault21+iFault22+iFault23+iFault24+iFault25+iFault26+iFault27+iFault28+iFault29+iFault30+
					iFault31+iFault32+iFault33+iFault34+iFault35+iFault36+iFault37+iFault38+iFault39+iFault40+
					iFault41+iFault42+iFault43+iFault44+iFault45+iFault46+iFault47+iFault48+iFault49+iFault50+
					iFault51+iFault52+iFault53+iFault54+iFault55+iFault56+iFault57+iFault58+iFault59+iFault60+
					iFault61+iFault62+iFault63+iFault64+iFault65+iFault66+iFault67+iFault68+iFault69+iFault70+
					iFault71+iFault72+iFault73+iFault74+iFault75+iFault76+iFault77+iFault78+iFault79+iFault80+iFault81+iFault82+
					iFault83+iFault84+iFault85+iFault86+iFault87+iFault88+iFault89+iFault90+iFault91+iFault92+iFault93+iFault94+iFault95+iFault96+iFault97+
					iFault98+iFault99+iFault100+iFault101+iFault102+iFault103+iFault104+iFault105+iFault106+iFault107+iFault108+iFault109+iFault110+iFault111+iFault112+iFault113+
					iFault114+iFault115+iFault116+iFault117+iFault118+iFault119+iFault120+iFault121+iFault122+iFault123+iFault124+iFault125+iFault126+iFault127+iFault128+iFault129+
					iFault130+iFault131+iFault132+iFault133+iFault134+iFault135+iFault136+iFault137+iFault138+iFault139+iFault140+iFault141+iFault142+iFault143+iFault144+iFault145+
					iFault146+iFault147+iFault148+iFault149+iFault150+iFault151+iFault152+iFault153+iFault154+iFault155+iFault156+iFault157+iFault158+iFault159+iFault160+iFault161+
					iFault162+iFault163+iFault164+iFault165+iFault166+iFault167+iFault168+iFault169+iFault170+iFault171+iFault172+iFault173+iFault174+iFault175+iFault176;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    g_diFGCFault[12] = iFault12;
    g_diFGCFault[13] = iFault13;
    g_diFGCFault[14] = iFault14;
    g_diFGCFault[15] = iFault15;
    g_diFGCFault[16] = iFault16;
    g_diFGCFault[17] = iFault17;
    g_diFGCFault[18] = iFault18;
    g_diFGCFault[19] = iFault19;
    g_diFGCFault[20] = iFault20;
    g_diFGCFault[21] = iFault21;
    g_diFGCFault[22] = iFault22;
    g_diFGCFault[23] = iFault23;
    g_diFGCFault[24] = iFault24;
    g_diFGCFault[25] = iFault25;
    g_diFGCFault[26] = iFault26;
    g_diFGCFault[27] = iFault27;
    g_diFGCFault[28] = iFault28;
    g_diFGCFault[29] = iFault29;
    g_diFGCFault[30] = iFault30;
    g_diFGCFault[31] = iFault31;
    g_diFGCFault[32] = iFault32;
    g_diFGCFault[33] = iFault33;
    g_diFGCFault[34] = iFault34;
    g_diFGCFault[35] = iFault35;
    g_diFGCFault[36] = iFault36;
    g_diFGCFault[37] = iFault37;
    g_diFGCFault[38] = iFault38;
    g_diFGCFault[39] = iFault39;
    g_diFGCFault[40] = iFault40;
    g_diFGCFault[41] = iFault41;
    g_diFGCFault[42] = iFault42;
    g_diFGCFault[43] = iFault43;
    g_diFGCFault[44] = iFault44;
    g_diFGCFault[45] = iFault45;
    g_diFGCFault[46] = iFault46;
    g_diFGCFault[47] = iFault47;
    g_diFGCFault[48] = iFault48;
    g_diFGCFault[49] = iFault49;
    g_diFGCFault[50] = iFault50;
    g_diFGCFault[51] = iFault51;
    g_diFGCFault[52] = iFault52;
    g_diFGCFault[53] = iFault53;
    g_diFGCFault[54] = iFault54;
    g_diFGCFault[55] = iFault55;
    g_diFGCFault[56] = iFault56;
    g_diFGCFault[57] = iFault57;
    g_diFGCFault[58] = iFault58;
    g_diFGCFault[59] = iFault59;
    g_diFGCFault[60] = iFault60;
    g_diFGCFault[61] = iFault61;
    g_diFGCFault[62] = iFault62;
    g_diFGCFault[63] = iFault63;
    g_diFGCFault[64] = iFault64;
    g_diFGCFault[65] = iFault65;
    g_diFGCFault[66] = iFault66;
    g_diFGCFault[67] = iFault67;
    g_diFGCFault[68] = iFault68;
    g_diFGCFault[69] = iFault69;
    g_diFGCFault[70] = iFault70;
    g_diFGCFault[71] = iFault71;
    g_diFGCFault[72] = iFault72;
    g_diFGCFault[73] = iFault73;
    g_diFGCFault[74] = iFault74;
    g_diFGCFault[75] = iFault75;
    g_diFGCFault[76] = iFault76;
    g_diFGCFault[77] = iFault77;
    g_diFGCFault[78] = iFault78;
    g_diFGCFault[79] = iFault79;
    g_diFGCFault[80] = iFault80;
    g_diFGCFault[81] = iFault81;
    g_diFGCFault[82] = iFault82;
    g_diFGCFault[83] = iFault83;
    g_diFGCFault[84] = iFault84;
    g_diFGCFault[85] = iFault85;
    g_diFGCFault[86] = iFault86;
    g_diFGCFault[87] = iFault87;
    g_diFGCFault[88] = iFault88;
    g_diFGCFault[89] = iFault89;
    g_diFGCFault[90] = iFault90;
    g_diFGCFault[91] = iFault91;
    g_diFGCFault[92] = iFault92;
    g_diFGCFault[93] = iFault93;
    g_diFGCFault[94] = iFault94;
    g_diFGCFault[95] = iFault95;
    g_diFGCFault[96] = iFault96;
    g_diFGCFault[97] = iFault97;
    g_diFGCFault[98] = iFault98;
    g_diFGCFault[99] = iFault99;
    g_diFGCFault[100] = iFault100;
    g_diFGCFault[101] = iFault101;
    g_diFGCFault[102] = iFault102;
    g_diFGCFault[103] = iFault103;
    g_diFGCFault[104] = iFault104;
    g_diFGCFault[105] = iFault105;
    g_diFGCFault[106] = iFault106;
    g_diFGCFault[107] = iFault107;
    g_diFGCFault[108] = iFault108;
    g_diFGCFault[109] = iFault109;
    g_diFGCFault[110] = iFault110;
    g_diFGCFault[111] = iFault111;
    g_diFGCFault[112] = iFault112;
    g_diFGCFault[113] = iFault113;
    g_diFGCFault[114] = iFault114;
    g_diFGCFault[115] = iFault115;
    g_diFGCFault[116] = iFault116;
    g_diFGCFault[117] = iFault117;
    g_diFGCFault[118] = iFault118;
    g_diFGCFault[119] = iFault119;
    g_diFGCFault[120] = iFault120;
    g_diFGCFault[121] = iFault121;
    g_diFGCFault[122] = iFault122;
    g_diFGCFault[123] = iFault123;
    g_diFGCFault[124] = iFault124;
    g_diFGCFault[125] = iFault125;
    g_diFGCFault[126] = iFault126;
    g_diFGCFault[127] = iFault127;
    g_diFGCFault[128] = iFault128;
    g_diFGCFault[129] = iFault129;
    g_diFGCFault[130] = iFault130;
    g_diFGCFault[131] = iFault131;
    g_diFGCFault[132] = iFault132;
    g_diFGCFault[133] = iFault133;
    g_diFGCFault[134] = iFault134;
    g_diFGCFault[135] = iFault135;
    g_diFGCFault[136] = iFault136;
    g_diFGCFault[137] = iFault137;
    g_diFGCFault[138] = iFault138;
    g_diFGCFault[139] = iFault139;
    g_diFGCFault[140] = iFault140;
    g_diFGCFault[141] = iFault141;
    g_diFGCFault[142] = iFault142;
    g_diFGCFault[143] = iFault143;
    g_diFGCFault[144] = iFault144;
    g_diFGCFault[145] = iFault145;
    g_diFGCFault[146] = iFault146;
    g_diFGCFault[147] = iFault147;
    g_diFGCFault[148] = iFault148;
    g_diFGCFault[149] = iFault149;
    g_diFGCFault[150] = iFault150;
    g_diFGCFault[151] = iFault151;
    g_diFGCFault[152] = iFault152;
    g_diFGCFault[153] = iFault153;
    g_diFGCFault[154] = iFault154;
    g_diFGCFault[155] = iFault155;
    g_diFGCFault[156] = iFault156;
    g_diFGCFault[157] = iFault157;
    g_diFGCFault[158] = iFault158;
    g_diFGCFault[159] = iFault159;
    g_diFGCFault[160] = iFault160;
    g_diFGCFault[161] = iFault161;
    g_diFGCFault[162] = iFault162;
    g_diFGCFault[163] = iFault163;
    g_diFGCFault[164] = iFault164;
    g_diFGCFault[165] = iFault165;
    g_diFGCFault[166] = iFault166;
    g_diFGCFault[167] = iFault167;
    g_diFGCFault[168] = iFault168;
    g_diFGCFault[169] = iFault169;
    g_diFGCFault[170] = iFault170;
    g_diFGCFault[171] = iFault171;
    g_diFGCFault[172] = iFault172;
    g_diFGCFault[173] = iFault173;
    g_diFGCFault[174] = iFault174;
    g_diFGCFault[175] = iFault175;
    g_diFGCFault[176] = iFault176;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1 & bFEEnabled2 & bFEEnabled3 & bFEEnabled4 & bFEEnabled5 & bFEEnabled6 & bFEEnabled7 & bFEEnabled8);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_172_8
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_172_8(	string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																													string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
																													string sDpFEAl3, int iFEAlValue3, string sDpFEEnabled3, bool bFEEnabled3,
																													string sDpFEAl4, int iFEAlValue4, string sDpFEEnabled4, bool bFEEnabled4,
																													string sDpFEAl5, int iFEAlValue5, string sDpFEEnabled5, bool bFEEnabled5,
																													string sDpFEAl6, int iFEAlValue6, string sDpFEEnabled6, bool bFEEnabled6,
																													string sDpFEAl7, int iFEAlValue7, string sDpFEEnabled7, bool bFEEnabled7,
																													string sDpFEAl8, int iFEAlValue8, string sDpFEEnabled8, bool bFEEnabled8,
																													string sDevice1, int iFault1, string sDevice2, int iFault2,
																													string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																													string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																													string sDevice11, int iFault11, string sDevice12, int iFault12, string sDevice13, int iFault13, string sDevice14, int iFault14,
																													string sDevice15, int iFault15, string sDevice16, int iFault16, string sDevice17, int iFault17, string sDevice18, int iFault18,
																													string sDevice19, int iFault19, string sDevice20, int iFault20, string sDevice21, int iFault21, string sDevice22, int iFault22,
																													string sDevice23, int iFault23, string sDevice24, int iFault24, string sDevice25, int iFault25, string sDevice26, int iFault26,
																													string sDevice27, int iFault27, string sDevice28, int iFault28, string sDevice29, int iFault29, string sDevice30, int iFault30,
																													string sDevice31, int iFault31, string sDevice32, int iFault32, string sDevice33, int iFault33, string sDevice34, int iFault34,
																													string sDevice35, int iFault35, string sDevice36, int iFault36, string sDevice37, int iFault37, string sDevice38, int iFault38,
																													string sDevice39, int iFault39, string sDevice40, int iFault40, string sDevice41, int iFault41, string sDevice42, int iFault42,
																													string sDevice43, int iFault43, string sDevice44, int iFault44, string sDevice45, int iFault45, string sDevice46, int iFault46,
																													string sDevice47, int iFault47, string sDevice48, int iFault48, string sDevice49, int iFault49, string sDevice50, int iFault50,
																													string sDevice51, int iFault51, string sDevice52, int iFault52, string sDevice53, int iFault53, string sDevice54, int iFault54,
																													string sDevice55, int iFault55, string sDevice56, int iFault56, string sDevice57, int iFault57, string sDevice58, int iFault58,
																													string sDevice59, int iFault59, string sDevice60, int iFault60, string sDevice61, int iFault61, string sDevice62, int iFault62,
																													string sDevice63, int iFault63, string sDevice64, int iFault64, string sDevice65, int iFault65, string sDevice66, int iFault66,
																													string sDevice67, int iFault67, string sDevice68, int iFault68, string sDevice69, int iFault69, string sDevice70, int iFault70,
																													string sDevice71, int iFault71, string sDevice72, int iFault72, string sDevice73, int iFault73, string sDevice74, int iFault74,
																													string sDevice75, int iFault75, string sDevice76, int iFault76, string sDevice77, int iFault77, string sDevice78, int iFault78
																													, string sDevice79, int iFault79, string sDevice80, int iFault80, string sDevice81, int iFault81, string sDevice82, int iFault82
																													, string sDevice83, int iFault83, string sDevice84, int iFault84, string sDevice85, int iFault85, string sDevice86, int iFault86
																													, string sDevice87, int iFault87, string sDevice88, int iFault88, string sDevice89, int iFault89, string sDevice90, int iFault90
																													, string sDevice91, int iFault91, string sDevice92, int iFault92, string sDevice93, int iFault93, string sDevice94, int iFault94
																													, string sDevice95, int iFault95, string sDevice96, int iFault96, string sDevice97, int iFault97, string sDevice98, int iFault98
																													, string sDevice99, int iFault99, string sDevice100, int iFault100, string sDevice101, int iFault101, string sDevice102, int iFault102
																													, string sDevice103, int iFault103, string sDevice104, int iFault104, string sDevice105, int iFault105, string sDevice106, int iFault106
																													, string sDevice107, int iFault107, string sDevice108, int iFault108, string sDevice109, int iFault109, string sDevice110, int iFault110
																													, string sDevice111, int iFault111, string sDevice112, int iFault112, string sDevice113, int iFault113, string sDevice114, int iFault114
																													, string sDevice115, int iFault115, string sDevice116, int iFault116, string sDevice117, int iFault117, string sDevice118, int iFault118
																													, string sDevice119, int iFault119, string sDevice120, int iFault120, string sDevice121, int iFault121, string sDevice122, int iFault122
																													, string sDevice123, int iFault123, string sDevice124, int iFault124, string sDevice125, int iFault125, string sDevice126, int iFault126
																													, string sDevice127, int iFault127, string sDevice128, int iFault128, string sDevice129, int iFault129, string sDevice130, int iFault130
																													, string sDevice131, int iFault131, string sDevice132, int iFault132, string sDevice133, int iFault133, string sDevice134, int iFault134
																													, string sDevice135, int iFault135, string sDevice136, int iFault136, string sDevice137, int iFault137, string sDevice138, int iFault138
																													, string sDevice139, int iFault139, string sDevice140, int iFault140, string sDevice141, int iFault141, string sDevice142, int iFault142
																													, string sDevice143, int iFault143, string sDevice144, int iFault144, string sDevice145, int iFault145, string sDevice146, int iFault146
																													, string sDevice147, int iFault147, string sDevice148, int iFault148, string sDevice149, int iFault149, string sDevice150, int iFault150
																													, string sDevice151, int iFault151, string sDevice152, int iFault152, string sDevice153, int iFault153, string sDevice154, int iFault154
																													, string sDevice155, int iFault155, string sDevice156, int iFault156, string sDevice157, int iFault157, string sDevice158, int iFault158
																													, string sDevice159, int iFault159, string sDevice160, int iFault160, string sDevice161, int iFault161, string sDevice162, int iFault162
																													, string sDevice163, int iFault163, string sDevice164, int iFault164, string sDevice165, int iFault165, string sDevice166, int iFault166
																													, string sDevice167, int iFault167, string sDevice168, int iFault168, string sDevice169, int iFault169, string sDevice170, int iFault170
																													, string sDevice171, int iFault171, string sDevice172, int iFault172)
{
int iFault;
dyn_int diFEValue;
	
	diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2, iFEAlValue3, iFEAlValue4, iFEAlValue5, iFEAlValue6, iFEAlValue7, iFEAlValue8);

	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11+iFault12+iFault13+iFault14+iFault15+iFault16+iFault17+iFault18+iFault19+iFault20+
					iFault21+iFault22+iFault23+iFault24+iFault25+iFault26+iFault27+iFault28+iFault29+iFault30+
					iFault31+iFault32+iFault33+iFault34+iFault35+iFault36+iFault37+iFault38+iFault39+iFault40+
					iFault41+iFault42+iFault43+iFault44+iFault45+iFault46+iFault47+iFault48+iFault49+iFault50+
					iFault51+iFault52+iFault53+iFault54+iFault55+iFault56+iFault57+iFault58+iFault59+iFault60+
					iFault61+iFault62+iFault63+iFault64+iFault65+iFault66+iFault67+iFault68+iFault69+iFault70+
					iFault71+iFault72+iFault73+iFault74+iFault75+iFault76+iFault77+iFault78+iFault79+iFault80+iFault81+iFault82+
					iFault83+iFault84+iFault85+iFault86+iFault87+iFault88+iFault89+iFault90+iFault91+iFault92+iFault93+iFault94+iFault95+iFault96+iFault97+
					iFault98+iFault99+iFault100+iFault101+iFault102+iFault103+iFault104+iFault105+iFault106+iFault107+iFault108+iFault109+iFault110+iFault111+iFault112+iFault113+
					iFault114+iFault115+iFault116+iFault117+iFault118+iFault119+iFault120+iFault121+iFault122+iFault123+iFault124+iFault125+iFault126+iFault127+iFault128+iFault129+
					iFault130+iFault131+iFault132+iFault133+iFault134+iFault135+iFault136+iFault137+iFault138+iFault139+iFault140+iFault141+iFault142+iFault143+iFault144+iFault145+
					iFault146+iFault147+iFault148+iFault149+iFault150+iFault151+iFault152+iFault153+iFault154+iFault155+iFault156+iFault157+iFault158+iFault159+iFault160+iFault161+
					iFault162+iFault163+iFault164+iFault165+iFault166+iFault167+iFault168+iFault169+iFault170+iFault171+iFault172;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    g_diFGCFault[12] = iFault12;
    g_diFGCFault[13] = iFault13;
    g_diFGCFault[14] = iFault14;
    g_diFGCFault[15] = iFault15;
    g_diFGCFault[16] = iFault16;
    g_diFGCFault[17] = iFault17;
    g_diFGCFault[18] = iFault18;
    g_diFGCFault[19] = iFault19;
    g_diFGCFault[20] = iFault20;
    g_diFGCFault[21] = iFault21;
    g_diFGCFault[22] = iFault22;
    g_diFGCFault[23] = iFault23;
    g_diFGCFault[24] = iFault24;
    g_diFGCFault[25] = iFault25;
    g_diFGCFault[26] = iFault26;
    g_diFGCFault[27] = iFault27;
    g_diFGCFault[28] = iFault28;
    g_diFGCFault[29] = iFault29;
    g_diFGCFault[30] = iFault30;
    g_diFGCFault[31] = iFault31;
    g_diFGCFault[32] = iFault32;
    g_diFGCFault[33] = iFault33;
    g_diFGCFault[34] = iFault34;
    g_diFGCFault[35] = iFault35;
    g_diFGCFault[36] = iFault36;
    g_diFGCFault[37] = iFault37;
    g_diFGCFault[38] = iFault38;
    g_diFGCFault[39] = iFault39;
    g_diFGCFault[40] = iFault40;
    g_diFGCFault[41] = iFault41;
    g_diFGCFault[42] = iFault42;
    g_diFGCFault[43] = iFault43;
    g_diFGCFault[44] = iFault44;
    g_diFGCFault[45] = iFault45;
    g_diFGCFault[46] = iFault46;
    g_diFGCFault[47] = iFault47;
    g_diFGCFault[48] = iFault48;
    g_diFGCFault[49] = iFault49;
    g_diFGCFault[50] = iFault50;
    g_diFGCFault[51] = iFault51;
    g_diFGCFault[52] = iFault52;
    g_diFGCFault[53] = iFault53;
    g_diFGCFault[54] = iFault54;
    g_diFGCFault[55] = iFault55;
    g_diFGCFault[56] = iFault56;
    g_diFGCFault[57] = iFault57;
    g_diFGCFault[58] = iFault58;
    g_diFGCFault[59] = iFault59;
    g_diFGCFault[60] = iFault60;
    g_diFGCFault[61] = iFault61;
    g_diFGCFault[62] = iFault62;
    g_diFGCFault[63] = iFault63;
    g_diFGCFault[64] = iFault64;
    g_diFGCFault[65] = iFault65;
    g_diFGCFault[66] = iFault66;
    g_diFGCFault[67] = iFault67;
    g_diFGCFault[68] = iFault68;
    g_diFGCFault[69] = iFault69;
    g_diFGCFault[70] = iFault70;
    g_diFGCFault[71] = iFault71;
    g_diFGCFault[72] = iFault72;
    g_diFGCFault[73] = iFault73;
    g_diFGCFault[74] = iFault74;
    g_diFGCFault[75] = iFault75;
    g_diFGCFault[76] = iFault76;
    g_diFGCFault[77] = iFault77;
    g_diFGCFault[78] = iFault78;
    g_diFGCFault[79] = iFault79;
    g_diFGCFault[80] = iFault80;
    g_diFGCFault[81] = iFault81;
    g_diFGCFault[82] = iFault82;
    g_diFGCFault[83] = iFault83;
    g_diFGCFault[84] = iFault84;
    g_diFGCFault[85] = iFault85;
    g_diFGCFault[86] = iFault86;
    g_diFGCFault[87] = iFault87;
    g_diFGCFault[88] = iFault88;
    g_diFGCFault[89] = iFault89;
    g_diFGCFault[90] = iFault90;
    g_diFGCFault[91] = iFault91;
    g_diFGCFault[92] = iFault92;
    g_diFGCFault[93] = iFault93;
    g_diFGCFault[94] = iFault94;
    g_diFGCFault[95] = iFault95;
    g_diFGCFault[96] = iFault96;
    g_diFGCFault[97] = iFault97;
    g_diFGCFault[98] = iFault98;
    g_diFGCFault[99] = iFault99;
    g_diFGCFault[100] = iFault100;
    g_diFGCFault[101] = iFault101;
    g_diFGCFault[102] = iFault102;
    g_diFGCFault[103] = iFault103;
    g_diFGCFault[104] = iFault104;
    g_diFGCFault[105] = iFault105;
    g_diFGCFault[106] = iFault106;
    g_diFGCFault[107] = iFault107;
    g_diFGCFault[108] = iFault108;
    g_diFGCFault[109] = iFault109;
    g_diFGCFault[110] = iFault110;
    g_diFGCFault[111] = iFault111;
    g_diFGCFault[112] = iFault112;
    g_diFGCFault[113] = iFault113;
    g_diFGCFault[114] = iFault114;
    g_diFGCFault[115] = iFault115;
    g_diFGCFault[116] = iFault116;
    g_diFGCFault[117] = iFault117;
    g_diFGCFault[118] = iFault118;
    g_diFGCFault[119] = iFault119;
    g_diFGCFault[120] = iFault120;
    g_diFGCFault[121] = iFault121;
    g_diFGCFault[122] = iFault122;
    g_diFGCFault[123] = iFault123;
    g_diFGCFault[124] = iFault124;
    g_diFGCFault[125] = iFault125;
    g_diFGCFault[126] = iFault126;
    g_diFGCFault[127] = iFault127;
    g_diFGCFault[128] = iFault128;
    g_diFGCFault[129] = iFault129;
    g_diFGCFault[130] = iFault130;
    g_diFGCFault[131] = iFault131;
    g_diFGCFault[132] = iFault132;
    g_diFGCFault[133] = iFault133;
    g_diFGCFault[134] = iFault134;
    g_diFGCFault[135] = iFault135;
    g_diFGCFault[136] = iFault136;
    g_diFGCFault[137] = iFault137;
    g_diFGCFault[138] = iFault138;
    g_diFGCFault[139] = iFault139;
    g_diFGCFault[140] = iFault140;
    g_diFGCFault[141] = iFault141;
    g_diFGCFault[142] = iFault142;
    g_diFGCFault[143] = iFault143;
    g_diFGCFault[144] = iFault144;
    g_diFGCFault[145] = iFault145;
    g_diFGCFault[146] = iFault146;
    g_diFGCFault[147] = iFault147;
    g_diFGCFault[148] = iFault148;
    g_diFGCFault[149] = iFault149;
    g_diFGCFault[150] = iFault150;
    g_diFGCFault[151] = iFault151;
    g_diFGCFault[152] = iFault152;
    g_diFGCFault[153] = iFault153;
    g_diFGCFault[154] = iFault154;
    g_diFGCFault[155] = iFault155;
    g_diFGCFault[156] = iFault156;
    g_diFGCFault[157] = iFault157;
    g_diFGCFault[158] = iFault158;
    g_diFGCFault[159] = iFault159;
    g_diFGCFault[160] = iFault160;
    g_diFGCFault[161] = iFault161;
    g_diFGCFault[162] = iFault162;
    g_diFGCFault[163] = iFault163;
    g_diFGCFault[164] = iFault164;
    g_diFGCFault[165] = iFault165;
    g_diFGCFault[166] = iFault166;
    g_diFGCFault[167] = iFault167;
    g_diFGCFault[168] = iFault168;
    g_diFGCFault[169] = iFault169;
    g_diFGCFault[170] = iFault170;
    g_diFGCFault[171] = iFault171;
    g_diFGCFault[172] = iFault172;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1 & bFEEnabled2 & bFEEnabled3 & bFEEnabled4 & bFEEnabled5 & bFEEnabled6 & bFEEnabled7 & bFEEnabled8);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** FGC2_LHC_PC_widgetCB_168_8
*/

void unLHCCircuit_FGC2_LHC_PC_widgetCB_168_8(	string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
																													string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
																													string sDpFEAl3, int iFEAlValue3, string sDpFEEnabled3, bool bFEEnabled3,
																													string sDpFEAl4, int iFEAlValue4, string sDpFEEnabled4, bool bFEEnabled4,
																													string sDpFEAl5, int iFEAlValue5, string sDpFEEnabled5, bool bFEEnabled5,
																													string sDpFEAl6, int iFEAlValue6, string sDpFEEnabled6, bool bFEEnabled6,
																													string sDpFEAl7, int iFEAlValue7, string sDpFEEnabled7, bool bFEEnabled7,
																													string sDpFEAl8, int iFEAlValue8, string sDpFEEnabled8, bool bFEEnabled8,
																													string sDevice1, int iFault1, string sDevice2, int iFault2,
																													string sDevice3, int iFault3, string sDevice4, int iFault4, string sDevice5, int iFault5, string sDevice6, int iFault6,
																													string sDevice7, int iFault7, string sDevice8, int iFault8, string sDevice9, int iFault9, string sDevice10, int iFault10,
																													string sDevice11, int iFault11, string sDevice12, int iFault12, string sDevice13, int iFault13, string sDevice14, int iFault14,
																													string sDevice15, int iFault15, string sDevice16, int iFault16, string sDevice17, int iFault17, string sDevice18, int iFault18,
																													string sDevice19, int iFault19, string sDevice20, int iFault20, string sDevice21, int iFault21, string sDevice22, int iFault22,
																													string sDevice23, int iFault23, string sDevice24, int iFault24, string sDevice25, int iFault25, string sDevice26, int iFault26,
																													string sDevice27, int iFault27, string sDevice28, int iFault28, string sDevice29, int iFault29, string sDevice30, int iFault30,
																													string sDevice31, int iFault31, string sDevice32, int iFault32, string sDevice33, int iFault33, string sDevice34, int iFault34,
																													string sDevice35, int iFault35, string sDevice36, int iFault36, string sDevice37, int iFault37, string sDevice38, int iFault38,
																													string sDevice39, int iFault39, string sDevice40, int iFault40, string sDevice41, int iFault41, string sDevice42, int iFault42,
																													string sDevice43, int iFault43, string sDevice44, int iFault44, string sDevice45, int iFault45, string sDevice46, int iFault46,
																													string sDevice47, int iFault47, string sDevice48, int iFault48, string sDevice49, int iFault49, string sDevice50, int iFault50,
																													string sDevice51, int iFault51, string sDevice52, int iFault52, string sDevice53, int iFault53, string sDevice54, int iFault54,
																													string sDevice55, int iFault55, string sDevice56, int iFault56, string sDevice57, int iFault57, string sDevice58, int iFault58,
																													string sDevice59, int iFault59, string sDevice60, int iFault60, string sDevice61, int iFault61, string sDevice62, int iFault62,
																													string sDevice63, int iFault63, string sDevice64, int iFault64, string sDevice65, int iFault65, string sDevice66, int iFault66,
																													string sDevice67, int iFault67, string sDevice68, int iFault68, string sDevice69, int iFault69, string sDevice70, int iFault70,
																													string sDevice71, int iFault71, string sDevice72, int iFault72, string sDevice73, int iFault73, string sDevice74, int iFault74,
																													string sDevice75, int iFault75, string sDevice76, int iFault76, string sDevice77, int iFault77, string sDevice78, int iFault78
																													, string sDevice79, int iFault79, string sDevice80, int iFault80, string sDevice81, int iFault81, string sDevice82, int iFault82
																													, string sDevice83, int iFault83, string sDevice84, int iFault84, string sDevice85, int iFault85, string sDevice86, int iFault86
																													, string sDevice87, int iFault87, string sDevice88, int iFault88, string sDevice89, int iFault89, string sDevice90, int iFault90
																													, string sDevice91, int iFault91, string sDevice92, int iFault92, string sDevice93, int iFault93, string sDevice94, int iFault94
																													, string sDevice95, int iFault95, string sDevice96, int iFault96, string sDevice97, int iFault97, string sDevice98, int iFault98
																													, string sDevice99, int iFault99, string sDevice100, int iFault100, string sDevice101, int iFault101, string sDevice102, int iFault102
																													, string sDevice103, int iFault103, string sDevice104, int iFault104, string sDevice105, int iFault105, string sDevice106, int iFault106
																													, string sDevice107, int iFault107, string sDevice108, int iFault108, string sDevice109, int iFault109, string sDevice110, int iFault110
																													, string sDevice111, int iFault111, string sDevice112, int iFault112, string sDevice113, int iFault113, string sDevice114, int iFault114
																													, string sDevice115, int iFault115, string sDevice116, int iFault116, string sDevice117, int iFault117, string sDevice118, int iFault118
																													, string sDevice119, int iFault119, string sDevice120, int iFault120, string sDevice121, int iFault121, string sDevice122, int iFault122
																													, string sDevice123, int iFault123, string sDevice124, int iFault124, string sDevice125, int iFault125, string sDevice126, int iFault126
																													, string sDevice127, int iFault127, string sDevice128, int iFault128, string sDevice129, int iFault129, string sDevice130, int iFault130
																													, string sDevice131, int iFault131, string sDevice132, int iFault132, string sDevice133, int iFault133, string sDevice134, int iFault134
																													, string sDevice135, int iFault135, string sDevice136, int iFault136, string sDevice137, int iFault137, string sDevice138, int iFault138
																													, string sDevice139, int iFault139, string sDevice140, int iFault140, string sDevice141, int iFault141, string sDevice142, int iFault142
																													, string sDevice143, int iFault143, string sDevice144, int iFault144, string sDevice145, int iFault145, string sDevice146, int iFault146
																													, string sDevice147, int iFault147, string sDevice148, int iFault148, string sDevice149, int iFault149, string sDevice150, int iFault150
																													, string sDevice151, int iFault151, string sDevice152, int iFault152, string sDevice153, int iFault153, string sDevice154, int iFault154
																													, string sDevice155, int iFault155, string sDevice156, int iFault156, string sDevice157, int iFault157, string sDevice158, int iFault158
																													, string sDevice159, int iFault159, string sDevice160, int iFault160, string sDevice161, int iFault161, string sDevice162, int iFault162
																													, string sDevice163, int iFault163, string sDevice164, int iFault164, string sDevice165, int iFault165, string sDevice166, int iFault166
																													, string sDevice167, int iFault167, string sDevice168, int iFault168)
{
int iFault;
dyn_int diFEValue;
	
	diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2, iFEAlValue3, iFEAlValue4, iFEAlValue5, iFEAlValue6, iFEAlValue7, iFEAlValue8);

	iFault=	iFault1+iFault2+iFault3+iFault4+iFault5+iFault6+iFault7+iFault8+iFault9+iFault10+
					iFault11+iFault12+iFault13+iFault14+iFault15+iFault16+iFault17+iFault18+iFault19+iFault20+
					iFault21+iFault22+iFault23+iFault24+iFault25+iFault26+iFault27+iFault28+iFault29+iFault30+
					iFault31+iFault32+iFault33+iFault34+iFault35+iFault36+iFault37+iFault38+iFault39+iFault40+
					iFault41+iFault42+iFault43+iFault44+iFault45+iFault46+iFault47+iFault48+iFault49+iFault50+
					iFault51+iFault52+iFault53+iFault54+iFault55+iFault56+iFault57+iFault58+iFault59+iFault60+
					iFault61+iFault62+iFault63+iFault64+iFault65+iFault66+iFault67+iFault68+iFault69+iFault70+
					iFault71+iFault72+iFault73+iFault74+iFault75+iFault76+iFault77+iFault78+iFault79+iFault80+iFault81+iFault82+
					iFault83+iFault84+iFault85+iFault86+iFault87+iFault88+iFault89+iFault90+iFault91+iFault92+iFault93+iFault94+iFault95+iFault96+iFault97+
					iFault98+iFault99+iFault100+iFault101+iFault102+iFault103+iFault104+iFault105+iFault106+iFault107+iFault108+iFault109+iFault110+iFault111+iFault112+iFault113+
					iFault114+iFault115+iFault116+iFault117+iFault118+iFault119+iFault120+iFault121+iFault122+iFault123+iFault124+iFault125+iFault126+iFault127+iFault128+iFault129+
					iFault130+iFault131+iFault132+iFault133+iFault134+iFault135+iFault136+iFault137+iFault138+iFault139+iFault140+iFault141+iFault142+iFault143+iFault144+iFault145+
					iFault146+iFault147+iFault148+iFault149+iFault150+iFault151+iFault152+iFault153+iFault154+iFault155+iFault156+iFault157+iFault158+iFault159+iFault160+iFault161+
					iFault162+iFault163+iFault164+iFault165+iFault166+iFault167+iFault168;
	
  synchronized(g_mFault)
  {
    g_diFGCFault[1] = iFault1;
    g_diFGCFault[2] = iFault2;
    g_diFGCFault[3] = iFault3;
    g_diFGCFault[4] = iFault4;
    g_diFGCFault[5] = iFault5;
    g_diFGCFault[6] = iFault6;
    g_diFGCFault[7] = iFault7;
    g_diFGCFault[8] = iFault8;
    g_diFGCFault[9] = iFault9;
    g_diFGCFault[10] = iFault10;
    g_diFGCFault[11] = iFault11;
    g_diFGCFault[12] = iFault12;
    g_diFGCFault[13] = iFault13;
    g_diFGCFault[14] = iFault14;
    g_diFGCFault[15] = iFault15;
    g_diFGCFault[16] = iFault16;
    g_diFGCFault[17] = iFault17;
    g_diFGCFault[18] = iFault18;
    g_diFGCFault[19] = iFault19;
    g_diFGCFault[20] = iFault20;
    g_diFGCFault[21] = iFault21;
    g_diFGCFault[22] = iFault22;
    g_diFGCFault[23] = iFault23;
    g_diFGCFault[24] = iFault24;
    g_diFGCFault[25] = iFault25;
    g_diFGCFault[26] = iFault26;
    g_diFGCFault[27] = iFault27;
    g_diFGCFault[28] = iFault28;
    g_diFGCFault[29] = iFault29;
    g_diFGCFault[30] = iFault30;
    g_diFGCFault[31] = iFault31;
    g_diFGCFault[32] = iFault32;
    g_diFGCFault[33] = iFault33;
    g_diFGCFault[34] = iFault34;
    g_diFGCFault[35] = iFault35;
    g_diFGCFault[36] = iFault36;
    g_diFGCFault[37] = iFault37;
    g_diFGCFault[38] = iFault38;
    g_diFGCFault[39] = iFault39;
    g_diFGCFault[40] = iFault40;
    g_diFGCFault[41] = iFault41;
    g_diFGCFault[42] = iFault42;
    g_diFGCFault[43] = iFault43;
    g_diFGCFault[44] = iFault44;
    g_diFGCFault[45] = iFault45;
    g_diFGCFault[46] = iFault46;
    g_diFGCFault[47] = iFault47;
    g_diFGCFault[48] = iFault48;
    g_diFGCFault[49] = iFault49;
    g_diFGCFault[50] = iFault50;
    g_diFGCFault[51] = iFault51;
    g_diFGCFault[52] = iFault52;
    g_diFGCFault[53] = iFault53;
    g_diFGCFault[54] = iFault54;
    g_diFGCFault[55] = iFault55;
    g_diFGCFault[56] = iFault56;
    g_diFGCFault[57] = iFault57;
    g_diFGCFault[58] = iFault58;
    g_diFGCFault[59] = iFault59;
    g_diFGCFault[60] = iFault60;
    g_diFGCFault[61] = iFault61;
    g_diFGCFault[62] = iFault62;
    g_diFGCFault[63] = iFault63;
    g_diFGCFault[64] = iFault64;
    g_diFGCFault[65] = iFault65;
    g_diFGCFault[66] = iFault66;
    g_diFGCFault[67] = iFault67;
    g_diFGCFault[68] = iFault68;
    g_diFGCFault[69] = iFault69;
    g_diFGCFault[70] = iFault70;
    g_diFGCFault[71] = iFault71;
    g_diFGCFault[72] = iFault72;
    g_diFGCFault[73] = iFault73;
    g_diFGCFault[74] = iFault74;
    g_diFGCFault[75] = iFault75;
    g_diFGCFault[76] = iFault76;
    g_diFGCFault[77] = iFault77;
    g_diFGCFault[78] = iFault78;
    g_diFGCFault[79] = iFault79;
    g_diFGCFault[80] = iFault80;
    g_diFGCFault[81] = iFault81;
    g_diFGCFault[82] = iFault82;
    g_diFGCFault[83] = iFault83;
    g_diFGCFault[84] = iFault84;
    g_diFGCFault[85] = iFault85;
    g_diFGCFault[86] = iFault86;
    g_diFGCFault[87] = iFault87;
    g_diFGCFault[88] = iFault88;
    g_diFGCFault[89] = iFault89;
    g_diFGCFault[90] = iFault90;
    g_diFGCFault[91] = iFault91;
    g_diFGCFault[92] = iFault92;
    g_diFGCFault[93] = iFault93;
    g_diFGCFault[94] = iFault94;
    g_diFGCFault[95] = iFault95;
    g_diFGCFault[96] = iFault96;
    g_diFGCFault[97] = iFault97;
    g_diFGCFault[98] = iFault98;
    g_diFGCFault[99] = iFault99;
    g_diFGCFault[100] = iFault100;
    g_diFGCFault[101] = iFault101;
    g_diFGCFault[102] = iFault102;
    g_diFGCFault[103] = iFault103;
    g_diFGCFault[104] = iFault104;
    g_diFGCFault[105] = iFault105;
    g_diFGCFault[106] = iFault106;
    g_diFGCFault[107] = iFault107;
    g_diFGCFault[108] = iFault108;
    g_diFGCFault[109] = iFault109;
    g_diFGCFault[110] = iFault110;
    g_diFGCFault[111] = iFault111;
    g_diFGCFault[112] = iFault112;
    g_diFGCFault[113] = iFault113;
    g_diFGCFault[114] = iFault114;
    g_diFGCFault[115] = iFault115;
    g_diFGCFault[116] = iFault116;
    g_diFGCFault[117] = iFault117;
    g_diFGCFault[118] = iFault118;
    g_diFGCFault[119] = iFault119;
    g_diFGCFault[120] = iFault120;
    g_diFGCFault[121] = iFault121;
    g_diFGCFault[122] = iFault122;
    g_diFGCFault[123] = iFault123;
    g_diFGCFault[124] = iFault124;
    g_diFGCFault[125] = iFault125;
    g_diFGCFault[126] = iFault126;
    g_diFGCFault[127] = iFault127;
    g_diFGCFault[128] = iFault128;
    g_diFGCFault[129] = iFault129;
    g_diFGCFault[130] = iFault130;
    g_diFGCFault[131] = iFault131;
    g_diFGCFault[132] = iFault132;
    g_diFGCFault[133] = iFault133;
    g_diFGCFault[134] = iFault134;
    g_diFGCFault[135] = iFault135;
    g_diFGCFault[136] = iFault136;
    g_diFGCFault[137] = iFault137;
    g_diFGCFault[138] = iFault138;
    g_diFGCFault[139] = iFault139;
    g_diFGCFault[140] = iFault140;
    g_diFGCFault[141] = iFault141;
    g_diFGCFault[142] = iFault142;
    g_diFGCFault[143] = iFault143;
    g_diFGCFault[144] = iFault144;
    g_diFGCFault[145] = iFault145;
    g_diFGCFault[146] = iFault146;
    g_diFGCFault[147] = iFault147;
    g_diFGCFault[148] = iFault148;
    g_diFGCFault[149] = iFault149;
    g_diFGCFault[150] = iFault150;
    g_diFGCFault[151] = iFault151;
    g_diFGCFault[152] = iFault152;
    g_diFGCFault[153] = iFault153;
    g_diFGCFault[154] = iFault154;
    g_diFGCFault[155] = iFault155;
    g_diFGCFault[156] = iFault156;
    g_diFGCFault[157] = iFault157;
    g_diFGCFault[158] = iFault158;
    g_diFGCFault[159] = iFault159;
    g_diFGCFault[160] = iFault160;
    g_diFGCFault[161] = iFault161;
    g_diFGCFault[162] = iFault162;
    g_diFGCFault[163] = iFault163;
    g_diFGCFault[164] = iFault164;
    g_diFGCFault[165] = iFault165;
    g_diFGCFault[166] = iFault166;
    g_diFGCFault[167] = iFault167;
    g_diFGCFault[168] = iFault168;
    unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault();
	unLHCCircuit_PC_FGC2_LHC_PC_Status(sDevice1, dynSum(g_diFGCFault), dynMax(diFEValue), bFEEnabled1 & bFEEnabled2 & bFEEnabled3 & bFEEnabled4 & bFEEnabled5 & bFEEnabled6 & bFEEnabled7 & bFEEnabled8);
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** PC_FGC2_LHC_PC_Status
*/

void unLHCCircuit_PC_FGC2_LHC_PC_Status(string sDevice, int iFault, int iFEAlValue, bool bFEEnabled)
{
string sSystem;
bit32 value;
	
	sSystem=unGenericDpFunctions_getSystemName(sDevice);
	
	if (mappingHasKey(g_mFault, sSystem))
		{	
          g_bFGC_init = true;
		value=g_mFault[sSystem];
			
		//cast int to boolean with iFault
		setBit(value, 31, (bool)iFault);
		if ((iFEAlValue<10) && bFEEnabled)
			setBit(value, FE_BAD, FALSE);
		else
			setBit(value, FE_BAD, TRUE);
		
		/*setBit(value, FAULT_FIPBAD, FALSE);
		setBit(value, FAULT_CIPBAD, FALSE);*/
				
//DebugN(g_mFault[sSystem], value, iFault);
		g_mFault[sSystem]=value;
unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, (string)txtwidget.text+" FGC", (string)txtwidget.text+" FGC", iFault, iFEAlValue, bFEEnabled, g_mFault, g_dsFGCDevice, g_dsFGCCircuit, g_diFGCFault);   
		}
	else
		DebugN("unLHCCircuit_PC_FGC2_LHC_PC_Status(): System UNKNOWN: " + sSystem + " - " + sDevice);	
}

//------------------------------------------------------------------------------------------------------------------------
/** PC_getSynopticDollarParameters
*/

void unLHCCircuit_PC_getSynopticDollarParameters(const dyn_string dsFGC, const int iPC, dyn_string &dsPC)
{
int i;

	switch (iPC)
		{
		case 1:
			dynAppend(dsPC, "$PC_IDENTIFIER:" + dsFGC[1]);
			break;
		
		case 2:	
			for (i=1; i<=iPC; i++)
				{
				if (patternMatch("*B1", dsFGC[i]))			
					dynAppend(dsPC, "$PC_IDENTIFIER1:" + dsFGC[i]);					
				else if (patternMatch("*B2", dsFGC[i]))			
					dynAppend(dsPC, "$PC_IDENTIFIER2:" + dsFGC[i]);				
				}	
			break;

		case 3:	
			for (i=1; i<=iPC; i++)
				{
				if (patternMatch("*.RQX.*", dsFGC[i]))			
					dynAppend(dsPC, "$PC_IDENTIFIER1:" + dsFGC[i]);					
				else if (patternMatch("*.RTQX1.*", dsFGC[i]))			
					dynAppend(dsPC, "$PC_IDENTIFIER2:" + dsFGC[i]);				
				else if (patternMatch("*.RTQX2.*", dsFGC[i]))			
					dynAppend(dsPC, "$PC_IDENTIFIER3:" + dsFGC[i]);				
				}
			break;			

		default:
			dynClear(dsPC);
		}
}

//------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault
/** correct the FGC fault if the circuit is a 60A circuit and it is not connected: address config inactive.
  
@par Constraints
  None

@par Usage
  Public

@par PVSS managers
  Ui

@param dsDPE  input, list of DPE
@return true=OK/false=BAD
*/
unLHCCircuit_FGC2_LHC_PC_widgetCB_DType_correctFGCFault()
{
  int i, len=dynlen(g_diFGCFault);
  
  for(i=1;i<=len;i++)
  {
    if(g_dbDType_NotConnected[i])
    {
      g_diFGCFault[i] = 0;
unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, (string)txtwidget.text+" FGC DType corrected", (string)txtwidget.text+" FGC isDType corrected", g_dbDType_NotConnected[i], g_dsFGCDevice[i], g_dsFGCCircuit[i], g_diFGCFault[i]);   
    }
  }
}

//@}
