/**@file

// unLHCCircuit_QPS.ctl
This library contains the functions to manage the QPS used in the subsector widget in the LHCCircuit.

@par Creation Date
  24/09/2007

@par Modification History
  26/04/2011: Herve
  - CIR-23: Powering sub-sector and circuit widget: use PIC superlock for the animation

@par Constraints
  None

@par Usage
  Public

@par PVSS managers
  Ui

@author 
  Frederic BERNARD (AB/CO-IS)
*/

/**
* @name LHCCircuit QPS functions
This is a set of functions provided to manage QPS data in LHCCircuit
* @{
*/
   
//------------------------------------------------------------------------------------------------------------------------
// QPS CB FUNCTIONS
//------------------------------------------------------------------------------------------------------------------------
/** DQGROUP_widgetCB_1_1
*/

void unLHCCircuit_DQGROUP_widgetCB_1_1( string sDpFEAl, int iFEAlValue, string sDpFEEnabled, bool bFEEnabled,
                          string sDevice1, dyn_int diOK, string sDevice2, dyn_int diPWR_PERM, string sDevice3, dyn_int diLOGGING, 
                          string sDevice4, dyn_int diFIP, string sDevice5, dyn_int diFIP_DRV)
{
dyn_int diBody, diFault;

 dynAppend(diBody, diOK);
 dynAppend(diBody, diLOGGING);
 //dynUnique(diBody);
 dynAppend(diFault, diFIP);
 dynAppend(diFault, diFIP_DRV);  
 dynAppend(diFault, diPWR_PERM);
 //dynUnique(diFault);
   
 unLHCCircuit_QPS_DQGROUP_Status(sDevice1, diBody, diFault, iFEAlValue, bFEEnabled);
}

/** DQGROUP_widgetCB_2_2
*/

void unLHCCircuit_DQGROUP_widgetCB_2_2(  string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
                            string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
                            string sDevice1, dyn_int diOK1, string sDevice2, dyn_int diPWR_PERM1, string sDevice3, dyn_int diLOGGING1, 
                            string sDevice4, dyn_int diFIP1, string sDevice5, dyn_int diFIP_DRV1,
                            string sDevice6, dyn_int diOK2, string sDevice7, dyn_int diPWR_PERM2, string sDevice8, dyn_int diLOGGING2, 
                            string sDevice9, dyn_int diFIP2, string sDevice10, dyn_int diFIP_DRV2
                            )
{
dyn_int diBody, diFault;
dyn_int diFEValue;

 diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2);

 dynAppend(diBody, diOK1);
 dynAppend(diBody, diOK2);
 dynAppend(diBody, diLOGGING1);
 dynAppend(diBody, diLOGGING2);
 dynAppend(diFault, diFIP1);
 dynAppend(diFault, diFIP2);
 dynAppend(diFault, diFIP_DRV1);
 dynAppend(diFault, diFIP_DRV2); 
 dynAppend(diFault, diPWR_PERM1);
 dynAppend(diFault, diPWR_PERM2);
 
 unLHCCircuit_QPS_DQGROUP_Status(sDevice1, diBody, diFault, dynMax(diFEValue), bFEEnabled1 & bFEEnabled2);
}

//------------------------------------------------------------------------------------------------------------------------
/** DQGROUP_widgetCB_12_4
*/

void unLHCCircuit_DQGROUP_widgetCB_12_4( string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
                            string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
                            string sDpFEAl3, int iFEAlValue3, string sDpFEEnabled3, bool bFEEnabled3,
                            string sDpFEAl4, int iFEAlValue4, string sDpFEEnabled4, bool bFEEnabled4,                            
                            string sDevice1, dyn_int diOK1, string sDevice2, dyn_int diPWR_PERM1, string sDevice3, dyn_int diLOGGING1, 
                            string sDevice4, dyn_int diFIP1, string sDevice5, dyn_int diFIP_DRV1,
                            string sDevice6, dyn_int diOK2, string sDevice7, dyn_int diPWR_PERM2, string sDevice8, dyn_int diLOGGING2, 
                            string sDevice9, dyn_int diFIP2, string sDevice10, dyn_int diFIP_DRV2,
                            string sDevice11, dyn_int diOK3, string sDevice12, dyn_int diPWR_PERM3, string sDevice13, dyn_int diLOGGING3, 
                            string sDevice14, dyn_int diFIP3, string sDevice15, dyn_int diFIP_DRV3,
                            string sDevice16, dyn_int diOK4, string sDevice17, dyn_int diPWR_PERM4, string sDevice18, dyn_int diLOGGING4, 
                            string sDevice19, dyn_int diFIP4, string sDevice20, dyn_int diFIP_DRV4,
                            string sDevice21, dyn_int diOK5, string sDevice22, dyn_int diPWR_PERM5, string sDevice23, dyn_int diLOGGING5, 
                            string sDevice24, dyn_int diFIP5, string sDevice25, dyn_int diFIP_DRV5,
                            string sDevice26, dyn_int diOK6, string sDevice27, dyn_int diPWR_PERM6, string sDevice28, dyn_int diLOGGING6, 
                            string sDevice29, dyn_int diFIP6, string sDevice30, dyn_int diFIP_DRV6,                            
                            string sDevice31, dyn_int diOK7, string sDevice32, dyn_int diPWR_PERM7, string sDevice33, dyn_int diLOGGING7, 
                            string sDevice34, dyn_int diFIP7, string sDevice35, dyn_int diFIP_DRV7,
                            string sDevice36, dyn_int diOK8, string sDevice37, dyn_int diPWR_PERM8, string sDevice38, dyn_int diLOGGING8, 
                            string sDevice39, dyn_int diFIP8, string sDevice40, dyn_int diFIP_DRV8,
                            string sDevice41, dyn_int diOK9, string sDevice42, dyn_int diPWR_PERM9, string sDevice43, dyn_int diLOGGING9, 
                            string sDevice44, dyn_int diFIP9, string sDevice45, dyn_int diFIP_DRV9,
                            string sDevice46, dyn_int diOK10, string sDevice47, dyn_int diPWR_PERM10, string sDevice48, dyn_int diLOGGING10, 
                            string sDevice49, dyn_int diFIP10, string sDevice50, dyn_int diFIP_DRV10,
                            string sDevice51, dyn_int diOK11, string sDevice52, dyn_int diPWR_PERM11, string sDevice53, dyn_int diLOGGING11, 
                            string sDevice54, dyn_int diFIP11, string sDevice55, dyn_int diFIP_DRV11,
                            string sDevice56, dyn_int diOK12, string sDevice57, dyn_int diPWR_PERM12, string sDevice58, dyn_int diLOGGING12, 
                            string sDevice59, dyn_int diFIP12, string sDevice60, dyn_int diFIP_DRV12                            
                            
                            )
{
dyn_int diBody, diFault;
dyn_int diFEValue;

 diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2, iFEAlValue3, iFEAlValue4);

 dynAppend(diBody, diOK1);
 dynAppend(diBody, diOK2);
 dynAppend(diBody, diOK3);
 dynAppend(diBody, diOK4);
 dynAppend(diBody, diOK5);
 dynAppend(diBody, diOK6);
 dynAppend(diBody, diOK7);
 dynAppend(diBody, diOK8);
 dynAppend(diBody, diOK9);
 dynAppend(diBody, diOK10);
 dynAppend(diBody, diOK11);
 dynAppend(diBody, diOK12);  
 dynAppend(diBody, diLOGGING1);
 dynAppend(diBody, diLOGGING2);
 dynAppend(diBody, diLOGGING3);
 dynAppend(diBody, diLOGGING4);
 dynAppend(diBody, diLOGGING5);
 dynAppend(diBody, diLOGGING6);
 dynAppend(diBody, diLOGGING7);
 dynAppend(diBody, diLOGGING8);
 dynAppend(diBody, diLOGGING9);
 dynAppend(diBody, diLOGGING10);
 dynAppend(diBody, diLOGGING11);
 dynAppend(diBody, diLOGGING12); 
 dynAppend(diFault, diFIP1);
 dynAppend(diFault, diFIP2);
 dynAppend(diFault, diFIP3);
 dynAppend(diFault, diFIP4);
 dynAppend(diFault, diFIP5);
 dynAppend(diFault, diFIP6);
 dynAppend(diFault, diFIP7);
 dynAppend(diFault, diFIP8);
 dynAppend(diFault, diFIP9);
 dynAppend(diFault, diFIP10);
 dynAppend(diFault, diFIP11);
 dynAppend(diFault, diFIP12); 
 dynAppend(diFault, diFIP_DRV1);
 dynAppend(diFault, diFIP_DRV2); 
 dynAppend(diFault, diFIP_DRV3);
 dynAppend(diFault, diFIP_DRV4);
 dynAppend(diFault, diFIP_DRV5); 
 dynAppend(diFault, diFIP_DRV6);   
 dynAppend(diFault, diFIP_DRV7);
 dynAppend(diFault, diFIP_DRV8); 
 dynAppend(diFault, diFIP_DRV9);
 dynAppend(diFault, diFIP_DRV10);
 dynAppend(diFault, diFIP_DRV11); 
 dynAppend(diFault, diFIP_DRV12);    
 dynAppend(diFault, diPWR_PERM1);
 dynAppend(diFault, diPWR_PERM2);
 dynAppend(diFault, diPWR_PERM3);
 dynAppend(diFault, diPWR_PERM4);
 dynAppend(diFault, diPWR_PERM5); 
 dynAppend(diFault, diPWR_PERM6);
 dynAppend(diFault, diPWR_PERM7);
 dynAppend(diFault, diPWR_PERM8);
 dynAppend(diFault, diPWR_PERM9);
 dynAppend(diFault, diPWR_PERM10);
 dynAppend(diFault, diPWR_PERM11); 
 dynAppend(diFault, diPWR_PERM12); 
 
 unLHCCircuit_QPS_DQGROUP_Status(sDevice1, diBody, diFault, dynMax(diFEValue), bFEEnabled1 & bFEEnabled2 & bFEEnabled3 & bFEEnabled4);

}

//------------------------------------------------------------------------------------------------------------------------
/** DQGROUP_widgetCB_6_6
*/

void unLHCCircuit_DQGROUP_widgetCB_6_6( string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
                            string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
                            string sDpFEAl3, int iFEAlValue3, string sDpFEEnabled3, bool bFEEnabled3,
                            string sDpFEAl4, int iFEAlValue4, string sDpFEEnabled4, bool bFEEnabled4,
                            string sDpFEAl5, int iFEAlValue5, string sDpFEEnabled5, bool bFEEnabled5,
                            string sDpFEAl6, int iFEAlValue6, string sDpFEEnabled6, bool bFEEnabled6,                              
                            string sDevice1, dyn_int diOK1, string sDevice2, dyn_int diPWR_PERM1, string sDevice3, dyn_int diLOGGING1, 
                            string sDevice4, dyn_int diFIP1, string sDevice5, dyn_int diFIP_DRV1,
                            string sDevice6, dyn_int diOK2, string sDevice7, dyn_int diPWR_PERM2, string sDevice8, dyn_int diLOGGING2, 
                            string sDevice9, dyn_int diFIP2, string sDevice10, dyn_int diFIP_DRV2,
                            string sDevice11, dyn_int diOK3, string sDevice12, dyn_int diPWR_PERM3, string sDevice13, dyn_int diLOGGING3, 
                            string sDevice14, dyn_int diFIP3, string sDevice15, dyn_int diFIP_DRV3,
                            string sDevice16, dyn_int diOK4, string sDevice17, dyn_int diPWR_PERM4, string sDevice18, dyn_int diLOGGING4, 
                            string sDevice19, dyn_int diFIP4, string sDevice20, dyn_int diFIP_DRV4,
                            string sDevice21, dyn_int diOK5, string sDevice22, dyn_int diPWR_PERM5, string sDevice23, dyn_int diLOGGING5, 
                            string sDevice24, dyn_int diFIP5, string sDevice25, dyn_int diFIP_DRV5,
                            string sDevice26, dyn_int diOK6, string sDevice27, dyn_int diPWR_PERM6, string sDevice28, dyn_int diLOGGING6, 
                            string sDevice29, dyn_int diFIP6, string sDevice30, dyn_int diFIP_DRV6)
{
dyn_int diBody, diFault;
dyn_int diFEValue;

 diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2, iFEAlValue3, iFEAlValue4, iFEAlValue5, iFEAlValue6);

 dynAppend(diBody, diOK1);
 dynAppend(diBody, diOK2);
 dynAppend(diBody, diOK3);
 dynAppend(diBody, diOK4);
 dynAppend(diBody, diOK5);
 dynAppend(diBody, diOK6); 
 dynAppend(diBody, diLOGGING1);
 dynAppend(diBody, diLOGGING2);
 dynAppend(diBody, diLOGGING3);
 dynAppend(diBody, diLOGGING4);
 dynAppend(diBody, diLOGGING5);
 dynAppend(diBody, diLOGGING6);
 dynAppend(diFault, diFIP1);
 dynAppend(diFault, diFIP2);
 dynAppend(diFault, diFIP3);
 dynAppend(diFault, diFIP4);
 dynAppend(diFault, diFIP5);
 dynAppend(diFault, diFIP6);
 dynAppend(diFault, diFIP_DRV1);
 dynAppend(diFault, diFIP_DRV2); 
 dynAppend(diFault, diFIP_DRV3);
 dynAppend(diFault, diFIP_DRV4);
 dynAppend(diFault, diFIP_DRV5); 
 dynAppend(diFault, diFIP_DRV6);   
 dynAppend(diFault, diPWR_PERM1);
 dynAppend(diFault, diPWR_PERM2);
 dynAppend(diFault, diPWR_PERM3);
 dynAppend(diFault, diPWR_PERM4);
 dynAppend(diFault, diPWR_PERM5); 
 dynAppend(diFault, diPWR_PERM6);
 
 unLHCCircuit_QPS_DQGROUP_Status(sDevice1, diBody, diFault, dynMax(diFEValue), bFEEnabled1 & bFEEnabled2 & bFEEnabled3 & bFEEnabled4 & bFEEnabled5 & bFEEnabled6);

}

//------------------------------------------------------------------------------------------------------------------------
/** DQGROUP_widgetCB_10_6
*/

void unLHCCircuit_DQGROUP_widgetCB_10_6( string sDpFEAl1, int iFEAlValue1, string sDpFEEnabled1, bool bFEEnabled1,
                            string sDpFEAl2, int iFEAlValue2, string sDpFEEnabled2, bool bFEEnabled2,
                            string sDpFEAl3, int iFEAlValue3, string sDpFEEnabled3, bool bFEEnabled3,
                            string sDpFEAl4, int iFEAlValue4, string sDpFEEnabled4, bool bFEEnabled4,
                            string sDpFEAl5, int iFEAlValue5, string sDpFEEnabled5, bool bFEEnabled5,
                            string sDpFEAl6, int iFEAlValue6, string sDpFEEnabled6, bool bFEEnabled6,                                                    
                            string sDevice1, dyn_int diOK1, string sDevice2, dyn_int diPWR_PERM1, string sDevice3, dyn_int diLOGGING1, 
                            string sDevice4, dyn_int diFIP1, string sDevice5, dyn_int diFIP_DRV1,
                            string sDevice6, dyn_int diOK2, string sDevice7, dyn_int diPWR_PERM2, string sDevice8, dyn_int diLOGGING2, 
                            string sDevice9, dyn_int diFIP2, string sDevice10, dyn_int diFIP_DRV2,
                            string sDevice11, dyn_int diOK3, string sDevice12, dyn_int diPWR_PERM3, string sDevice13, dyn_int diLOGGING3, 
                            string sDevice14, dyn_int diFIP3, string sDevice15, dyn_int diFIP_DRV3,
                            string sDevice16, dyn_int diOK4, string sDevice17, dyn_int diPWR_PERM4, string sDevice18, dyn_int diLOGGING4, 
                            string sDevice19, dyn_int diFIP4, string sDevice20, dyn_int diFIP_DRV4,
                            string sDevice21, dyn_int diOK5, string sDevice22, dyn_int diPWR_PERM5, string sDevice23, dyn_int diLOGGING5, 
                            string sDevice24, dyn_int diFIP5, string sDevice25, dyn_int diFIP_DRV5,
                            string sDevice26, dyn_int diOK6, string sDevice27, dyn_int diPWR_PERM6, string sDevice28, dyn_int diLOGGING6, 
                            string sDevice29, dyn_int diFIP6, string sDevice30, dyn_int diFIP_DRV6,
                            string sDevice31, dyn_int diOK7, string sDevice32, dyn_int diPWR_PERM7, string sDevice33, dyn_int diLOGGING7, 
                            string sDevice34, dyn_int diFIP7, string sDevice35, dyn_int diFIP_DRV7,
                            string sDevice36, dyn_int diOK8, string sDevice37, dyn_int diPWR_PERM8, string sDevice38, dyn_int diLOGGING8, 
                            string sDevice39, dyn_int diFIP8, string sDevice40, dyn_int diFIP_DRV8,
                            string sDevice41, dyn_int diOK9, string sDevice42, dyn_int diPWR_PERM9, string sDevice43, dyn_int diLOGGING9, 
                            string sDevice44, dyn_int diFIP9, string sDevice45, dyn_int diFIP_DRV9,
                            string sDevice46, dyn_int diOK10, string sDevice47, dyn_int diPWR_PERM10, string sDevice48, dyn_int diLOGGING10, 
                            string sDevice49, dyn_int diFIP10, string sDevice50, dyn_int diFIP_DRV10)
{
dyn_int diBody, diFault;
dyn_int diFEValue;

 diFEValue=makeDynInt(iFEAlValue1, iFEAlValue2, iFEAlValue3, iFEAlValue4, iFEAlValue5, iFEAlValue6);

 dynAppend(diBody, diOK1);
 dynAppend(diBody, diOK2);
 dynAppend(diBody, diOK3);
 dynAppend(diBody, diOK4);
 dynAppend(diBody, diOK5);
 dynAppend(diBody, diOK6); 
 dynAppend(diBody, diOK7);
 dynAppend(diBody, diOK8);
 dynAppend(diBody, diOK9);
 dynAppend(diBody, diOK10); 
 dynAppend(diBody, diLOGGING1);
 dynAppend(diBody, diLOGGING2);
 dynAppend(diBody, diLOGGING3);
 dynAppend(diBody, diLOGGING4);
 dynAppend(diBody, diLOGGING5);
 dynAppend(diBody, diLOGGING6);
 dynAppend(diBody, diLOGGING7);
 dynAppend(diBody, diLOGGING8);
 dynAppend(diBody, diLOGGING9);
 dynAppend(diBody, diLOGGING10);
 dynAppend(diFault, diFIP1);
 dynAppend(diFault, diFIP2);
 dynAppend(diFault, diFIP3);
 dynAppend(diFault, diFIP4);
 dynAppend(diFault, diFIP5);
 dynAppend(diFault, diFIP6);
 dynAppend(diFault, diFIP7);
 dynAppend(diFault, diFIP8);
 dynAppend(diFault, diFIP9);
 dynAppend(diFault, diFIP10);
 dynAppend(diFault, diFIP_DRV1);
 dynAppend(diFault, diFIP_DRV2); 
 dynAppend(diFault, diFIP_DRV3);
 dynAppend(diFault, diFIP_DRV4);
 dynAppend(diFault, diFIP_DRV5); 
 dynAppend(diFault, diFIP_DRV6); 
 dynAppend(diFault, diFIP_DRV7);
 dynAppend(diFault, diFIP_DRV8);
 dynAppend(diFault, diFIP_DRV9); 
 dynAppend(diFault, diFIP_DRV10);    
 dynAppend(diFault, diPWR_PERM1);
 dynAppend(diFault, diPWR_PERM2);
 dynAppend(diFault, diPWR_PERM3);
 dynAppend(diFault, diPWR_PERM4);
 dynAppend(diFault, diPWR_PERM5); 
 dynAppend(diFault, diPWR_PERM6);
 dynAppend(diFault, diPWR_PERM7);
 dynAppend(diFault, diPWR_PERM8);
 dynAppend(diFault, diPWR_PERM9); 
 dynAppend(diFault, diPWR_PERM10);
 
  unLHCCircuit_QPS_DQGROUP_Status(sDevice1, diBody, diFault, dynMax(diFEValue), bFEEnabled1 & bFEEnabled2 & bFEEnabled3 & bFEEnabled4 & bFEEnabled5 & bFEEnabled6);

}

//------------------------------------------------------------------------------------------------------------------------
/** QPS_DQGROUP_Status
*/

void unLHCCircuit_QPS_DQGROUP_Status(string sDevice, dyn_int diBody, dyn_int diFault, int iFEAlValue, bool bFEEnabled)
{
dyn_string dsDpId;
string sSystem, sId;
bit32 value;
int iLen, i;
bool bError, bFault;
 
 sSystem=unGenericDpFunctions_getSystemName(sDevice);

  synchronized(g_mFault)
  {
 if (mappingHasKey(g_mFault, sSystem))
  {
  value=g_mFault[sSystem];
   
  if (dynlen(diBody)==0 && dynlen(diFault)==0)
   {
   setBit(value, BODY_ERROR, FALSE);
   setBit(value, FAULT_FIPBAD, FALSE);
   }
  else
   {
   sDevice=substr(sDevice, 0, strpos(sDevice, ":_online"));
			if (mappingHasKey(g_mQPSId, sDevice))
				sId=g_mQPSId[sDevice];
			
			dsDpId=strsplit(sId, ",");
			iLen=dynlen(dsDpId);			
			
			if(iLen==0)
				{
				setBit(value, BODY_ERROR, TRUE);	
				setBit(value, FAULT_FIPBAD, TRUE);
				}
			else
				{			
				bError=FALSE;
				bFault=FALSE;
				for (i=1; i<=iLen && !(bFault && bError); i++)
					{
					if (dynContains(diBody, dsDpId[i])>0) bError=TRUE;
					if (dynContains(diFault, dsDpId[i])>0) bFault=TRUE;					
					}
				setBit(value, BODY_ERROR, bError);
				setBit(value, FAULT_FIPBAD, bFault);
				}
			}
		
		setBit(value, FE_BAD, !((iFEAlValue<10) && bFEEnabled));
		g_mFault[sSystem]=value;
		}
	else
		DebugN("unLHCCircuit_QPS_DQGROUP_Status(): System UNKNOWN: " + sSystem);
unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, (string)txtwidget.text+" QPS", (string)txtwidget.text+" QPS", g_mFault, sDevice, diBody, diFault, iFEAlValue, bFEEnabled);   
  }
}

//------------------------------------------------------------------------------------------------------------------------
/** QPS_getDQAMSRBLocation
*/

string unLHCCircuit_QPS_getDQAMSRBLocation(const string sDpN)
{
string sLocation, sDomain;
dyn_string dsParam, dsDomain;
int iLen;
 		
	unGenericDpFunctions_getParameters(sDpN, dsParam);
	
	if (dynlen(dsParam)==UN_PARAMETER_LENGTH)
		sDomain=dsParam[UN_PARAMETER_DOMAIN];

	dsDomain=strsplit(sDomain, ",");
	
	iLen=dynlen(dsDomain);
	if(iLen>0)
		sLocation=dsDomain[dynlen(dsDomain)];	//!!! Location position is harcoded = all the time at the end of the array
	
	return sLocation;
}

//------------------------------------------------------------------------------------------------------------------------
/** unLHCCircuit_QPS_getDQGROUP
*/

string unLHCCircuit_QPS_getDQGROUP(const string sDpNames, const string sCircuit)
{
string sSystem_CBW, sApplication, sPLC, sDQGROUP, sType, sDQGroupType;  
dyn_string dsSplit, dsPLC;      

   sSystem_CBW=unGenericDpFunctions_getSystemName(sDpNames);
   dsSplit=strsplit(sDpNames, UN_DPNAME_SEPARATOR);
   if (dynlen(dsSplit)>=UN_DPNAME_FIELD_LENGTH)
      {
      sApplication=dsSplit[UN_DPNAME_FIELD_PLCSUBAPPLICATION];
      sPLC=dsSplit[UN_DPNAME_FIELD_PLCNAME];
      sType=dsSplit[UN_DPNAME_FIELD_OBJECT];
      dsPLC=strsplit(sPLC, "_");
            
      if(dynlen(dsPLC)==5) sPLC=dsPLC[5];
      else sPLC="";
      
      switch(sType)
        {
        case "DQAMCNMB":
        case "DQAMGNSRB":          
        case "DQAMCNMQ":
        case "DQAMGNSRQF":
        case "DQAMGNSRQD":
          sDQGroupType=substr(sCircuit, 0, strpos(sCircuit, "."));
          break;          
        default:
          sDQGroupType="unknown";
          DebugN("unLHCCircuit_QPS_getDQGROUP - unknown QPS Type: " + sType);            
        }          
      
      sDQGROUP=sSystem_CBW + sApplication + "." + sDQGroupType + "." + sApplication + "." + sPLC;
      }
   
   return sDQGROUP;
}

//@}
