/**
@authors: Herve Milcent AB/CO-IS
@date: 12/04/2007
@file unLHCCircuit_TreeOverview.ctl

Modification History:

  01/01/2011: Herve
  - CIR-17: DQAMGND implementation
  
  - 11/08/2009 Frederic:  add new function unLHCCircuit_TreeOverview_getCryoDeviceList()
  16/06/2009: Herve
  correct CRYO device
  modified function: unLHCCircuit_TreeOverview_initialize
    - bug fix: removeSymbol in PVSS 3.8
    modified function: unLHCCircuit_TreeOverview_removedDisplayedCircuit
  16/02/2009: Herve
    - Bug PVSS 3.8: removeSymbol that was not added
      unLHCCircuit_TreeOverview_removedDisplayedCircuit: test if index == 0        
	- Frederic 13/11/2008: update the comments (-> doxygen)
	- Herve 28/04/2008: extended diag message
	- Herve 21/04/2008: tree circuit/device: use add symbol instead of module
	- Herve 10/03/2008: circuit/device & widget/snapshot individual check box
	- Herve 09/10/2007: fast select implementation
	- Herve 27/09/2007: new tree overview like treeDeviceOverview
	- Herve 10/07/2007: add Other 
	- Herve 25/04/2007: replace Devive by Device
	- Herve 20/04/2007: bug use b32SortByState_graph instead of selectDeviceCircuit in unLHCCircuit_TreeOverview_DoubleClick. / comment out Debug statement
	- Herve 18/04/2007: keep nb of device / get nb of circuit added from dll and show nb of circuits
	- Herve 17/04/2007: modif constants / load pictures for all interlock type and circuit type / new function unLHCCircuit_TreeOverview_filterChanged
	- Herve 12/04/2007: click/dbl click implementation / remove dll code
	- Herve 05/04/2007: new implementation
	- Herve 27/03/2007: implementation of dll functions.

*/

/**
* @name LHCCircuit Tree functions
Library for the functions used by the LHC_CIRCUIT tree overview (Common PC, QPS and PIC)
* @{
*/

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_initialize
/**
Purpose:
Initialize the tree device overview 

	@param b32InitSelectState: b32, input:  the filter setup.
	@param b32InitSortByState: b32, input:  the filter setup.	
	@param dsExcludedDeviceType: dyn_string, input: the list of device type to exclude in the tree device overview
	@param exInfo: dyn_string, output: exception are returned here

Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_initialize(bit32 b32InitSelectState, bit32 b32InitSortByState, dyn_string dsExcludedDeviceType, dyn_string &exInfo)
{
	int i, len, pos;
	shape shTreeShape = getShape(TREE_NAME);
	dyn_string dsFrontEndType = dsFrontEndType_graph.items;
	bit32 b32SelectState = b32SelectState_graph.text;
	bit32 b32SortByState = b32SortByState_graph.text;
	dyn_string dsDeviceType = dsDeviceType_graph.items;
	string imageClassParameters;
	string iconWithChildrenClose, iconWithChildrenOpen, iconWithChildrenSelected;
	string iconWithChildrenPath, iconWithoutChildrenNotSelected, iconWithoutChildrenSelected;
	dyn_int diAliasDim;
	string sTreeDevOvDp=unTreeDeviceOverview_getInternalTriggerName();
	dyn_dyn_string ddsTemp;
	dyn_string dsTemp;
	mapping m;
	
	applyFilter.enabled(false);
	saveFilter.enabled(false);
	openFilter.enabled(false);
	advanceFilter.enabled(false);
	selectPWS.enabled(false);
	sortByPWS.enabled(false);
	selectIT.enabled(false);
	sortByIT.enabled(false);
	selectCT.enabled(false);
	sortByCT.enabled(false);
	selectC.enabled(false);
	sortByC.enabled(false);
	selectQPSPICPC.enabled(false);
	sortByQPSPICPC.enabled(false);
	selectB.enabled(false);
	sortByB.enabled(false);
	selectD.enabled(false);
	sortByD.enabled(false);
	selectA.enabled(false);
	selectCircuit.enabled(false);
	selectDevice.enabled(false);
	SOC.enabled(false);
	
	listPages.enabled(false);
	listPages.deleteAllItems();
	beginDisplay_graph.text = 0; 
	endDisplay_graph.text = 0; 
	displayList_graph.deleteAllItems();
	displayInfo1.text = "";
	cWidget.enabled(false);
	cSnapshot.enabled(false);

	circuitList_graph.deleteAllItems();
        dscircuitType_graph.deleteAllItems();
        dsinterlockType_graph.deleteAllItems();
        
	circuitPages.enabled(false);
	circuitPages.deleteAllItems();
	circuitInfo.text = "";

	for(i=1;i<=LHC_CIRCUIT_DEVICE_FILTER_MAX;i++){
		setMultiValue("lvl"+i+"filter", "text", "lvl"+i+"filter", "lvl"+i+"selection", "text", "");
		g_dbLvlFilterVisible[i] = false;
		g_dbLvlSelectionVisible[i] = false;
	}
	for(i=1;i<=LHC_CIRCUIT_CIRCUIT_FILTER_MAX;i++){
		setMultiValue("lvlCircuit"+i+"filter", "text", "lvlCircuit"+i+"filter", "lvlCircuit"+i+"selection", "text", "");
		g_dbLvlCircuitFilterVisible[i] = true;
		g_dbLvlCircuitSelectionVisible[i] = true;
	}

	if(!dpExists(sTreeDevOvDp)) {
		dpCreate(sTreeDevOvDp, DEVUN_DPTYPE);
	}
	dynAppend(g_dsTreeDeviceOverview_triggerDisplayDP, sTreeDevOvDp);
	dynUnique(g_dsTreeDeviceOverview_triggerDisplayDP);
	
	if(dpExists(sTreeDevOvDp)) {
	// 4. Other...
		beginDisplay_graph.text = 0;
		endDisplay_graph.text = 0;
// get DisplayAliasLarge dimension
		diAliasDim = getPanelSize("objects/UN_INFOS/unDisplayAliasLarge.pnl");
		if (dynlen(diAliasDim) >= 2)
		{
			widthAliasLarge_graph.text = diAliasDim[1];
		}
		else
		{
			widthAliasLarge_graph.text = 180;
		}
// get DisplayAlias dimension
		diAliasDim = getPanelSize("objects/UN_INFOS/unDisplayAlias.pnl");
		if (dynlen(diAliasDim) >= 2)
		{
			widthAliasSmall_graph.text = diAliasDim[1];
			widthAlias_graph.text = diAliasDim[1];
			heightAlias_graph.text = diAliasDim[2];
		}
		else
		{
			widthAliasSmall_graph.text = 125;
			widthAlias_graph.text = 125;
			heightAlias_graph.text = 20;
		}
		
		b32SelectState = b32InitSelectState;
		b32SelectState_graph.text = b32SelectState;

		b32SortByState = b32InitSortByState;
		b32SortByState_graph.text = b32SortByState;
	
		// 2. get list of device type and remove the excluded
		dsDeviceType = makeDynString("CIPC", "FGC2_LHC_PC", "AnalogInput", "DigitalInput", "Analog", "CPC_AnalogInput", "CPC_DigitalInput", "CPC_Analog", 
                                             "DQAMCNMB", "DQAMCNMQ", 
                                             "DQAMGNA", "DQAMGNC", "DQAMGNDRB_EVEN", "DQAMGNDRB_ODD", "DQAMGNDRQ", 
                                             "DQAMGNRD", "DQAMGNRQA", "DQAMGNRQB", "DQAMGNRQC",
                                             "DQQLC_NEVEN", "DQQLC_NODD",
                                             "DQAMSN600", "DQAMSNRB", "DQAMSNRQ",
                                             "DQAMGNSRB", "DQAMGNSRQD", "DQAMGNSRQF");
		
		len = dynlen(dsExcludedDeviceType);
		for(i=1;i<=len;i++) {
			pos = dynContains(dsDeviceType, dsExcludedDeviceType[i]);
			if(pos>0)
				dynRemove(dsDeviceType, pos);
		}
		dsDeviceType_graph.items = dsDeviceType;
		g_dsDeviceType = dsDeviceType;

		dsExcludedDeviceType = dsDeviceType;
		dynAppend(dsExcludedDeviceType, UN_EVENT_LIST_LIST_NAME);
		dynInsertAt(dsExcludedDeviceType, "*", 1);
		deviceTypeList.items = dsExcludedDeviceType;
		deviceTypeList.selectedPos(1);

		g_QPSPICPO = makeDynString("QPS", "PIC", "PC", "Other");
		dsExcludedDeviceType = g_QPSPICPO;
		dynAppend(dsExcludedDeviceType, UN_EVENT_LIST_LIST_NAME);
		dynInsertAt(dsExcludedDeviceType, "*", 1);
		QPSPICPOList.items = dsExcludedDeviceType;
		QPSPICPOList.selectedPos(1);
		
		// 1. get all the front-end type
		unGenericDpFunctions_getFrontEndDeviceType(dsFrontEndType);
		dsFrontEndType_graph.items = dsFrontEndType;
	
		unTreeWidget_setPropertyValue(shTreeShape, "set_bNodeNotRemovedOnCollapseExpand", true, true);
	
	// load the images for circuit CIRCUIT_CLASS
		iconWithChildrenClose = getPath(PICTURES_REL_PATH,CIRCUIT_CLASS+"/iconWithChildrenClose.bmp");
		iconWithChildrenOpen = getPath(PICTURES_REL_PATH,CIRCUIT_CLASS+"/iconWithChildrenOpen.bmp");
		iconWithChildrenSelected = getPath(PICTURES_REL_PATH,CIRCUIT_CLASS+"/iconWithChildrenSelected.bmp");
		iconWithChildrenPath = getPath(PICTURES_REL_PATH,CIRCUIT_CLASS+"/iconWithChildrenPath.bmp");
		iconWithoutChildrenNotSelected = getPath(PICTURES_REL_PATH,CIRCUIT_CLASS+"/iconWithoutChildrenNotSelected.bmp");
		iconWithoutChildrenSelected = getPath(PICTURES_REL_PATH,CIRCUIT_CLASS+"/iconWithoutChildrenSelected.bmp");
		
		if( (iconWithChildrenClose != "") && (iconWithChildrenOpen != "") &&
				(iconWithChildrenSelected != "") && (iconWithChildrenPath != "") &&
				(iconWithoutChildrenNotSelected != "") && (iconWithoutChildrenSelected != "")) {
			imageClassParameters = iconWithChildrenClose + ";" +
								   iconWithChildrenOpen + ";" +
								   iconWithChildrenSelected + ";" +
								   iconWithChildrenPath + ";" +
								   iconWithoutChildrenNotSelected + ";" +
								   iconWithoutChildrenSelected;
			unTreeWidget_setPropertyValue(shTreeShape, "addImageClass", CIRCUIT_CLASS+";" + imageClassParameters, true);
		}

	// load images for QPSPICPO
		dsTemp = g_QPSPICPO;
		len = dynlen(dsTemp);
		for(i=1;i<=len;i++) {
			iconWithChildrenClose = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenClose.bmp");
			iconWithChildrenOpen = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenOpen.bmp");
			iconWithChildrenSelected = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenSelected.bmp");
			iconWithChildrenPath = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenPath.bmp");
			iconWithoutChildrenNotSelected = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithoutChildrenNotSelected.bmp");
			iconWithoutChildrenSelected = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithoutChildrenSelected.bmp");
			
			if( (iconWithChildrenClose != "") && (iconWithChildrenOpen != "") &&
					(iconWithChildrenSelected != "") && (iconWithChildrenPath != "") &&
					(iconWithoutChildrenNotSelected != "") && (iconWithoutChildrenSelected != "")) {
				imageClassParameters = iconWithChildrenClose + ";" +
									   iconWithChildrenOpen + ";" +
									   iconWithChildrenSelected + ";" +
									   iconWithChildrenPath + ";" +
									   iconWithoutChildrenNotSelected + ";" +
									   iconWithoutChildrenSelected;
				unTreeWidget_setPropertyValue(shTreeShape, "addImageClass", dsTemp[i]+";" + imageClassParameters, true);
			}
		}
		
	// load images for Interlock type
		dsTemp = g_dsLHC_CIRCUITCircuitInterlockType;
		dynUnique(dsTemp);
		len = dynlen(dsTemp);
		for(i=1;i<=len;i++) {
			iconWithChildrenClose = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenClose.bmp");
			iconWithChildrenOpen = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenOpen.bmp");
			iconWithChildrenSelected = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenSelected.bmp");
			iconWithChildrenPath = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenPath.bmp");
			iconWithoutChildrenNotSelected = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithoutChildrenNotSelected.bmp");
			iconWithoutChildrenSelected = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithoutChildrenSelected.bmp");
			
			if( (iconWithChildrenClose != "") && (iconWithChildrenOpen != "") &&
					(iconWithChildrenSelected != "") && (iconWithChildrenPath != "") &&
					(iconWithoutChildrenNotSelected != "") && (iconWithoutChildrenSelected != "")) {
				imageClassParameters = iconWithChildrenClose + ";" +
									   iconWithChildrenOpen + ";" +
									   iconWithChildrenSelected + ";" +
									   iconWithChildrenPath + ";" +
									   iconWithoutChildrenNotSelected + ";" +
									   iconWithoutChildrenSelected;
				unTreeWidget_setPropertyValue(shTreeShape, "addImageClass", dsTemp[i]+";" + imageClassParameters, true);
			}
		}

	// load images for Circuit type
		dsTemp = g_dsLHC_CIRCUITCircuitCircuitType;
		dynUnique(dsTemp);
		len = dynlen(dsTemp);
		for(i=1;i<=len;i++) {
			iconWithChildrenClose = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenClose.bmp");
			iconWithChildrenOpen = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenOpen.bmp");
			iconWithChildrenSelected = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenSelected.bmp");
			iconWithChildrenPath = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithChildrenPath.bmp");
			iconWithoutChildrenNotSelected = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithoutChildrenNotSelected.bmp");
			iconWithoutChildrenSelected = getPath(PICTURES_REL_PATH,dsTemp[i]+"/iconWithoutChildrenSelected.bmp");
			
			if( (iconWithChildrenClose != "") && (iconWithChildrenOpen != "") &&
					(iconWithChildrenSelected != "") && (iconWithChildrenPath != "") &&
					(iconWithoutChildrenNotSelected != "") && (iconWithoutChildrenSelected != "")) {
				imageClassParameters = iconWithChildrenClose + ";" +
									   iconWithChildrenOpen + ";" +
									   iconWithChildrenSelected + ";" +
									   iconWithChildrenPath + ";" +
									   iconWithoutChildrenNotSelected + ";" +
									   iconWithoutChildrenSelected;
				unTreeWidget_setPropertyValue(shTreeShape, "addImageClass", dsTemp[i]+";" + imageClassParameters, true);
			}
		}

	// load the images for device type
		len = dynlen(dsDeviceType);
		for(i=1;i<=len;i++) {
	// if the images exists then load it, otherwise use the default.
			iconWithChildrenClose = getPath(PICTURES_REL_PATH,dsDeviceType[i]+"/iconWithChildrenClose.bmp");
			iconWithChildrenOpen = getPath(PICTURES_REL_PATH,dsDeviceType[i]+"/iconWithChildrenOpen.bmp");
			iconWithChildrenSelected = getPath(PICTURES_REL_PATH,dsDeviceType[i]+"/iconWithChildrenSelected.bmp");
			iconWithChildrenPath = getPath(PICTURES_REL_PATH,dsDeviceType[i]+"/iconWithChildrenPath.bmp");
			iconWithoutChildrenNotSelected = getPath(PICTURES_REL_PATH,dsDeviceType[i]+"/iconWithoutChildrenNotSelected.bmp");
			iconWithoutChildrenSelected = getPath(PICTURES_REL_PATH,dsDeviceType[i]+"/iconWithoutChildrenSelected.bmp");
			
			if( (iconWithChildrenClose != "") && (iconWithChildrenOpen != "") &&
					(iconWithChildrenSelected != "") && (iconWithChildrenPath != "") &&
					(iconWithoutChildrenNotSelected != "") && (iconWithoutChildrenSelected != "")) {
				imageClassParameters = iconWithChildrenClose + ";" +
									   iconWithChildrenOpen + ";" +
									   iconWithChildrenSelected + ";" +
									   iconWithChildrenPath + ";" +
									   iconWithoutChildrenNotSelected + ";" +
									   iconWithoutChildrenSelected;
			}
			else {
				iconWithChildrenClose = getPath(PICTURES_REL_PATH,UN_OBJECT_DPTYPE+"/iconWithChildrenClose.bmp");
				iconWithChildrenOpen = getPath(PICTURES_REL_PATH,UN_OBJECT_DPTYPE+"/iconWithChildrenOpen.bmp");
				iconWithChildrenSelected = getPath(PICTURES_REL_PATH,UN_OBJECT_DPTYPE+"/iconWithChildrenSelected.bmp");
				iconWithChildrenPath = getPath(PICTURES_REL_PATH,UN_OBJECT_DPTYPE+"/iconWithChildrenPath.bmp");
				iconWithoutChildrenNotSelected = getPath(PICTURES_REL_PATH,UN_OBJECT_DPTYPE+"/iconWithoutChildrenNotSelected.bmp");
				iconWithoutChildrenSelected = getPath(PICTURES_REL_PATH,UN_OBJECT_DPTYPE+"/iconWithoutChildrenSelected.bmp");
				imageClassParameters = iconWithChildrenClose + ";" +
									   iconWithChildrenOpen + ";" +
									   iconWithChildrenSelected + ";" +
									   iconWithChildrenPath + ";" +
									   iconWithoutChildrenNotSelected + ";" +
									   iconWithoutChildrenSelected;
			}
			
			unTreeWidget_setPropertyValue(shTreeShape, "addImageClass", dsDeviceType[i]+";" + imageClassParameters, true);
		}
	
	// register the new system
	//DebugTN("START");
		unTreeWidget_setPropertyValue(shTreeShape, "clearTree", true, true);

		len = dynlen(g_dsTreeDeviceOverviewRegisteredSystem);
		for(i=1;i<=len;i++) {
			g_m_iDevicePerSystem[g_dsTreeDeviceOverviewRegisteredSystem[i]] = 0;
			g_m_dsCircuitPerSystem[g_dsTreeDeviceOverviewRegisteredSystem[i]] = makeDynString();
			g_m_ddsSelectedDevice[g_dsTreeDeviceOverviewRegisteredSystem[i]] = ddsTemp;
			g_m_dsNodeInTree[g_dsTreeDeviceOverviewRegisteredSystem[i]] = makeDynString();
			g_m_dbTopNode[g_dsTreeDeviceOverviewRegisteredSystem[i]] = makeDynBool();
		}
		g_m_ddsNodeDevice = m;
		dpConnect(UNCIRCUIT_TREEDISPLAY_CALLBACK, false, sTreeDevOvDp+".command", /*sTreeDevOvDp+".filter", sTreeDevOvDp+".view", */sTreeDevOvDp+".systemName");
	}
	else {
		fwException_raise(exInfo, "ERROR", "unLHCCircuit_TreeOverview_initialize: dp not existing "+sTreeDevOvDp, "");
	}
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_setCheckboxState
/**
Purpose:
Set the check box state
	@param bState: bool, input: true=circuit, false=device
	@param bSOC: bool, input: true=SOC selected, false=SOC not selected

Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/

unLHCCircuit_TreeOverview_setCheckboxState(bool bState, bool bSOC)
{
	if(bState) { // circuit 
		selectQPSPICPC.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		sortByQPSPICPC.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		selectB.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		sortByB.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		selectD.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		sortByD.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		selectA.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		sortByC.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		sortByC.enabled(false);
	}
	else {
		sortByC.enabled(true);
	}
	selectPWS.enabled(!bSOC);
	selectIT.enabled(!bSOC);
	selectCT.enabled(!bSOC);
	selectQPSPICPC.enabled(!bState);
	sortByQPSPICPC.enabled(!bState);
	selectB.enabled(!bState);
	sortByB.enabled(!bState);
	selectD.enabled(!bState);
	sortByD.enabled(!bState);
	selectA.enabled(!bState);

	selectC.enabled(!bSOC);

	if(bSOC) {
		selectC.state(FILTER_LHC_CIRCUIT_CHECKBOX, true);
		selectPWS.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		selectIT.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
		selectCT.state(FILTER_LHC_CIRCUIT_CHECKBOX, false);
	}
	
	reducedPWSList.enabled = selectPWS.enabled && selectPWS.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	reducedITList.enabled = selectIT.enabled && selectIT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	reducedCTList.enabled = selectCT.enabled && selectCT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	reducedCList.enabled = selectC.enabled && selectC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	reducedQPSPICPCList.enabled = selectQPSPICPC.enabled && selectQPSPICPC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	reducedBList.enabled = selectB.enabled && selectB.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	reducedDList.enabled = selectD.enabled && selectD.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	reducedAList.enabled = selectA.enabled && selectA.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	reducedSOCList.enabled = SOC.enabled && SOC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	
	selectCircuit.state(FILTER_LHC_CIRCUIT_CHECKBOX, bState);
	selectDevice.state(FILTER_LHC_CIRCUIT_CHECKBOX, !bState);
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_displayCallBack
/**
Purpose:
callback handling the the tree device display
	- DEVUN_ADD_COMMAND: add the data of a given system name
	- DEVUN_DELETE_COMMAND: delete the data of a given system name
	- DEVUN_APPLYFILTER_COMMAND: apply the new filter setting
	
	@param sCommandDp: string, input: the command DP
	@param iCommand: int, input: the command to execute.
	@param sSystemNameDp: string, input: the system DP
	@param sSystemName: string, input: the system name

Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_displayCallBack(string sCommandDp, int iCommand, string sSystemNameDp, string sSystemName)
{
	shape shTreeShape = getShape(TREE_NAME);
	int iCurrentPointer, iMousePointer;
	int id, i, len;
	bool bUpdate = false;
	dyn_string dsDomain, dsNature;
	dyn_string dsFrontEnd, dsFrontEndDp, dsFrontEndType, dsTempApplication, dsReturn, dsReturn2, dsAllDev1, dsAllDev2;
	dyn_dyn_string ddsTemp, ddsDomain, ddsNature, ddsEmptyTemp;
	string sGrpDp;
	dyn_string dsDeviceType=dsDeviceType_graph.items;
	bit32 b32SortByState, b32SelectState;
	bool bPWS, bInterlockType, bCircuitType, bCircuit, bQPSPICPO, bBuilding, bDeviceType,bAlias, bDevice;
	dyn_string dsCircuit, dsBuilding, dsInterlockType, dsCircuitType;
	dyn_string dsCircuitAdded, dsTemp;
	
	bPWS = sortByPWS.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bInterlockType = sortByIT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bCircuitType = sortByCT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bCircuit = sortByC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bQPSPICPO = sortByQPSPICPC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bBuilding = sortByB.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bDeviceType = sortByD.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bDevice = selectDevice.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_POWERING_SUB_SECTOR, bPWS);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_INTERLOCK_TYPE, bInterlockType);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_CIRCUIT_TYPE, bCircuitType);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_CIRCUIT, bCircuit);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_QPS_PIC_PO, bQPSPICPO);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_BUILDING, bBuilding);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_DEVICE_TYPE, bDeviceType);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_ALIAS, false);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_CIRCUIT_DEVICE, bDevice);

	bPWS = selectPWS.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bInterlockType = selectIT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bCircuitType = selectCT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bCircuit = selectC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bQPSPICPO = selectQPSPICPC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bBuilding = selectB.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bDeviceType = selectD.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bAlias = selectA.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_POWERING_SUB_SECTOR, bPWS);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_INTERLOCK_TYPE, bInterlockType);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_CIRCUIT_TYPE, bCircuitType);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_CIRCUIT, bCircuit);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_QPS_PIC_PO, bQPSPICPO);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_BUILDING, bBuilding);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_DEVICE_TYPE, bDeviceType);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_ALIAS, bAlias);

//DebugTN("unTreeDeviceOverview_displayCallBack start", sCommandDp, iCommand, b32SelectState, b32SortByState, bDevice, FILTER_LHC_CIRCUIT_CIRCUIT_DEVICE, FILTER_LHC_CIRCUIT_CHECKBOX, sSystemName);
// start the progress bar
//	id = unProgressBar_start(TREEBAR_NAME);	
// disable the unTreeWidget tree to have one action at a time.
	unTreeWidget_setPropertyValue(shTreeShape, "Enabled", false, true);
	iCurrentPointer = unTreeWidget_getPropertyValue(shTreeShape, "getMousePointer", true);
	iMousePointer = unTreeWidget_ccHourglass;
	unTreeWidget_setPropertyValue(shTreeShape, "setMousePointer", iMousePointer, true);

	applyFilter.enabled(false);
	saveFilter.enabled(false);
	openFilter.enabled(false);
	advanceFilter.enabled(false);
	selectPWS.enabled(false);
	sortByPWS.enabled(false);
	selectIT.enabled(false);
	sortByIT.enabled(false);
	selectCT.enabled(false);
	sortByCT.enabled(false);
	selectC.enabled(false);
	sortByC.enabled(false);
	selectQPSPICPC.enabled(false);
	sortByQPSPICPC.enabled(false);
	selectB.enabled(false);
	sortByB.enabled(false);
	selectD.enabled(false);
	sortByD.enabled(false);
	selectA.enabled(false);
	selectCircuit.enabled(false);
	selectDevice.enabled(false);
	SOC.enabled(false);
	
	listPages.enabled(false);
	cWidget.enabled(false);
	cSnapshot.enabled(false);

	switch(iCommand) {
		case DEVUN_ADD_COMMAND:
//DebugTN("start");
			g_m_bSystemForceSelectSort[sSystemName] = true;
			
// build the list of all connected system and display
			unLHCCircuit_TreeOverview_buildList();
			break;
		case DEVUN_DELETE_COMMAND:
// remove any panel if needed

// reset the list of the corresponding system
			g_m_bSystemForceSelectSort[sSystemName] = false;
			g_m_ddsSelectedDevice[sSystemName] = ddsTemp;
			g_m_dsNodeInTree[sSystemName] = makeDynString();
			g_m_dbTopNode[sSystemName] = makeDynBool();
// build the list of all connected system and display
			unLHCCircuit_TreeOverview_buildList();

//DebugN("CB", g_dsPVSSSystemSelected, g_dsFrontEndSelected, g_dsApplicationSelected);
			break;
		case DEVUN_APPLYFILTER_COMMAND:
			if(g_bApplyFilter) {
				devicePerSystem.deleteAllItems();
				unLHCCircuit_TreeOverview_applyFilter(shTreeShape, b32SelectState, b32SortByState, "", false); 
				bUpdate = true;
			}
			break;
		default:
			break;
	}
	if(bUpdate) {
		len = mappinglen(g_m_bTreeDeviceOverviewSystemConnected);
		for(i=1;i<=len;i++) {
			if(mappingGetValue(g_m_bTreeDeviceOverviewSystemConnected, i)) {
				if(bDevice)
					devicePerSystem.appendItem(mappingGetKey(g_m_bTreeDeviceOverviewSystemConnected, i)+" "+mappingGetValue(g_m_iDevicePerSystem, i)+" / "+mappingGetValue(g_m_dsLHC_CIRCUITDeviceNumber, i)+" filtered device(s)");
				else {
					dsTemp = mappingGetValue(g_m_dsCircuitPerSystem, i);
					dynAppend(dsCircuitAdded, dsTemp);
//DebugTN(mappingGetKey(g_m_dsCircuitPerSystem, i), mappingGetValue(g_m_dsCircuitPerSystem, i));
				}
			}
		}
//DebugTN(dsCircuitAdded, dynlen(dsCircuitAdded), dynUnique(dsCircuitAdded));
//int j, lenj, pos;
//dyn_string dsTemp=g_dsLHC_CIRCUITCircuit;
//lenj=dynlen(dsCircuitAdded);
//for(j=1;j<=lenj;j++) {
//	pos =dynContains(dsTemp, dsCircuitAdded[j]);
//	if(pos>0)
//		dynRemove(dsTemp, pos);
//}
//DebugN(dsTemp, dsCircuitAdded);
		if(!bDevice) 
			devicePerSystem.appendItem(dynUnique(dsCircuitAdded)+" / "+dynlen(g_dsLHC_CIRCUITCircuit)+" filtered circuit(s)");
	}
// hide the text if it is not already hidden
	unTreeWidget_hideText();

	applyFilter.enabled(true);
	saveFilter.enabled(true);
	openFilter.enabled(true);
	advanceFilter.enabled(true);
	sortByPWS.enabled(true);
	sortByIT.enabled(true);
	sortByCT.enabled(true);
	selectCircuit.enabled(true);
	selectDevice.enabled(true);
	SOC.enabled(true);

	unLHCCircuit_TreeOverview_setCheckboxState(selectCircuit.state(FILTER_LHC_CIRCUIT_CHECKBOX), SOC.state(FILTER_LHC_CIRCUIT_CHECKBOX));	

	if(cWidget.state(0))
		listPages.enabled(true);
	cWidget.enabled(true);
	cSnapshot.enabled(true);

	if(bUpdate)
		unLHCCircuit_TreeOverview_filterChanged();

	unTreeWidget_setPropertyValue(shTreeShape, "setMousePointer", iCurrentPointer, true);
// enable the unTreeWidget tree.
	unTreeWidget_setPropertyValue(shTreeShape, "Enabled", true, true);
// stop the progress bar.
//	unProgressBar_stop(id, TREEBAR_NAME);
//DebugTN("unTreeDeviceOverview_displayCallBack end");
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_buildList
/**
Purpose:
Build the list of subsystem1 and subsystem2
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_buildList()
{
	PWSList.items = g_dsLHC_CIRCUITPWS_list;
	PWSList.selectedPos(1);
	interlockTypeList.items = g_dsLHC_CIRCUITInterlockType_list;
	interlockTypeList.selectedPos(1);
	circuitList.items = g_dsLHC_CIRCUITCircuit_list;
	circuitList.selectedPos(1);
	circuitTypeList.items = g_dsLHC_CIRCUITCircuitType_list;
	circuitTypeList.selectedPos(1);
	buildingList.items = g_dsLHC_CIRCUITBuilding_list;
	buildingList.selectedPos(1);
}

//--------------------------------------------------------------------------------------------------------------------------------

// _unLHCCircuit_TreeOverview_buildList
/**
Purpose:
Build the list of subsystem1 and subsystem2
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
_unLHCCircuit_TreeOverview_buildList()
{
	int len, i;
	dyn_string dsCircuit, dsCircuitType, dsInterlockType, dsBuilding, dsTemp, dsPWS;
	
	len = mappinglen(g_m_dsLHC_CIRCUITPWS);
	for(i=1;i<=len;i++) {
		dsTemp = mappingGetValue(g_m_dsLHC_CIRCUITPWS, i);
		dynAppend(dsPWS, dsTemp);
		dsTemp = mappingGetValue(g_m_dsLHC_CIRCUITCircuitBuilding, i);
		dynAppend(dsBuilding, dsTemp);
	}

	dsCircuit = g_dsLHC_CIRCUITCircuit;
	dsCircuitType = g_dsLHC_CIRCUITCircuitCircuitType;
	dsInterlockType = g_dsLHC_CIRCUITCircuitInterlockType;

	dynInsertAt(dsPWS, "*", 1);
	dynAppend(dsPWS, UN_EVENT_LIST_LIST_NAME);
	dynInsertAt(dsInterlockType, "*", 1);
	dynAppend(dsInterlockType, UN_EVENT_LIST_LIST_NAME);
	dynInsertAt(dsCircuit, "*", 1);
	dynAppend(dsCircuit, UN_EVENT_LIST_LIST_NAME);
	dynInsertAt(dsCircuitType, "*", 1);
	dynAppend(dsCircuitType, UN_EVENT_LIST_LIST_NAME);
	dynInsertAt(dsBuilding, "*", 1);
	dynAppend(dsBuilding, UN_EVENT_LIST_LIST_NAME);

	dynUnique(dsPWS);
	dynUnique(dsInterlockType);
	dynUnique(dsCircuit);
	dynUnique(dsCircuitType);
	dynUnique(dsBuilding);
	
	g_dsLHC_CIRCUITPWS_list = dsPWS;
	g_dsLHC_CIRCUITInterlockType_list = dsInterlockType;
	g_dsLHC_CIRCUITCircuit_list = dsCircuit;
	g_dsLHC_CIRCUITCircuitType_list = dsCircuitType;
	g_dsLHC_CIRCUITBuilding_list = dsBuilding;
}

//--------------------------------------------------------------------------------------------------------------------------------

// _unLHCCircuit_TreeOverview_getCircuitDeviceProperty
/**
Purpose:
Build the list of subsystem1 and subsystem2
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_getCircuitDeviceProperty(string sSystemName, dyn_string &dsPWS, dyn_string &dsCircuit, dyn_string &dsInterlockType, dyn_string &dsCircuitType, dyn_string &dsBuilding, int &iDeviceNumber)
{
	string sFileName;
	string sBuffer;
	string sFileSystemName = sSystemName;
	file fFile;
	dyn_string dsSplit;
	dyn_dyn_string ddsCircuitTemp;
	int i, len;
	
//DebugTN("start unLHCCircuit_TreeOverview_getCircuitDeviceProperty");
	strreplace(sFileSystemName, ":", "");
	sFileName = getPath(DATA_REL_PATH)+"_"+sFileSystemName+LHC_CIRCUIT_CIRCUIT_FILE;
//DebugTN("*** start _unTreeDeviceOverview_getDeviceListFomFile", sSystemName, sFileName);
	fileToString(sFileName, sBuffer);
	dsSplit = strsplit(sBuffer, "\n");
	len = dynlen(dsSplit);
	for(i=1;i<=len;i++)
	{
		dynAppend(ddsCircuitTemp, strsplit(dsSplit[i], ";"));
	}
	if(!unLHCCircuit_TreeOverview_checkDeviceListSize(ddsCircuitTemp)) {
		dsCircuit = dsInterlockType = dsCircuitType = dsBuilding = dsPWS = makeDynString();
		iDeviceNumber = 0;
	}
	else{
		dsCircuit = ddsCircuitTemp[LHC_CIRCUIT_CIRCUIT_FILE_CIRCUIT];
		dsInterlockType = ddsCircuitTemp[LHC_CIRCUIT_CIRCUIT_FILE_INTERLOCKTYPE];
		dsCircuitType = ddsCircuitTemp[LHC_CIRCUIT_CIRCUIT_FILE_CIRCUITTYPE];
		dsBuilding = ddsCircuitTemp[LHC_CIRCUIT_CIRCUIT_FILE_BUILDING];
		dsPWS = ddsCircuitTemp[LHC_CIRCUIT_CIRCUIT_FILE_PWS];
		sscanf(ddsCircuitTemp[LHC_CIRCUIT_CIRCUIT_FILE_NB_DEVICE][1], "%d", iDeviceNumber);
	}
//DebugN(dynlen(dsRetDpName), dynlen(dsBuilding)/*, dsRetSubsystem1[1], dsRetSubsystem2[1]*/);
//DebugTN("end unLHCCircuit_TreeOverview_getCircuitDeviceProperty", iDeviceNumber);
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_checkDeviceListSize
/**
Purpose:
check the size of the dyn_string
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
bool unLHCCircuit_TreeOverview_checkDeviceListSize(dyn_dyn_string ddsList)
{
	bool bResult = false;

	if(dynlen(ddsList) == 6) {
		if((dynlen(ddsList[LHC_CIRCUIT_CIRCUIT_FILE_CIRCUIT]) == dynlen(ddsList[LHC_CIRCUIT_CIRCUIT_FILE_INTERLOCKTYPE])) && 
			(dynlen(ddsList[LHC_CIRCUIT_CIRCUIT_FILE_CIRCUIT]) == dynlen(ddsList[LHC_CIRCUIT_CIRCUIT_FILE_CIRCUITTYPE])) && 
			(dynlen(ddsList[LHC_CIRCUIT_CIRCUIT_FILE_NB_DEVICE]) == 1)){
					bResult = true;
			}
	}
	
	return bResult;
}

//--------------------------------------------------------------------------------------------------------------------------------

// _unLHCCircuit_TreeOverview_getCircuitDeviceProperty
/**
Purpose:
Build the list of subsystem1 and subsystem2
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
_unLHCCircuit_TreeOverview_getCircuitDeviceProperty(const string sSystemName, dyn_dyn_string &ddsDeviceList, dyn_string &dsPWS, dyn_string &dsCircuit, dyn_string &dsInterlockType, dyn_string &dsCircuitType, dyn_string &dsBuilding, int &iDeviceNumber)
{
int i, len;
dyn_string dsFE, dsAppl, dsDevType, dsSubsystem1, dsSubsystem2, dsAlias, dsDpName, dsFEDpName, dsFEDPType;
dyn_string dsRetFE, dsRetAppl, dsRetDevType, dsRetSubsystem1, dsRetSubsystem2, dsRetAlias, dsRetDpName, dsRetFEDpName, dsRetFEDPType;

  //DebugTN("start _unLHCCircuit_TreeOverview_getCircuitDeviceProperty");
              
 	dsDpName = ddsDeviceList[TREE_DEVICE_DPNAME];
 	dsAlias = ddsDeviceList[TREE_DEVICE_ALIAS];
 	dsFE = ddsDeviceList[TREE_DEVICE_FE];
 	dsFEDpName = ddsDeviceList[TREE_DEVICE_FEDPNAME];
 	dsFEDPType = ddsDeviceList[TREE_DEVICE_FEDPTYPE];
 	dsAppl = ddsDeviceList[TREE_DEVICE_FEAPPLICATION];
 	dsDevType = ddsDeviceList[TREE_DEVICE_TYPE];
 	dsSubsystem1 = ddsDeviceList[TREE_DEVICE_SUBSYSTEM1];
 	dsSubsystem2 = ddsDeviceList[TREE_DEVICE_SUBSYSTEM2];
       
 	CtrlLHCCircuit_TreeOverview_getCircuitDeviceProperty( dsDpName, dsAlias, dsFE, dsFEDpName, dsFEDPType, dsAppl, dsDevType,
          																							dsSubsystem1, dsSubsystem2, dsRetDpName, dsRetAlias, dsRetFE,
         																								dsRetFEDpName, dsRetFEDPType, dsRetAppl, dsRetDevType,
				          																			dsRetSubsystem1, dsRetSubsystem2, 
									          														dsPWS, dsCircuit, dsInterlockType, dsCircuitType, dsBuilding, iDeviceNumber);
            
	ddsDeviceList[TREE_DEVICE_DPNAME] = dsRetDpName;
	ddsDeviceList[TREE_DEVICE_ALIAS] = dsRetAlias;
	ddsDeviceList[TREE_DEVICE_FE] = dsRetFE;
	ddsDeviceList[TREE_DEVICE_FEDPNAME] = dsRetFEDpName;
	ddsDeviceList[TREE_DEVICE_FEDPTYPE] = dsRetFEDPType;
	ddsDeviceList[TREE_DEVICE_FEAPPLICATION] = dsRetAppl;
	ddsDeviceList[TREE_DEVICE_TYPE] = dsRetDevType;
	ddsDeviceList[TREE_DEVICE_SUBSYSTEM1] = dsRetSubsystem1;
	ddsDeviceList[TREE_DEVICE_SUBSYSTEM2] = dsRetSubsystem2;

//DebugN(dynlen(dsRetDpName), dynlen(dsBuilding)/*, dsRetSubsystem1[1], dsRetSubsystem2[1]*/);
//DebugTN("end _unLHCCircuit_TreeOverview_getCircuitDeviceProperty", iDeviceNumber);
}

//--------------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_TreeOverview_getCircuit
/**
Purpose:
Get the list of circuit
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_getCircuit(dyn_string dsPWS, dyn_string dsInterlockType, dyn_string dsCircuitType, dyn_string &dsCircuit)
{
	dyn_string dsRetInterlockType, dsRetCircuitType;
	
//DebugTN("start unLHCCircuit_TreeOverview_getCircuit");
	unLHCCircuit_TreeOverview_getCircuitInterlockAndType(dsPWS, dsInterlockType, dsCircuitType, 
																											dsCircuit, dsRetInterlockType, dsRetCircuitType);
//DebugTN("end unLHCCircuit_TreeOverview_getCircuit");
}

//--------------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_TreeOverview_getCircuitInterlockAndType
/**
Purpose:
Get the list of circuit, circuit type and internlock type
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_getCircuitInterlockAndType(dyn_string dsPWS, dyn_string dsInterlockType, dyn_string dsCircuitType, 
																											dyn_string &dsCircuit, dyn_string &dsCircuitInterlockType, dyn_string &dsCircuitCircuitType)
{
	bit32 b32SelectState;
	string sSystemName = getSystemName();
	dyn_string dsAppl, dsDevType, dsSubsystem1, dsSubsystem2, dsAlias, dsDpName;
	dyn_string dsRetAppl, dsRetDevType, dsRetSubsystem1, dsRetCircuitInterlockType, dsRetCircuitCircuitType, dsRetAlias, dsRetDpName, dsRetQPSPICPO, dsRetCircuit, dsRetCircuitBuilding;
	dyn_string dsDeviceType=makeDynString("FGC2_LHC_PC");
	dyn_string dsAll = makeDynString("*"), dsEmpty;
	
//DebugTN("start unLHCCircuit_TreeOverview_getCircuit");
	if(mappingHasKey(g_m_ddsTreeDeviceOverviewDeviceList, sSystemName)) {
		dsDpName = g_m_ddsTreeDeviceOverviewDeviceList[sSystemName][TREE_DEVICE_DPNAME];
		dsAlias = g_m_ddsTreeDeviceOverviewDeviceList[sSystemName][TREE_DEVICE_ALIAS];
		dsAppl = g_m_ddsTreeDeviceOverviewDeviceList[sSystemName][TREE_DEVICE_FEAPPLICATION];
		dsDevType = g_m_ddsTreeDeviceOverviewDeviceList[sSystemName][TREE_DEVICE_TYPE];
		dsSubsystem1 = g_m_ddsTreeDeviceOverviewDeviceList[sSystemName][TREE_DEVICE_SUBSYSTEM1];
		dsSubsystem2 = g_m_ddsTreeDeviceOverviewDeviceList[sSystemName][TREE_DEVICE_SUBSYSTEM2];
	
		setBit(b32SelectState, FILTER_LHC_CIRCUIT_POWERING_SUB_SECTOR, true);
		setBit(b32SelectState, FILTER_LHC_CIRCUIT_INTERLOCK_TYPE, true);
		setBit(b32SelectState, FILTER_LHC_CIRCUIT_CIRCUIT_TYPE, true);
		setBit(b32SelectState, FILTER_LHC_CIRCUIT_DEVICE_TYPE, true);
	
		CtrlLHCCircuit_TreeOverview_getSelectedDeviceList(b32SelectState, sSystemName, 
																									dsPWS, dsInterlockType, 
																									dsCircuitType, dsAll,  
																									dsDeviceType, dsAll, 
																									dsAll,
																									dsAll, dsEmpty,
																									dsDpName, dsAlias, dsAppl, 
																									dsDevType, dsSubsystem1, dsSubsystem2, 
																									g_dsLHC_CIRCUITCircuitInterlockType, g_dsLHC_CIRCUITCircuitCircuitType, 
																									g_dsLHC_CIRCUITCircuit, makeDynString("QPS", "PIC", "PC", "Other"), g_m_dsLHC_CIRCUITCircuitBuilding[sSystemName], 
																									dsRetDpName, dsRetAlias, 
																									dsRetAppl, dsRetCircuitInterlockType, 
																									dsRetCircuitCircuitType, dsRetCircuit,
																									dsRetQPSPICPO, dsRetCircuitBuilding, 
																									dsRetDevType, dsRetSubsystem1);
		dynUnique(dsRetCircuit);
		dynUnique(dsRetCircuitInterlockType);
		dynUnique(dsRetCircuitCircuitType);
	}
	dsCircuit = dsRetCircuit;
	dsCircuitInterlockType = dsRetCircuitInterlockType;
	dsCircuitCircuitType = dsRetCircuitCircuitType;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_applyFilter
/**
Purpose: Apply the new filter: erase everything and add all the system connected
	
*/
unLHCCircuit_TreeOverview_applyFilter(shape shTreeShape, bit32 b32SelectState, bit32 b32SortByState, string sRegisteredSystem, bool bRegisterSystem)
{
	int i, len;
	bool bSelect, bSortBy, bTree;
	string sSystemName;
	mapping m;
	
	bSelect = unLHCCircuit_TreeOverview_checkSelectState(b32SelectState);
	bSortBy = unTreeDeviceOverview_checkSortByState(b32SortByState);
	
	if(bSelect) // if new filter selection --> force tree update
		bSortBy = true;
//DebugTN("***** start ApplyFilter", sRegisteredSystem, bRegisterSystem, bSelect, bSortBy, b32SortByState);
			
	b32SelectState_graph.text = b32SelectState;
	b32SortByState_graph.text = b32SortByState;

	if(bSortBy)
		bTree = true;
		
// system add or delete			
	if(bRegisterSystem) {
		bSortBy = true;
		bTree = true;
//DebugN("**** case add", sRegisteredSystem);	
	}
	if(bTree) // clear the tree if new display
		unTreeWidget_setPropertyValue(shTreeShape, "clearTree", true, true);
	if(bSortBy) {
	// add the devices of the connected systems
		g_m_ddsNodeDevice = m;
		len = mappinglen(g_m_bTreeDeviceOverviewSystemConnected);
		unProgressBar_setMax(TREEBAR_NAME, len);
		for(i=1;i<=len;i++) {
			sSystemName = mappingGetKey(g_m_bTreeDeviceOverviewSystemConnected, i);
			unTreeWidget_showText("Select/Sort devices fom "+sSystemName, "Please wait ... "+i+"/"+len);
// wait to let a change to show the text
			delay(0,10);
			unProgressBar_setPosition(TREEBAR_NAME, i);
			if(mappingGetValue(g_m_bTreeDeviceOverviewSystemConnected, i)) {
				g_m_dsNodeInTree[sSystemName] = makeDynString();
				g_m_dbTopNode[sSystemName] = makeDynBool();
				if(g_m_bSystemForceSelectSort[sSystemName]) { // force select and sort
					g_m_bSystemForceSelectSort[sSystemName] = false;
					unLHCCircuit_TreeOverview_selectSortDeviceList(b32SelectState, b32SortByState, sSystemName, true, bSortBy, 
																											g_m_dsNodeInTree[sSystemName], g_m_dbTopNode[sSystemName]);
				}
				else {
					unLHCCircuit_TreeOverview_selectSortDeviceList(b32SelectState, b32SortByState, sSystemName, bSelect, bSortBy, 
																											g_m_dsNodeInTree[sSystemName], g_m_dbTopNode[sSystemName]);
				}
			}
		}
		unProgressBar_setPosition(TREEBAR_NAME, 0);
	// keep the display state
		unTreeDeviceOverview_setSortByState(b32SortByState);
	}
	if(bTree) {
		unTreeDeviceOverview_addNodeInTree(shTreeShape, g_m_bTreeDeviceOverviewSystemConnected, g_m_dsNodeInTree, g_m_dbTopNode);
	}
	if(bSelect) // keep the filter state
		unLHCCircuit_TreeOverview_setSelectState(b32SelectState);
//DebugTN("***** end ApplyFilter");
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_checkSelectState
/**
Purpose:
Check if the filter was modified.
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
bool unLHCCircuit_TreeOverview_checkSelectState(bit32 b32SelectState)
{
	bool bSelect;
	dyn_string dsDeviceType = dsDeviceType_graph.items;
	
	if(g_b32OldSelectState != b32SelectState) {
		bSelect = true;
	}
	else if(g_dsOldInterlockTypeSelected != g_dsInterlockTypeSelected) {
		bSelect = true;
	}
	else if(g_dsOldCircuitTypeSelected != g_dsCircuitTypeSelected) {
		bSelect = true;
	}
	else if(g_dsOldCircuitSelected != g_dsCircuitSelected) {
		bSelect = true;
	}
	else if(g_dsOldPWSSelected != g_dsPWSSelected) {
		bSelect = true;
	}
	else if(g_dsOldQPSPICPOSelected != g_dsQPSPICPOSelected) {
		bSelect = true;
	}
	else if(g_dsOldBuildingSelected != g_dsBuildingSelected) {
		bSelect = true;
	}
	else if(g_dsOldAliasSelected != g_dsAliasSelected) {
		bSelect = true;
	}
	else if(g_dsOldExcludedAliasSelected != g_dsExcludedAliasSelected) {
		bSelect = true;
	}
	else if(g_dsOldDeviceType != dsDeviceType) {
		bSelect = true;
	}
	return bSelect;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_setSelectState
/**
Purpose:
Keep the current filter setting
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_setSelectState(bit32 b32SelectState)
{
	dyn_string dsDeviceType = dsDeviceType_graph.items;
	
	g_b32OldSelectState = b32SelectState;
	g_dsOldInterlockTypeSelected = g_dsInterlockTypeSelected;
	g_dsOldCircuitTypeSelected = g_dsCircuitTypeSelected;
	g_dsOldCircuitSelected = g_dsCircuitSelected;
	g_dsOldPWSSelected = g_dsPWSSelected;
	g_dsOldQPSPICPOSelected = g_dsQPSPICPOSelected;
	g_dsOldBuildingSelected = g_dsBuildingSelected;
	g_dsOldAliasSelected = g_dsAliasSelected;
	g_dsOldExcludedAliasSelected = g_dsExcludedAliasSelected;
	g_dsOldDeviceType = dsDeviceType;
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_selectSortDeviceList
/**
Purpose: Select and/or sort the device list
*/
unLHCCircuit_TreeOverview_selectSortDeviceList(bit32 b32SelectState, bit32 b32SortByState, string sSystemName, bool bSelect, bool bSortBy, 
																										dyn_string &dsNodeInTree, dyn_bool &dbTopNode)
{	
	int iTotalDevice;
	dyn_string dsCircuitAdded;

//DebugTN("start selectSortDeviceList", sSystemName);

	if(bSelect){
		unTreeWidget_showText("Selecting devices fom "+sSystemName, "Please wait ...");
		unLHCCircuit_TreeOverview_getSelectedDeviceList(b32SelectState, sSystemName, g_m_ddsTreeDeviceOverviewDeviceList[sSystemName], g_m_ddsSelectedDevice[sSystemName]);
	}

	if(bSortBy) {
		unTreeWidget_showText("Sorting devices fom "+sSystemName, "Please wait ...");
		unLHCCircuit_TreeOverview_sortSelectedDeviceList(b32SortByState, sSystemName, g_m_ddsSelectedDevice[sSystemName], dsNodeInTree, dbTopNode, dsCircuitAdded,
																											g_m_ddsNodeDevice, "", "");

		iTotalDevice = dynlen(g_m_ddsSelectedDevice[sSystemName][1]);
// keep here the number of devices found=total dev - excluded - clipboard.
		g_m_iDevicePerSystem[sSystemName] = iTotalDevice;
		g_m_dsCircuitPerSystem[sSystemName] = dsCircuitAdded;
//DebugN(sSystemName, g_m_dsCircuitPerSystem);
	}
//DebugTN("End selectSortDeviceList", sSystemName, iTotalDevice);
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_getSelectedDeviceList
/**
Purpose:
Get the list of device and its configuration based on the filter selection criteria
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_getSelectedDeviceList(bit32 b32SelectState, string sSystemName, dyn_dyn_string ddsDeviceList, dyn_dyn_string &ddsSelectedDevice)
{
	dyn_string dsCircuit, dsBuilding, dsQPSPICPO;
	dyn_string dsAppl, dsDevType, dsSubsystem1, dsSubsystem2, dsAlias, dsDpName;
	dyn_string dsRetAppl, dsRetDevType, dsRetSubsystem1, dsRetCircuitInterlockType, dsRetCircuitCircuitType, dsRetAlias, dsRetDpName, dsRetQPSPICPO, dsRetCircuit, dsRetCircuitBuilding;
	dyn_string dsDeviceType=dsDeviceType_graph.items;
	
	dsDpName = ddsDeviceList[TREE_DEVICE_DPNAME];
	dsAlias = ddsDeviceList[TREE_DEVICE_ALIAS];
	dsAppl = ddsDeviceList[TREE_DEVICE_FEAPPLICATION];
	dsDevType = ddsDeviceList[TREE_DEVICE_TYPE];
	dsSubsystem1 = ddsDeviceList[TREE_DEVICE_SUBSYSTEM1];
	dsSubsystem2 = ddsDeviceList[TREE_DEVICE_SUBSYSTEM2];

//DebugTN("start unLHCCircuit_TreeOverview_getSelectedDeviceList", sSystemName, dynlen(dsDpName));
	CtrlLHCCircuit_TreeOverview_getSelectedDeviceList(b32SelectState, sSystemName, 
																								g_dsPWSSelected, g_dsInterlockTypeSelected, 
																								g_dsCircuitTypeSelected, g_dsCircuitSelected,  
																								dsDeviceType, g_dsQPSPICPOSelected, 
																								g_dsBuildingSelected,
																								g_dsAliasSelected, g_dsExcludedAliasSelected,
																								dsDpName, dsAlias, dsAppl, 
																								dsDevType, dsSubsystem1, dsSubsystem2, 
																								g_dsLHC_CIRCUITCircuitInterlockType, g_dsLHC_CIRCUITCircuitCircuitType, 
																								g_dsLHC_CIRCUITCircuit, g_QPSPICPO, g_m_dsLHC_CIRCUITCircuitBuilding[sSystemName], 
																								dsRetDpName, dsRetAlias, 
																								dsRetAppl, dsRetCircuitInterlockType, 
																								dsRetCircuitCircuitType, dsRetCircuit,
																								dsRetQPSPICPO, dsRetCircuitBuilding, 
																								dsRetDevType, dsRetSubsystem1);

	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_DPNAME] = dsRetDpName;
	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_ALIAS] = dsRetAlias;
	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_CIRCUIT] = dsRetCircuit;
	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_BUILDING] = dsRetCircuitBuilding;
	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_QPSPICPO] = dsRetQPSPICPO;
	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_PWS] = dsRetAppl;
	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_TYPE] = dsRetDevType;
	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_SUBSYSTEM1] = dsRetSubsystem1;
	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_INTERLOCKTYPE] = dsRetCircuitInterlockType;
	ddsSelectedDevice[LHC_CIRCUIT_TREE_DEVICE_CIRCUITTYPE] = dsRetCircuitCircuitType;
//DebugTN("end unLHCCircuit_TreeOverview_getSelectedDeviceList", sSystemName, dynlen(dsRetDpName));
/*int i, len=dynlen(dsRetDpName);
for(i=1;i<=len;i++)
DebugN(i, dsRetAppl[i], dsRetDpName[i], dsRetAlias[i], dsRetDevType[i], dsRetCircuitInterlockType[i], dsRetCircuitCircuitType[i], dsRetCircuit[i], dsRetSubsystem1[i]);
*/
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_sortSelectedDeviceList
/**
Purpose:
Sort the list of selected device.
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_sortSelectedDeviceList(bit32 b32SortByState, string sSystemName, dyn_dyn_string ddsDeviceList, dyn_string &dsNodeInTree, dyn_bool &dbTopNode, dyn_string &dsCircuitAdded,
																									mapping &m_ddsNodeDevice, string sSelectedKey, string sSelectedLabel)
{
	dyn_string dsDevType, dsAlias, dsDpName, dsCircuit, dsQPSPICPO, dsBuilding, dsPWS, dsInterlockType, dsCircuitType;
	dyn_dyn_string ddsNodeDevice, ddsDpName, ddsAlias, ddsPWS, ddsInterlockType, ddsCircuitType, ddsCircuit, ddsQPSPICPO, ddsBuilding, ddsDevType;
	dyn_string dsKey; 
	bit32 b32 = b32SortByState;
	bool bKey;
	int i, len;
//DebugTN("start sortSelectedDeviceList", sSystemName, dynlen(ddsDeviceList));

/*
		// add topNode: class~key where key is |labelOfTheNode;dpNameOfTheNode
			aShape.addTopNode(class+"~"+key);


	// add Node: class~key where key is parentLabel;dpParent|childLabel;dpChild@parentKey
				aShape.addNode(class+"~"+key);

*/

	if(dynlen(ddsDeviceList) <= 0)
		return;
		
	dsDpName = ddsDeviceList[LHC_CIRCUIT_TREE_DEVICE_DPNAME];
	dsAlias = ddsDeviceList[LHC_CIRCUIT_TREE_DEVICE_ALIAS];
	dsCircuit = ddsDeviceList[LHC_CIRCUIT_TREE_DEVICE_CIRCUIT];
	dsQPSPICPO = ddsDeviceList[LHC_CIRCUIT_TREE_DEVICE_QPSPICPO];
	dsBuilding = ddsDeviceList[LHC_CIRCUIT_TREE_DEVICE_BUILDING];
	dsPWS = ddsDeviceList[LHC_CIRCUIT_TREE_DEVICE_PWS];
	dsDevType = ddsDeviceList[LHC_CIRCUIT_TREE_DEVICE_TYPE];
	dsInterlockType = ddsDeviceList[LHC_CIRCUIT_TREE_DEVICE_INTERLOCKTYPE];
	dsCircuitType = ddsDeviceList[LHC_CIRCUIT_TREE_DEVICE_CIRCUITTYPE];

	if(sSelectedKey != "")
		bKey = true;
//DebugTN("start unLHCCircuit_TreeOverview_sortSelectedDeviceList", sSystemName, dynlen(dsDpName), dynlen(dsAlias), dynlen(dsNodeInTree));

//DebugN(dynlen(dsDpName), dynlen(dsAlias), dynlen(dsFE), dynlen(dsFEDpName), dynlen(dsFEDpType), dynlen(dsAppl), dynlen(dsDevType), dynlen(dsDevSubsystem1), dynlen(dsDevSubsystem2));
//DebugN(sSelectedKey, bKey);
	CtrlLHCCircuit_TreeOverview_sortSelectedDeviceList(b32SortByState, sSystemName, dsDpName, dsAlias, dsPWS,
																									dsInterlockType, dsCircuitType, dsCircuit, dsQPSPICPO, dsBuilding, dsDevType,
																									dsNodeInTree, dbTopNode, dsCircuitAdded,
																									dsKey, ddsDpName, ddsAlias, ddsPWS, ddsInterlockType, ddsCircuitType, 
																									ddsCircuit, ddsQPSPICPO, ddsBuilding, ddsDevType,
																									bKey, sSelectedKey, sSelectedLabel);


	if(getBit(b32, FILTER_LHC_CIRCUIT_POWERING_SUB_SECTOR))
		setBit(b32, FILTER_LHC_CIRCUIT_POWERING_SUB_SECTOR, false);
	else if(getBit(b32, FILTER_LHC_CIRCUIT_INTERLOCK_TYPE))
		setBit(b32, FILTER_LHC_CIRCUIT_INTERLOCK_TYPE, false);
	else if(getBit(b32, FILTER_LHC_CIRCUIT_CIRCUIT_TYPE))
		setBit(b32, FILTER_LHC_CIRCUIT_CIRCUIT_TYPE, false);
	else if(getBit(b32, FILTER_LHC_CIRCUIT_CIRCUIT))
		setBit(b32, FILTER_LHC_CIRCUIT_CIRCUIT, false);
	else if(getBit(b32, FILTER_LHC_CIRCUIT_QPS_PIC_PO))
		setBit(b32, FILTER_LHC_CIRCUIT_QPS_PIC_PO, false);
	else if(getBit(b32, FILTER_LHC_CIRCUIT_BUILDING))
		setBit(b32, FILTER_LHC_CIRCUIT_BUILDING, false);
	else if(getBit(b32, FILTER_LHC_CIRCUIT_DEVICE_TYPE))
		setBit(b32, FILTER_LHC_CIRCUIT_DEVICE_TYPE, false);

	len = dynlen(dsKey);
	for(i=1;i<=len;i++) {
		dsDpName = ddsDpName[i];
		dsAlias = ddsAlias[i];
		dsCircuit = ddsCircuit[i];
		dsQPSPICPO = ddsQPSPICPO[i];
		dsBuilding = ddsBuilding[i];
		dsPWS = ddsPWS[i];
		dsDevType = ddsDevType[i];
		dsInterlockType = ddsInterlockType[i];
		dsCircuitType = ddsCircuitType[i];
		if(mappingHasKey(m_ddsNodeDevice, dsKey[i])) {
			ddsNodeDevice = m_ddsNodeDevice[dsKey[i]];
			dynAppend(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_DPNAME], dsDpName);
			dynAppend(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_ALIAS], dsAlias);
			dynAppend(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_CIRCUIT], dsCircuit);
			dynAppend(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_QPSPICPO], dsQPSPICPO);
			dynAppend(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_BUILDING], dsBuilding);
			dynAppend(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_PWS], dsPWS);
			dynAppend(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_TYPE], dsDevType);
			dynAppend(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_INTERLOCKTYPE], dsInterlockType);
			dynAppend(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_CIRCUITTYPE], dsCircuitType);
		}
		else {
			ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_DPNAME] = dsDpName;
			ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_ALIAS] = dsAlias;
			ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_CIRCUIT] = dsCircuit;
			ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_QPSPICPO] = dsQPSPICPO;
			ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_BUILDING] = dsBuilding;
			ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_PWS] = dsPWS;
			ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_TYPE] = dsDevType;
			ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_INTERLOCKTYPE] = dsInterlockType;
			ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_CIRCUITTYPE] = dsCircuitType;
		}
		ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_SORTSTATE][1] = b32;
		m_ddsNodeDevice[dsKey[i]] = ddsNodeDevice;
	}
	
/*for(i=1;i<=mappinglen(m_ddsNodeDevice);i++) {
ddsNodeDevice = mappingGetValue(m_ddsNodeDevice, i);
DebugN(i, mappingGetKey(m_ddsNodeDevice, i), dynlen(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_DPNAME]), dynlen(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_ALIAS]), 
					dynlen(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_CIRCUIT]),dynlen(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_QPSPICPO]),
					dynlen(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_BUILDING]),dynlen(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_PWS]),
					dynlen(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_TYPE]),dynlen(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_INTERLOCKTYPE]),
					dynlen(ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_CIRCUITTYPE]), ddsNodeDevice[LHC_CIRCUIT_TREE_DEVICE_SORTSTATE]);
}
*/
//DebugTN(sSystemName, dsCircuitAdded);
//DebugTN("end", sSystemName);
//DebugTN("end unLHCCircuit_TreeOverview_sortSelectedDeviceList", sSystemName, iCircuitNumber, dynlen(dsNodeInTree));
}

//--------------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_TreeOverview_DoubleClick
/**
Purpose: Function called called when a click on a node of the unTreeWidget is done.

	@param sSelectedKey: string, input: the key of the node that was selected in the unTreeWidget, the format of the sSelectedKey is sContext|childrenLabel parentKey
	@param sMode: string, input: the type of mouse click
	@param sCompositeLabel: string, input: the composite label of the node
	@param sGraphTree: string, input: the name of the unTreeWidget graphical element
	@param sBar: string, input: the name of the the Microsoft ProgressBar Control, version 6.0 graphical element
	@param bClipboard: bool, input: true show the clipboard, false don't show the clipboard

Constraints:
	the Microsoft ProgressBar Control, version 6.0
*/

unLHCCircuit_TreeOverview_DoubleClick(string sSelectedKey, string sMode, string sCompositeLabel, string sGraphTree, string sBar, bool bClipboard)
{
	string sDpName, sDisplayNodeName, sParentDpName, sParentNodeName;
	dyn_string dsUnicosObjects, exInfo;
	int iX, iY;
//	bool bDevice = selectDevice.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bool bDevice;
	bit32 b32SortByState = b32SortByState_graph.text;
	
	bDevice = getBit(b32SortByState, FILTER_LHC_CIRCUIT_CIRCUIT_DEVICE);

	if(bDevice) { // device mode
		if((sMode == "doubleClick") && (sCompositeLabel != "")) {
			unTreeWidget_getNodeNameAndNodeDp(sCompositeLabel, sDpName, sDisplayNodeName, sParentDpName, sParentNodeName);
			if(dpExists(sDpName)) {
				unGenericDpFunctions_getUnicosObjects(dsUnicosObjects);
				if(dynContains(dsUnicosObjects, dpTypeName(sDpName)) > 0) {
					unGenericObject_OpenFaceplate(sDpName, exInfo);
				}
			}
		}
	}
	else { // circuit mode
		if((sMode == "doubleClick") && (sCompositeLabel != "")) {
			unTreeWidget_getNodeNameAndNodeDp(sCompositeLabel, sDpName, sDisplayNodeName, sParentDpName, sParentNodeName);
			if(sDpName == CIRCUIT_DP) {
				iX = childXPos.text();
				iY = childYPos.text();
				
                                string sInterlockType, sCircuitType;
                                unLHCCircuit_GenericFunctions_getCircuitType(sDisplayNodeName, sInterlockType, sCircuitType);
                                
                                dyn_string dsDollarParameters;
                                dsDollarParameters=makeDynString("$bPopup:"+true,"$sCircuit:"+sDisplayNodeName,"$sInterlockType:"+sInterlockType);  //InterlockType X - temporarly - need to find a dynamic solution
                                unLHCCircuit_GenericFunctions_CircuitModule("vision/SYNOPTICS/LHC_CIRCUIT_SYNOPTIC_VIEW.pnl", sDisplayNodeName, dsDollarParameters);
                                
                                /*
                                ChildPanelOn("vision/SYNOPTICS/LHC_CIRCUIT_SYNOPTIC_VIEW.pnl", sDisplayNodeName, 
				makeDynString("$sCircuit:"+sDisplayNodeName, "$bPopup:"+true), iX, iY);
				*/
                                
                                childXPos.text() = iX + LHC_CIRCUIT_TREE_DEVICE_CHILD_POS_XIDENT;
				childYPos.text() = iY + LHC_CIRCUIT_TREE_DEVICE_CHILD_POS_YIDENT;
//DebugN("open circuit synoptic "+ sDisplayNodeName, "vision/SYNOPTICS/LHC_CIRCUIT_SYNOPTIC_VIEW.pnl");
			}
		}
	}
}

//--------------------------------------------------------------------------------------------------------------------------------

//
// unLHCCircuit_TreeOverview_getCircuitList
/**
Purpose: 
Get the list of children circuit when a left click was done on a node of the tree 

Parameters:
	@param sTreeName: string, input, the unTreeWidget name
	@param sSelectedKey: string, input, the key of the selected node
	@param sCompositeLabel: string, input, the compostite label of the selected node
	@param dsDeviceName: dyn_string, output, the list of children device name of the selected node
	@param dsParentDeviceName: dyn_string, output, the list of parent (parent of the parent of the parent ...) device DP name of the selected node
	
Usage: External

PVSS manager usage: NG, NV

Constraints:
	. Use constants UN_POPUPMENU_***
	. PVSS version: 2.12.1 
	. operating system: NT and W2000, but tested only under W2000.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_getCircuitList(string sTreeName, string sSelectedKey, string sCompositeLabel, dyn_string &dsDeviceName, dyn_string &dsParentDeviceName)
{
	dyn_string dsChildrenCompositeLabel, dsDpName, dsDisplayNodeName, dsParentDpName, dsParentNodeName, dsParentCompositeLabel;
	int len, i;
	shape aShape = getShape(sTreeName);
	string sChildrenCompositeLabelOfSelectedNode, sAllParentCompositeLabelOfSelectedNode;
	string sDpName, sDisplayNodeName, sParentDpName, sParentNodeName;
	
	if(sSelectedKey != "") {
		unTreeWidget_getNodeNameAndNodeDp(sCompositeLabel, sDpName, sDisplayNodeName, sParentDpName, sParentNodeName);
		unTreeDeviceOverview_displayLoadingText("Loading circuit "+sDisplayNodeName, "Please wait ...");
		sChildrenCompositeLabelOfSelectedNode = unTreeWidget_getPropertyValue(aShape, "getChildrenCompositeLabelOfNode", true, sSelectedKey);
		sAllParentCompositeLabelOfSelectedNode = unTreeWidget_getPropertyValue(aShape, "getAllParentCompositeLabelOfNode", true, sSelectedKey);
		dsChildrenCompositeLabel = strsplit(sChildrenCompositeLabelOfSelectedNode, unTreeWidget_keySeparator);
		dsParentCompositeLabel = strsplit(sAllParentCompositeLabelOfSelectedNode, unTreeWidget_keySeparator);
		len = dynlen(dsChildrenCompositeLabel);
		for(i=1; i<=len; i++) {
			unTreeDeviceOverview_displayLoadingText("Extracting circuit configuration "+i+"/"+len, "Please wait ...", 100*i/len);
			unTreeWidget_getNodeNameAndNodeDp(dsChildrenCompositeLabel[i], dsDpName[i], dsDisplayNodeName[i], dsParentDpName[i], dsParentNodeName[i]);
			if(dsDpName[i] == CIRCUIT_DP) {
				dynAppend(dsDeviceName, dsDisplayNodeName[i]);
			}
//DebugN(i, dsChildrenCompositeLabel[i], dsDpName[i], dsDisplayNodeName[i], dsParentDpName[i], dsParentNodeName[i]);
		}
		dynInsertAt(dsParentCompositeLabel, sCompositeLabel, 1);
		len = dynlen(dsParentCompositeLabel);
		dsDpName = dsDisplayNodeName = dsParentDpName = dsParentNodeName = makeDynString();
		for(i=1; i<=len; i++) {
			unTreeDeviceOverview_displayLoadingText("Extracting configuration from circuit tree "+i+"/"+len, "Please wait ...", 100*i/len);
			unTreeWidget_getNodeNameAndNodeDp(dsParentCompositeLabel[i], dsDpName[i], dsDisplayNodeName[i], dsParentDpName[i], dsParentNodeName[i]);
			dynAppend(dsParentDeviceName, dsDisplayNodeName[i]);
//DebugN(i, dsParentCompositeLabel[i], dsDpName[i], dsDisplayNodeName[i], dsParentDpName[i], dsParentNodeName[i]);
		}
	}
//DebugN(dsDeviceName);
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_initializeCircuitToDisplay
/**
Purpose:
Initialize the circuit list to show and the display variables.
	
	@param dsDeviceName: dyn_string, input: the list of device name.

Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_initializeCircuitToDisplay(dyn_string dsDeviceName)
{
  int i, iPages, msg1, msg2, len=dynlen(dsDeviceName);
  int beginCircuit; 
  int endCircuit; 
  dyn_string dsIt, dsCt;
  int columnsCircuit = columnsCircuit_graph.text(), linesCircuit = linesCircuit_graph.text();
  int iTotal;
  
  unLHCCircuit_GenericFunctions_getCircuitType(dsDeviceName, dsIt, dsCt);
  circuitList_graph.items = dsDeviceName;
  dscircuitType_graph.items = dsCt;
  dsinterlockType_graph.items = dsIt;
  circuitInfo.text = len + " circuit(s) found";
  circuitPages.deleteAllItems();
  beginCircuit = 0;
  beginCircuit_graph.text = beginCircuit;
  endCircuit = 0;
  endCircuit_graph.text = endCircuit;

  if (len > 0)
  {
    iTotal = linesCircuit * columnsCircuit;
    iPages = len / iTotal;
    if (iPages * iTotal != len)
    {
      iPages++;
    }
    for(i=1;i<=iPages-1;i++)
    {
      msg1 = (i-1) * iTotal + 1;
      msg2 = i * iTotal;
      circuitPages.appendItem("Circuit " + msg1 + " to " + msg2);
    }
    msg1 = (iPages-1) * iTotal + 1;
    msg2 = len;
    circuitPages.appendItem("Circuit " + msg1 + " to " + msg2);
  }
//DebugN("old", dsDeviceName);
}

//--------------------------------------------------------------------------------------------------------------------------------

// unLHCCircuit_TreeOverview_removedDisplayedCircuit
/**
Purpose:
Remove all the added symbol circuit in the circuit overview

Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_removedDisplayedCircuit()
{
  int i, length;
  int beginCircuit = beginCircuit_graph.text;
  int endCircuit = endCircuit_graph.text; 
  string sShape;
  
  for(i=endCircuit;i>=beginCircuit;i--)
  {
    sShape = WIDGET_REFERENCE + i;
    if(shapeExists(sShape+".Body1"))
    {
      removeSymbol(myModuleName(), myPanelName(), WIDGET_REFERENCE + i);
    }
  }
}

//--------------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_TreeOverview_displayCircuit
/**
Purpose:
Show the circuits in the circuit overview
	
	@param newBeginCircuit: string, input: start position in the list of circuits.
	@param newEndCircuit: dyn_string, input: end position in the list of circuits.

Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_displayCircuit(int newBeginCircuit, int newEndCircuit)
{
  int i;
  dyn_string dsDollar;
  dyn_string circuitList = circuitList_graph.items;
  dyn_string dsCt= dscircuitType_graph.items;
  dyn_string dsIt = dsinterlockType_graph.items;
  int beginCircuit = beginCircuit_graph.text;
  int endCircuit = endCircuit_graph.text; 
  string sCircuitList;
  int iPerc;
  int widthCircuit = widthCircuit_graph.text(), heightCircuit = heightCircuit_graph.text();
  int columnsCircuit = columnsCircuit_graph.text(), linesCircuit = linesCircuit_graph.text();
  int leftSpacingCircuit = leftSpacingCircuit_graph.text(), topSpacingCircuit = topSpacingCircuit_graph.text();
  int positionX, positionY;
  int iLeft, iTop;
        
  unTreeDeviceOverview_displayLoadingText("Loading circuits", "Please wait ...");
  if ((newBeginCircuit != beginCircuit) || (newEndCircuit != endCircuit))
  {
    // remove the current devices symbol and keep the new value for future use
    unLHCCircuit_TreeOverview_removedDisplayedCircuit();

    beginCircuit = newBeginCircuit;
    beginCircuit_graph.text = beginCircuit; 

    endCircuit = newEndCircuit;
    endCircuit_graph.text = endCircuit; 

    positionX = 1;
    positionY = 1;
    for(i=beginCircuit;i<=endCircuit;i++)
    {
      // get the device name
      iPerc = 100*(1+i-beginCircuit)/(1+endCircuit-beginCircuit);
      unTreeDeviceOverview_displayLoadingText("Loading circuits "+(1+i-beginCircuit)+"/"+(1+endCircuit-beginCircuit), "Please wait ... ", iPerc);
		
      iLeft = leftSpacingCircuit + (widthCircuit * (positionX - 1));
      iTop = topSpacingCircuit + (heightCircuit * (positionY - 1));

      unGenericDpFunctions_debugN(DEBUG_ONLY_BIT0, "unLHCCircuit_TreeOverview_displayCircuit", i, iLeft, leftSpacingCircuit, widthCircuit, positionX, iTop, topSpacingCircuit, heightCircuit, positionY);
		
      unLHCCircuit_GenericFunctions_addCircuit(i, circuitList[i], dsIt[i], dsCt[i], iLeft, iTop);						
			
      positionX++;
      if (positionX > columnsCircuit)
      {
        positionX = 1;
        positionY++;
      }
    }
  }

}
unLHCCircuit_TreeOverview_distributedRegister(dyn_string &exceptionInfo)
{
  string sTreeDevOvDp=unTreeDeviceOverview_getInternalTriggerName();
  bool bInitOk, bConnected;
  
  if(dpExists(sTreeDevOvDp)) {
    unTreeDeviceOverview_distributedRegister("unLHCCircuit_GenericFunctions_TreeDeviceOverviewWidgetRegisterCB", bInitOk, bConnected, getSystemName(), sTreeDevOvDp, exceptionInfo);
    if (!bInitOk)
    {
		unSendMessage_toAllUsers("LHCCircuit_TreeOverview " + getCatStr("unOperator","UNKNOWNDOLLARPARAM") + " in panel " + sPanelName, exceptionInfoTemp);
		if (dynlen(exceptionInfoTemp) > 0)
			fwExceptionHandling_display(exceptionInfoTemp);

		fwException_raise(exceptionInfo, "EXPERTINFO", "$sIdentifier" + getCatStr("unPVSS","UNKNOWNDOLLARPARAM") + " or register failed", "");
		unSendMessage_toExpertException("unGenericObject_WidgetInit", exceptionInfo);
		}	
  }
  else
    fwException_raise(exceptionInfo, "ERROR", "Wrong inialisation, please restart .... ", "");
}

//--------------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_TreeOverview_filterChanged()
/**
Purpose: Evaluate if something changed in the filter compared to the current one applied and show it
*/
unLHCCircuit_TreeOverview_filterChanged()
{
	bit32 b32SelectState, b32SortByState;
	bool bPWS, bInterlockType, bCircuitType, bCircuit, bQPSPICPO, bBuilding, bDeviceType,bAlias, bDevice;

	bPWS = sortByPWS.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bInterlockType = sortByIT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bCircuitType = sortByCT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bCircuit = sortByC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bQPSPICPO = sortByQPSPICPC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bBuilding = sortByB.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bDeviceType = sortByD.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bDevice = selectDevice.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_POWERING_SUB_SECTOR, bPWS);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_INTERLOCK_TYPE, bInterlockType);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_CIRCUIT_TYPE, bCircuitType);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_CIRCUIT, bCircuit);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_QPS_PIC_PO, bQPSPICPO);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_BUILDING, bBuilding);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_DEVICE_TYPE, bDeviceType);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_ALIAS, false);
	setBit(b32SortByState, FILTER_LHC_CIRCUIT_CIRCUIT_DEVICE, bDevice);

	bPWS = selectPWS.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bInterlockType = selectIT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bCircuitType = selectCT.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bCircuit = selectC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bQPSPICPO = selectQPSPICPC.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bBuilding = selectB.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bDeviceType = selectD.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	bAlias = selectA.state(FILTER_LHC_CIRCUIT_CHECKBOX);
	
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_POWERING_SUB_SECTOR, bPWS);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_INTERLOCK_TYPE, bInterlockType);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_CIRCUIT_TYPE, bCircuitType);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_CIRCUIT, bCircuit);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_QPS_PIC_PO, bQPSPICPO);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_BUILDING, bBuilding);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_DEVICE_TYPE, bDeviceType);
	setBit(b32SelectState, FILTER_LHC_CIRCUIT_ALIAS, bAlias);

	needApplyBackground.visible() = unLHCCircuit_TreeOverview_checkSelectState(b32SelectState) || unTreeDeviceOverview_checkSortByState(b32SortByState);
}

//--------------------------------------------------------------------------------------------------------------------------------
// _unLHCCircuit_TreeOverview_buildDeviceList()
/**
Purpose: 
Build the device list for all the known circuits

Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.6 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
_unLHCCircuit_TreeOverview_buildDeviceList()
{        
// init done, enable dev tree ov.
  unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unLHCCircuit_TreeOverview", "Start _unLHCCircuit_TreeOverview_buildDeviceList", dynlen(g_dsLHC_CIRCUITCircuit));
  synchronized(g_dsLHC_CIRCUITCircuit) {
    unLHCCircuit_GenericFunctions_getCircuitDevice(g_dsLHC_CIRCUITCircuit, g_ddsLHC_CIRCUITDeviceDp, g_ddsLHC_CIRCUITDeviceAlias, g_ddsLHC_CIRCUITDeviceType);
  }
  unGenericDpFunctions_debugTN(DEBUG_ONLY_BIT0, "unLHCCircuit_TreeOverview", "end _unLHCCircuit_TreeOverview_buildDeviceList", dynlen(g_ddsLHC_CIRCUITDeviceDp), dynlen(g_ddsLHC_CIRCUITDeviceAlias), dynlen(g_ddsLHC_CIRCUITDeviceType));
}

//--------------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_TreeOverview_getCircuitDevice()
/**
Purpose: 
Evaluate if something changed in the filter compared to the current one applied and show it

	@param sCircuit: string, input: the circuit name.
	@param dsCircuitDeviceDp: dyn_string, output: the list of device Dp of the circuit.
	@param dsCircuitDeviceAlias: dyn_string, output: the list of device name of the circuit.
	@param dsCircuitDeviceType: dyn_string, output: the list of device type of the circuit.
	
Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. PVSS manager type: PVSS00NG and PVSS00NV
	. operating system: WXP.
	. distributed system: yes.
*/
unLHCCircuit_TreeOverview_getCircuitDevice(string sCircuit, dyn_string &dsCircuitDeviceDp, dyn_string &dsCircuitDeviceAlias, dyn_string &dsCircuitDeviceType)
{
  int iPos;
  
  iPos = dynContains(g_dsLHC_CIRCUITCircuit, sCircuit);
//DebugTN("start unLHCCircuit_TreeOverview_getCircuitDevice", sCircuit, iPos);
  if(iPos > 0) {
    synchronized(g_dsLHC_CIRCUITCircuit) {
      dsCircuitDeviceDp = g_ddsLHC_CIRCUITDeviceDp[iPos];
      dsCircuitDeviceAlias = g_ddsLHC_CIRCUITDeviceAlias[iPos];
      dsCircuitDeviceType = g_ddsLHC_CIRCUITDeviceType[iPos];
    }
  }  
//DebugTN("end unLHCCircuit_TreeOverview_getCircuitDevice", sCircuit, iPos);
}

//--------------------------------------------------------------------------------------------------------------------------------
// unLHCCircuit_TreeOverview_getCryoDeviceList()
/**
Purpose: 
Get the list of CRYO devices and its configuration

	@param sSystemName: string, input: the system name
	@param ddsDeviceDetail: dyn_string, output: CRYO devices information

Usage: Public

PVSS manager usage: Ctrl

Constraints:
	. PVSS version: 3.6 
	. PVSS manager type: PVSS00Ctrl
	. operating system: WXP, SLC4
	. distributed system: yes.
*/

void unLHCCircuit_TreeOverview_getCryoDeviceList(const string sSystemName, dyn_dyn_string &ddsDeviceDetail)
{
int i, iLen, ident, iDocum, element;
dyn_string dsSplit, dsDpNames, exceptionInfo, dsFE, dsAppl, dsDevType, dsSubsystem1, dsSubsystem2, dsFEDpName, dsFEDPType;	
string sDpName, sCircuit, sPWS, sInterlockType, sCircuitType, sFEDpName, sDomain;
dyn_string dsDevices;
dyn_dyn_string ddsCircuits;
    
  //get the list of Alias from the xml file => dsAlias (<cryo_device name=...)
 
  iDocum=unLHCCircuit_xml_init(getPath(DATA_REL_PATH, LHC_CIRCUIT_CRYO_DATA_FILE));
  if(mappingHasKey(g_mSystemId, sSystemName)) ident=g_mSystemId[sSystemName];
  else ident=0;         
  unLHCCircuit_xml_getData(iDocum, ident, sSystemName, dsDevices, ddsCircuits, exceptionInfo);
  unLHCCircuit_xml_close(iDocum);        
  
  iLen=dynlen(dsDevices);
  for(i=1;i<=iLen;i++)
    {
    sDpName=unGenericDpFunctions_dpAliasToName(sSystemName + dsDevices[i]);
    if(dpExists(sDpName))
      {
      dsDpNames[i] = sDpName;
      dsFE[i] = unGenericObject_GetPLCNameFromDpName(sDpName);
  		sFEDpName = sSystemName + dsFE[i];
      dsAppl[i] = unGenericDpFunctions_getApplication(sDpName);
      dsDevType[i] = dpTypeName(sDpName);
      dsSubsystem2[i] = ddsCircuits[i][4] + "," + ddsCircuits[i][2] + "," + ddsCircuits[i][3];
      
      if((dsDevType[i]=="AnalogInput") || (dsDevType[i]=="Analog") || (dsDevType[i]=="CPC_AnalogInput") || (dsDevType[i]=="CPC_Analog"))
        {
        dsSplit=strsplit(dsDevices[i],"_");
        if(dynlen(dsSplit)==3) sDomain=dsSplit[1] + "," + dsSplit[3] + "," + dsSplit[2];
        else sDomain=",,";
        dsSubsystem1[i] = sDomain + "," + ddsCircuits[i][1];
        }
	  	else
        {
        /*dsSplit=strsplit(dsDevices[i],"_");
        if(dynlen(dsSplit)==3) sDomain=dsSplit[1] + "," + dsSplit[2];
        else*/ sDomain=",";                  
        dsSubsystem1[i] = sDomain + "," + ddsCircuits[i][1];
        }

      if(dpExists(sFEDpName))
        {
 			  dsFEDpName[i] = sFEDpName;                                                    
        dsFEDPType[i] = dpTypeName(sFEDpName);
        }
  		else
        {     
        dsFEDPType[i] = NOT_DP;
 			  dsFEDpName[i] = NOT_DP;                        
        }              
      }
    else
      {
      dsDpNames[i] = NOT_DP;
      dsFE[i] = NOT_DP;
      dsFEDPType[i] = NOT_DP;
      dsFEDpName[i] = NOT_DP;
      dsAppl[i] = NOT_DP;
      dsDevType[i] = NOT_DP;
      dsSubsystem1[i] = NOT_DP;
      dsSubsystem2[i] = NOT_DP;
      }
    }
  
	//DebugTN("end for",sSystemName, dynlen(dsDpNames));

	ddsDeviceDetail[TREE_DEVICE_DPNAME] = dsDpNames;
	ddsDeviceDetail[TREE_DEVICE_ALIAS] = dsDevices;
	ddsDeviceDetail[TREE_DEVICE_FE] = dsFE;
	ddsDeviceDetail[TREE_DEVICE_FEDPNAME] = dsFEDpName;
	ddsDeviceDetail[TREE_DEVICE_FEDPTYPE] = dsFEDPType;
	ddsDeviceDetail[TREE_DEVICE_FEAPPLICATION] = dsAppl;
	ddsDeviceDetail[TREE_DEVICE_TYPE] = dsDevType;
	ddsDeviceDetail[TREE_DEVICE_SUBSYSTEM1] = dsSubsystem1;
	ddsDeviceDetail[TREE_DEVICE_SUBSYSTEM2] = dsSubsystem2;
	
}

//@}


